**********************************************************
**********************************************************
** Figure 3: Dynamics of Employment, Earnings and Wages **
**********************************************************
**********************************************************

*** PART A: Dynamic Figures (left-hand side of Figure 3)

use "${mystart}/Datasets/Spell Dataset Quarterly.dta", clear

** i. Create variables **

**Rename variables for plots
rename totearn_2013Q4 totearn_Q1 
rename totmonths_2013Q4 totmonths_Q1
rename wage_2013Q4 wage_Q1

rename totearn_2014Q1 totearn_Q2
rename totmonths_2014Q1 totmonths_Q2
rename wage_2014Q1 wage_Q2

rename totearn_2014Q2 totearn_Q3
rename totmonths_2014Q2 totmonths_Q3
rename wage_2014Q2 wage_Q3

rename totearn_2014Q3 totearn_Q4
rename totmonths_2014Q3 totmonths_Q4 
rename wage_2014Q3 wage_Q4

rename totearn_2014Q4  totearn_Q5
rename totmonths_2014Q4 totmonths_Q5
rename wage_2014Q4 wage_Q5

rename totearn_2015Q1 totearn_Q6
rename totmonths_2015Q1 totmonths_Q6
rename wage_2015Q1 wage_Q6

rename totearn_2015Q2 totearn_Q7 
rename totmonths_2015Q2 totmonths_Q7
rename wage_2015Q2 wage_Q7

rename totearn_2015Q3 totearn_Q8
rename totmonths_2015Q3 totmonths_Q8
rename wage_2015Q3 wage_Q8

rename totearn_2015Q4 totearn_Q9
rename totmonths_2015Q4 totmonths_Q9
rename wage_2015Q4 wage_Q9

rename totearn_2016Q1 totearn_Q10
rename totmonths_2016Q1 totmonths_Q10
rename wage_2016Q1 wage_Q10

rename totearn_2016Q2 totearn_Q11 
rename totmonths_2016Q2 totmonths_Q11
rename wage_2016Q2 wage_Q11

rename totearn_2016Q3 totearn_Q12
rename totmonths_2016Q3 totmonths_Q12
rename wage_2016Q3 wage_Q12

**Only keep variables with non-missing observations on number of months
keep if totmonths_Q1!=.&totmonths_Q2!=.&totmonths_Q3!=.&totmonths_Q4!=.&totmonths_Q5!=.&totmonths_Q6!=.&totmonths_Q7!=.&totmonths_Q8!=.&totmonths_Q9!=.&totmonths_Q10!=.&totmonths_Q11!=.&totmonths_Q12!=.

**Save temporary file for the second part of the figure
tempfile temp1
save `temp1'

**Reshape dataset at the quarterly dataset and collapse
reshape long totmonths_Q totearn_Q wage_Q, i(idno) j(quarter)
drop if totmonths_Q==.

drop if group_final_2==3
gen tr_group=0 if group_final_2==0
replace tr_group=1 if group_final_2==1 | group_final_2==2
replace tr_group=2 if group_final_2==4

gen const=1
collapse (mean) totmonths_Q totearn_Q wage_Q, by(quarter tr_group)


** ii. Figure **

label def quarter 1 "2013Q4" 2 "2014Q1" 3 "2014Q2" 4 "2014Q3" 5 "2014Q4" 6 "2015Q1" 7 "2015Q2" 8 "2015Q3" 9 "2015Q4" 10 "2016Q1" 11 "2016Q2" 12 "2016Q3"
label val quarter quarter

twoway (scatter totmonths_Q quarter if tr_group==0, xline(3, lpattern("-") lcolor(black)) msymbol(D) msize(medsmall) connect(line) xtitle("") ytitle("Months Worked per Quarter")) (scatter totmonths_Q quarter if tr_group==1, msymbol(T) connect(line) msize(medsmall))  (scatter totmonths_Q quarter if tr_group==2, connect(line) msymbol(O) connect(line)), ylabel(0.2(0.4)1.6) xlabel(1  3  5  7  9 11, valuelabel) graphregion(color(white)) legend(rows(1) lab(1 "Control") lab(2 "VT") lab(3 "FT"))

twoway (scatter totearn_Q quarter if tr_group==0, xline(3, lpattern("-") lcolor(black)) msymbol(D) msize(medsmall) connect(line) xtitle("") ytitle("Total Quarterly Earnings [USD]")) (scatter totearn_Q quarter if tr_group==1, msymbol(T) connect(line) msize(medsmall))  (scatter totearn_Q quarter if tr_group==2, connect(line) msymbol(O) connect(line)), ylabel(10(20)120) xlabel(1  3  5  7  9 11, valuelabel) graphregion(color(white)) legend(rows(1) lab(1 "Control") lab(2 "VT") lab(3 "FT"))

twoway (scatter wage_Q quarter if tr_group==0&quarter>=3, xline(3, lpattern("-") lcolor(black)) msymbol(D) msize(medsmall) connect(line) xtitle("") ytitle("Mean Hourly Wage in Wage Emp. in Quarter [USD]")) (scatter wage_Q quarter if tr_group==1&quarter>=3, msymbol(T) connect(line) msize(medsmall))  (scatter wage_Q quarter if tr_group==2&quarter>=3, connect(line) msymbol(O) connect(line)), ylabel(0(0.1)0.3) xlabel(1  3  5  7  9 11, valuelabel) graphregion(color(white)) legend(rows(1) lab(1 "Control") lab(2 "VT") lab(3 "FT"))


*** PART B: Dynamic ITT effects (right-hand side of Figure 3)

use `temp1', clear

** i. Create variables **

** Merge with main dataset to obtain control variables
gen followup=1
merge 1:1 idno followup using "${mystart}/Datasets/Panel Dataset_noBL.dta", keepusing(round_2 married_bl any_child_bl employed_bl score_high_bl)
drop if _m!=3
drop _m

global X_bl "age_bl married_bl any_child_bl employed_bl score_high_bl"

**Reshape dataset at the quarterly dataset
reshape long totmonths_Q totearn_Q wage_Q, i(idno) j(quarter)

**Create interactions between treatment variables and quarters
gen     treat_temp=0 if group_final_2==0
replace treat_temp=2 if group_final_2==1|group_final_2==2
replace treat_temp=1 if group_final_2==4

tab quarter, gen(q)

** generate interactions with follow-up waves
forval i=1(1)12{
gen treat_temp_`i'=treat_temp*q`i'
}
drop treat_temp

*rename paid_emp_lastmonth_bl emp_month__bl
*rename earnings_lastmonth_bl earn_month__bl

drop if group_final_2==3
*keep if invpr_panel_incl!=.&group_final_2!=.
gen VTsample=group_final_2<4
gen FTsample=group_final_2==0|group_final_2==4

** 1. MONTHS WORKED 
xi:reg totmonths_Q i.treat_temp_1 i.treat_temp_2 i.treat_temp_3 i.treat_temp_4 i.treat_temp_5 i.treat_temp_6 i.treat_temp_7 i.treat_temp_8 i.treat_temp_9 i.treat_temp_10 i.treat_temp_11 i.treat_temp_12 i.quarter i.strata ${X_bl} round_2 , robust
estimates store totmonths_Q
label var _Itreat_tem_1 "2013Q4"
label var _Itreat_tem_2 "2013Q4"
label var _Itreat_tema1 " "
label var _Itreat_tema2 " "
label var _Itreat_temb1 " "
label var _Itreat_temb2 " "
label var _Itreat_temc1 " "
label var _Itreat_temc2 " "
label var _Itreat_temd1 "2014Q4"
label var _Itreat_temd2 "2014Q4"
label var _Itreat_teme1 " "
label var _Itreat_teme2 " "
label var _Itreat_temf1 " "
label var _Itreat_temf2 " "
label var _Itreat_temg1 " "
label var _Itreat_temg2 " "
label var _Itreat_temh1 "2015Q4"
label var _Itreat_temh2 "2015Q4"
label var _Itreat_temi1 " "
label var _Itreat_temi2 " "
label var _Itreat_temj1 " "
label var _Itreat_temj2 " "
label var _Itreat_temk1 "2016Q3"
label var _Itreat_temk2 "2016Q3"
*Firm Trained
coefplot (totmonths_Q), keep( _Itreat_tem_1 _Itreat_tema1 _Itreat_temb1 _Itreat_temc1 _Itreat_temd1 _Itreat_teme1 _Itreat_temf1 _Itreat_temg1 _Itreat_temh1 _Itreat_temi1 _Itreat_temj1 _Itreat_temk1 ) mcolor(dkgreen) lcolor(dkgreen) ylabel(-0.4(0.2)0.6) yline(0, lpattern(dash) lcolor(black)) ytitle("ITT Effect") xtitle("Quarter") title("Firm Trained") xlabel(1 "2013Q4" 5 "2014Q4" 9 "2015Q4" 12 "2016Q3") graphregion(color(white)) legend(off) vertical recast(connected) name(monthsFT)
*Vocationally Trained
coefplot (totmonths_Q), keep( _Itreat_tem_2 _Itreat_tema2 _Itreat_temb2 _Itreat_temc2 _Itreat_temd2 _Itreat_teme2 _Itreat_temf2 _Itreat_temg2 _Itreat_temh2 _Itreat_temi2 _Itreat_temj2 _Itreat_temk2 ) mcolor(maroon) lcolor(maroon) ylabel(-0.4(0.2)0.6) yline(0, lpattern(dash) lcolor(black)) ytitle("ITT Effect") xtitle("Quarter") title("Vocationally Trained") xlabel(1 "2013Q4" 5 "2014Q4" 9 "2015Q4" 12 "2016Q3") graphregion(color(white)) legend(off) vertical recast(connected) name(monthsVT)
*Combine graphs
graph combine monthsFT monthsVT, graphregion(color(white))


** 2. TOTAL EARNINGS
xi:reg totearn_Q i.treat_temp_1 i.treat_temp_2 i.treat_temp_3 i.treat_temp_4 i.treat_temp_5 i.treat_temp_6 i.treat_temp_7 i.treat_temp_8 i.treat_temp_9 i.treat_temp_10 i.treat_temp_11 i.treat_temp_12 i.quarter i.strata ${X_bl} round_2 , robust
estimates store totearn_Q
label var _Itreat_tem_1 "2013Q4"
label var _Itreat_tem_2 "2013Q4"
label var _Itreat_tema1 " "
label var _Itreat_tema2 " "
label var _Itreat_temb1 " "
label var _Itreat_temb2 " "
label var _Itreat_temc1 " "
label var _Itreat_temc2 " "
label var _Itreat_temd1 "2014Q4"
label var _Itreat_temd2 "2014Q4"
label var _Itreat_teme1 " "
label var _Itreat_teme2 " "
label var _Itreat_temf1 " "
label var _Itreat_temf2 " "
label var _Itreat_temg1 " "
label var _Itreat_temg2 " "
label var _Itreat_temh1 "2015Q4"
label var _Itreat_temh2 "2015Q4"
label var _Itreat_temi1 " "
label var _Itreat_temi2 " "
label var _Itreat_temj1 " "
label var _Itreat_temj2 " "
label var _Itreat_temk1 "2016Q3"
label var _Itreat_temk2 "2016Q3"
*Firm Trained
coefplot (totearn_Q), keep( _Itreat_tem_1 _Itreat_tema1 _Itreat_temb1 _Itreat_temc1 _Itreat_temd1 _Itreat_teme1 _Itreat_temf1 _Itreat_temg1 _Itreat_temh1 _Itreat_temi1 _Itreat_temj1 _Itreat_temk1 ) mcolor(dkgreen) lcolor(dkgreen) yline(0, lpattern(dash) lcolor(black)) ylabel(-30(15)65) ytitle("ITT Effect") xtitle("Quarter") title("Firm Trained") xlabel(1 "2013Q4" 5 "2014Q4" 9 "2015Q4" 12 "2016Q3") graphregion(color(white)) legend(off) vertical recast(connected) name(earningsFT)
*Vocationally Trained
coefplot (totearn_Q), keep( _Itreat_tem_2 _Itreat_tema2 _Itreat_temb2 _Itreat_temc2 _Itreat_temd2 _Itreat_teme2 _Itreat_temf2 _Itreat_temg2 _Itreat_temh2 _Itreat_temi2 _Itreat_temj2 _Itreat_temk2 ) mcolor(maroon) lcolor(maroon) yline(0, lpattern(dash) lcolor(black)) ylabel(-30(15)65) ytitle("ITT Effect") xtitle("Quarter") title("Vocationally Trained") xlabel(1 "2013Q4" 5 "2014Q4" 9 "2015Q4" 12 "2016Q3") graphregion(color(white)) legend(off) vertical recast(connected) name(earningsVT)
*Combine graphs
graph combine earningsFT earningsVT, graphregion(color(white))


** 3. WAGES
xi:reg wage_Q  i.treat_temp_1 i.treat_temp_2 i.treat_temp_3 i.treat_temp_4 i.treat_temp_5 i.treat_temp_6 i.treat_temp_7 i.treat_temp_8 i.treat_temp_9 i.treat_temp_10 i.treat_temp_11 i.treat_temp_12 i.quarter i.strata ${X_bl} round_2 , robust
estimates store wage_Q
label var _Itreat_tem_1 "2013Q4"
label var _Itreat_tem_2 "2013Q4"
label var _Itreat_tema1 " "
label var _Itreat_tema2 " "
label var _Itreat_temb1 " "
label var _Itreat_temb2 " "
label var _Itreat_temc1 " "
label var _Itreat_temc2 " "
label var _Itreat_temd1 "2014Q4"
label var _Itreat_temd2 "2014Q4"
label var _Itreat_teme1 " "
label var _Itreat_teme2 " "
label var _Itreat_temf1 " "
label var _Itreat_temf2 " "
label var _Itreat_temg1 " "
label var _Itreat_temg2 " "
label var _Itreat_temh1 "2015Q4"
label var _Itreat_temh2 "2015Q4"
label var _Itreat_temi1 " "
label var _Itreat_temi2 " "
label var _Itreat_temj1 " "
label var _Itreat_temj2 " "
label var _Itreat_temk1 "2016Q3"
label var _Itreat_temk2 "2016Q3"
*Firm Trained
coefplot (wage_Q), keep(  _Itreat_temb1 _Itreat_temc1 _Itreat_temd1 _Itreat_teme1 _Itreat_temf1 _Itreat_temg1 _Itreat_temh1 _Itreat_temi1 _Itreat_temj1 _Itreat_temk1 ) mcolor(dkgreen) lcolor(dkgreen)  yline(0, lpattern(dash) lcolor(black)) ylabel(-0.06(0.03)0.12) ytitle("ITT Effect") xtitle("Quarter") title("Firm Trained") xlabel(1 "2014Q2" 5 "2015Q2" 9 "2016Q2" ) graphregion(color(white)) legend(off) vertical recast(connected) name(wagesFT)
*Vocationally Trained
coefplot (wage_Q), keep(  _Itreat_temb2 _Itreat_temc2 _Itreat_temd2 _Itreat_teme2 _Itreat_temf2 _Itreat_temg2 _Itreat_temh2 _Itreat_temi2 _Itreat_temj2 _Itreat_temk2 ) mcolor(maroon) lcolor(maroon) yline(0, lpattern(dash) lcolor(black)) ylabel(-0.06(0.03)0.12) ytitle("ITT Effect") xtitle("Quarter") title("Vocationally Trained") xlabel(1 "2014Q2" 5 "2015Q2" 9 "2016Q2") graphregion(color(white)) legend(off) vertical  recast(connected) name(wagesVT)
*Combine Graphs
graph combine wagesFT wagesVT, graphregion(color(white))

