********************************************************************
********************************************************************
** Figure A1a: Wage Distribution of Unskilled Workers at Baseline **
**         Figure A1b: Worker-Firm Wage Subsidy Splits            **
********************************************************************
********************************************************************

** Figure A1a: Wage Distribution of Unskilled Workers at Baseline **

use "${mystart}/Datasets/Firm Census.dta", clear

** i. Create variables

local i=1
while `i'<=20 {
rename emp_income_`i'_0_skilled emp_income_skilled_`i'
rename emp_income_`i'_0_unskilled emp_income_unskilled_`i'
rename emp_income_`i'_0 emp_income_`i'
local i=`i'+1
}
*

reshape long emp_ emp_pay_ emp_inkind_month_ emp_income_ emp_income_skilled_ emp_income_unskilled_ emp_position_skilled_ emp_position_unskilled_, i(bid) j(emp_num)
keep if emp_==1

count
*6,292 employees

gen emp_inkind_month_skilled=emp_inkind_month_ if emp_position_skilled==1
gen emp_inkind_month_unskilled=emp_inkind_month_ if emp_position_unskilled==1

*exclude outliers (top 5% of in-kind payments and top 1% of earnings)

*all
_pctile emp_inkind_month_, p(95)
replace emp_inkind_month_=. if emp_inkind_month_>=`r(r1)'
_pctile emp_income_, p(99)
replace emp_income_=. if emp_income_>=`r(r1)'

*skilled
_pctile emp_inkind_month_skilled, p(95)
replace emp_inkind_month_skilled=. if emp_inkind_month_skilled>=`r(r1)'
_pctile emp_income_skilled, p(99)
replace emp_income_skilled=. if emp_income_skilled>=`r(r1)'

*unskilled
_pctile emp_inkind_month_unskilled, p(95)
replace emp_inkind_month_unskilled=. if emp_inkind_month_unskilled>=`r(r1)'
_pctile emp_income_unskilled, p(99)
replace emp_income_unskilled=. if emp_income_unskilled>=`r(r1)'


gen tot_emp_income_=emp_inkind_month_+emp_income_ if emp_inkind_month_!=.&emp_income_!=.
format tot_emp_income_ %9.0gc

gen tot_emp_income_skilled=emp_inkind_month_skilled+emp_income_skilled if emp_inkind_month_skilled!=.&emp_income_skilled!=.
format tot_emp_income_skilled %9.0gc

gen tot_emp_income_unskilled=emp_inkind_month_unskilled+emp_income_unskilled if emp_inkind_month_unskilled!=.&emp_income_unskilled!=.
format tot_emp_income_unskilled %9.0gc

gen     tot_emp_income_unskilled_def=(tot_emp_income_unskilled)/2384.87           if month_interview==2
replace tot_emp_income_unskilled_def=(tot_emp_income_unskilled*236.9/237)/2384.87 if month_interview==3
replace tot_emp_income_unskilled_def=(tot_emp_income_unskilled*236.9/237)/2384.87 if month_interview==4
replace tot_emp_income_unskilled_def=(tot_emp_income_unskilled*236.9/((236.9+237+237)/3))/2384.87 if month_interview==.

sum tot_emp_income_unskilled_def, d

** ii. Graph **

hist tot_emp_income_unskilled_def, kdensity percent addplot(pci 0 50.30 25 50.30, lcolor(red)||pci 0 29.34 25 29.34, lcolor(black) lpattern(dash)||pci 0 45.32 25 45.32, lcolor(navy) lpattern(dash)) ytitle(Percentage) legend(off) xtitle(Unskilled employee monthly wage [USD]) xlabel(0(50)400) graphregion(color(white))


** Figure A1b: Worker-Firm Wage Subsidy Splits **

** i. Create variables

** Firm First Follow-up data

use "${mystart}/Datasets/Firm First Follow-up.dta", clear

keep bid s3162b_0 s3162b_1

reshape long s3162b_, i(bid) j(worker_n)
count
*4,612 obs

foreach var of varlist s3162b_ {
gen `var'def = (`var'/2384.87)  if `var'!=.
}

rename s3162b_def shareTA5_def

gen cons=1
collapse (sum) cons, by(shareTA5_def)

drop if shareTA5_def==.
egen tot=sum(cons)
gen shareTA5_firms=cons/tot

tempfile temp1
save `temp1'


** Worker First Follow-up data

use "${mystart}/Datasets/Panel Dataset.dta", clear

keep if followup==1
keep idno mainlast_e_subs_res_f_0 mainlast_e_subs_res_f_1

reshape long mainlast_e_subs_res_f_, i(idno) j(spell_n)
count
*3,428 obs

foreach var of varlist mainlast_e_subs_res_f_ {
gen `var'def = (`var'/2384.87)  if `var'!=.
}

rename mainlast_e_subs_res_f_def shareTA5_def

gen cons=1
collapse (sum) cons, by(shareTA5_def)

drop if shareTA5_def==.
egen tot=sum(cons)
gen shareTA5_workers=cons/tot


** Merge datasets and plot graphs

merge 1:1 shareTA5_def using `temp1'
drop _m cons tot

sort shareTA5_def
replace shareTA5_def=round(shareTA5_def)

*generate new categories
local i=9
while `i'<=58 {
set obs `i'
replace shareTA5_def=`i'-8 in `i'
local i=`i'+1
}
*

sort shareTA5_def
duplicates tag shareTA5_def, gen(dup)
drop if dup==1 & shareTA5_workers==. & shareTA5_firms==.
drop dup

*keep categories to be plotted
keep if shareTA5_def==0 | shareTA5_def==4 | shareTA5_def==8 | shareTA5_def==13 | shareTA5_def==17 | shareTA5_def==21 | shareTA5_def==25 | shareTA5_def==29 | shareTA5_def==34 | shareTA5_def==38 | shareTA5_def==42 | shareTA5_def==46 | shareTA5_def==50

foreach var of varlist shareTA5_workers shareTA5_firms {
replace `var'=0 if `var'==.
replace `var'=`var'*100
} 


** ii. Graph **

graph bar shareTA5_workers shareTA5_firms, over(shareTA5_def) legend(off) ytitle("% of respondents", size(medium)) title(Reported Wage Subsidy [USD], position(6) size(medium)) graphregion(color(white))


