**********************************************
**********************************************
** Figure A3: Change in Worker Productivity **
** Between Recruitment and First Follow-up  **
**********************************************
**********************************************

use "${mystart}/Datasets/Firm First Follow-up Employee.dta", clear

** i. Create variables **

* Change in workers' poductivity between recruitment and first follow-up
gen prod_change=prod_fup_-prod_recr_

* Learnt sector-specific task
gen task_learnt=task_able_fup_-task_able_recr_
recode task_learnt(-1=.)

* Leant firm-specific task
foreach var of varlist othertask_able_recr_ othertask_able_fup_ {
replace `var'=0 if othertask_id_==0
}

gen othertask_learnt=othertask_able_fup_-othertask_able_recr_
recode othertask_learnt(-1=.)


*** PANEL A: Change in Worker Productivity
* FT Employees worker_n: 22, 23
* new hires worker_n: >=26

* A3Aa) FT Firms - Hired through Intervention
ci mean prod_change if (worker_n==22 | worker_n==23) & (tenure_==4 | tenure_==5 | tenure_==6)

* A3Ab) Control Firms
ci mean prod_change if worker_n>=26 & (tenure_==4 | tenure_==5 | tenure_==6) & treatment==1

* A3Ac) Control Firms - Trained OTJ
ci mean prod_change if worker_n>=26 & (tenure_==4 | tenure_==5 | tenure_==6) & training==1 & treatment==1

* A3Ad) Control Firms - Not Trained OTJ
ci mean prod_change if worker_n>=26 & (tenure_==4 | tenure_==5 | tenure_==6) & training==0 & treatment==1

* A3Ae) FT Firms - Not hired through Intervention
ci mean prod_change if worker_n>=26 & (tenure_==4 | tenure_==5 | tenure_==6) & treatment==4 


*** PANEL B: Change in FT Workers' Ability to Perform Tasks

** Reported by Firms

* A3Ba) Learnt to perform sector-specific task
ci mean task_learnt if (worker_n==22 | worker_n==23) & (tenure_==4 | tenure_==5 | tenure_==6)

* A3Bb) Learnt to perform firm-specific task
ci mean othertask_learnt if (worker_n==22 | worker_n==23) & (tenure_==4 | tenure_==5 | tenure_==6)


** Reported by Workers

use "${mystart}/Datasets/Panel Dataset.dta", clear

keep if followup==1

* Learnt sector-specific task
gen task_learnt=first_job_task_able_now-first_job_task_able
recode task_learnt(-1=.)

* Learnt firm-specific task
replace first_job_othtask_able=0 if first_job_othtask_any==0
replace first_job_othtask_able_now=0 if first_job_othtask_any==0

gen othertask_learnt=first_job_othtask_able_now-first_job_othtask_able
recode othertask_learnt(-1=.)

* Compliance
gen complier_all=(t2_training_attended==1|t3_training_attended==1|t5_accepted==1) if t2_training_attended!=.| t3_training_attended!=.|t5_accepted!=.
gen complier_all_FT=(complier_all==1&group_final_2==4)

* A3Bc) Learnt to perform sector-specific task
ci mean task_learnt if group_final_2==4 & complier_all_FT==1

* A3Bd) Learnt to perform firm-specific task
ci mean othertask_learnt if group_final_2==4 & complier_all_FT==1

