*************************************************
*************************************************
** Table 2: ATE Estimates, Training and Skills **
*************************************************
*************************************************

use "${mystart}/Datasets/Panel Dataset_noBL.dta", clear

** i. Create variables **

** Received on-the-job training in first job
tab first_job_train
tab first_job_train_length first_job_train, m
*26 people say they got training but then report 0 months of training
*take conservative approach: recode them as having received no training
replace first_job_train=0 if first_job_train_length==0

** Position is "Trainee" in first job
tab first_job_pos
gen first_job_pos_d=(first_job_pos==3) if first_job_pos!=.

** Identify workers that said know nothing in sector-specific skills test
rename q8_0 skills_test_sector
gen noskills=(skills_test_sector==99) if skills_test_sector!=.
recode noskills (1=0) (0=1), gen(anyskills)
replace anyskills=. if score_all==.

** Recode skills transferability index so that a positive coefficient means more transferable skills
tab index_new_tool_skills
sum index_new_tool_skills if group_final_2==0
replace index_new_tool_skills=index_new_tool_skills*(-1)


**  Define globals for control variables

global X_bl "age_bl married_bl any_child_bl employed_bl score_high_bl"


** ii. Table **

* 2a)Received On the Job Training
* 2b)Position is "Trainee"

**set sample for regressions
foreach var of varlist first_job_train first_job_pos_d {
qui xi:reg `var' ib0.group_final_2_pooled i.round_2 i.strata i.idate_mm i.followup ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
gen s_`var'=e(sample)
}
*

gen complier_all=(t2_training_attended==1|t3_training_attended==1|t5_accepted==1) if t2_training_attended!=.| t3_training_attended!=.|t5_accepted!=.
gen complier_all_VT=(complier_all==1&(group_final_2==1|group_final_2==2))
gen complier_all_FT=(complier_all==1&group_final_2==4)

gen VT=(group_final_2==1|group_final_2==2)
gen FT=(group_final_2==4)

keep if group_final_2_pooled!=.&invpr_panel_incl!=.

gen VTsample=group_final_2_pooled<4
gen FTsample=group_final_2_pooled==0|group_final_2_pooled==4


local lhs "first_job_train first_job_pos_d"

foreach var of local lhs {
	*1st stages by treatment
	quietly reg complier_all_VT  i.VT   i.round_2 i.strata i.idate_mm i.followup ${X_bl} if VTsa==1, robust
	predict VTHat`var'A, xb
	quietly reg complier_all_FT  i.FT   i.round_2 i.strata i.idate_mm i.followup ${X_bl} if FTsa==1, robust
	predict FTHat`var'A, xb

	for var VTH* :replace X=0 if VT==0
	for var FTH* :replace X=0 if FT==0
	
	/*
	*ITT 
	reg `var' FT VT i.round_2 i.strata i.idate_mm i.followup ${X_bl} [pweight=invpr_panel_incl], robust 
	test FT=VT
	sum `var' if FT==0&VT==0&e(sample)==1
	*/
	
	*ATE
	bootstrap , reps(1000) seed(435) strata(strata) nodots: reg `var' FTHat`var'A   VTHat`var'A i.round_2 i.strata i.idate_mm i.followup ${X_bl} 
	test FTHat`var'A  = VTHat`var'A
	
}
*

* 2a)Received On the Job Training
* 2b)Position is "Trainee"

**set sample for regressions
foreach var of varlist anyskills score_all {
qui xi:reg `var' sfup tfup ib0.group_final_2_pooled i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
gen s_`var'=e(sample)
} 
 
local lhs "anyskills score_all"

foreach var of local lhs {
	*1st stages by treatment
	quietly reg complier_all_VT  i.VT sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl} if VTsa==1, robust
	predict VTHat`var'A, xb
	quietly reg complier_all_FT  i.FT sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl} if FTsa==1, robust
	predict FTHat`var'A, xb

	for var VTH* :replace X=0 if VT==0
	for var FTH* :replace X=0 if FT==0
	
	/*
	*ITT 
	reg `var' FT VT  tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
	test FT=VT
	sum `var' if FT==0&VT==0&e(sample)==1
	*/
	
	*ATE
	bootstrap , reps(1000) seed(435) strata(strata) nodots: reg `var' FTHat`var'A   VTHat`var'A sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
	test FTHat`var'A  = VTHat`var'A
	
}
*

* 2c)Skills transferability

**set sample for regressions
foreach var of varlist index_new_tool_skills {
qui xi:reg `var' ib0.group_final_2_pooled  i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
gen s_`var'=e(sample)
}
*

local lhs "index_new_tool_skills"

foreach var of local lhs {
	*1st stages by treatment
	quietly reg complier_all_VT  i.VT   i.round_2 i.strata i.idate_mm ${X_bl} if VTsa==1&followup==3, robust
	predict VTHat`var'A, xb
	quietly reg complier_all_FT  i.FT   i.round_2 i.strata i.idate_mm ${X_bl} if FTsa==1&followup==3, robust
	predict FTHat`var'A, xb

	for var VTH* :replace X=0 if VT==0
	for var FTH* :replace X=0 if FT==0
	
	/*
	*ITT 
	reg `var' FT VT  i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&followup==3, robust
	test FT=VT
	sum `var' if FT==0&VT==0&e(sample)==1
	*/
	
	*ATE
	bootstrap , reps(1000) seed(435) strata(strata) nodots: reg `var' FTHat`var'A   VTHat`var'A  i.round_2 i.strata i.idate_mm ${X_bl} if followup==3, robust
	test FTHat`var'A  = VTHat`var'A
	
}
*

*** SAVE INFORMATION FOR ROMANO WOLF PVALUE CORRECTION ***

* Save Baseline coefficients

foreach var of varlist first_job_train first_job_pos_d anyskills score_all index_new_tool_skills {
reg `var' FTHat`var'A   VTHat`var'A sfup tfup i.round_2 i.idate_mm i.strata ${X_bl}, robust
	matrix coeff=e(b)
	matrix varcov      = e(V)
	
	scalar b_vt_`var'=coeff[1,2]
	scalar b_ft_`var'  = coeff[1,1]

	scalar s_vt_`var'=sqrt(varcov[2,2])
	scalar s_ft_`var'  = sqrt(varcov[1,1])

	scalar t_vt_`var'=abs(b_vt_`var'/s_vt_`var')
	scalar t_ft_`var'  = abs(b_ft_`var'/s_ft_`var')

	}
*

tempfile temp1
save "`temp1'"

* Export vector of test statistics (t) - already exported as Sx1 so should not transpose

	matrix t=(t_vt_first_job_train \ t_ft_first_job_train \ t_vt_first_job_pos_d \ t_ft_first_job_pos_d \ t_vt_anyskills \ t_ft_anyskills \ t_vt_score_all \ t_ft_score_all 	         \ t_vt_index_new_tool_skills \ t_ft_index_new_tool_skills)
	putexcel set "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_SKILLS_t.xls", replace
	putexcel A1=matrix(t)

	import excel using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_SKILLS_t.xls", clear
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_SKILLS_t.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_SKILLS_t", replace wide

	
* Bootstrapping

use "`temp1'", clear

char group_final_2_pooled[omit] 0

	*1. Preparation for *bootstrap: define program to run all regressions within *bootstrap --> bb_`y'_`x' (boostrapped beta)
	
	capture program drop regset_oa
	program define regset_oa, eclass
	version 14
		
		tempname ests
		mat `ests'=J(1,10,.)

		reg first_job_train FTHatfirst_job_trainA VTHatfirst_job_trainA sfup tfup i.round_2 i.idate_mm i.strata ${X_bl}, robust
		mat `ests'[1,1]=abs((_b[VTHatfirst_job_trainA]-b_vt_first_job_train)/_se[VTHatfirst_job_trainA])
		mat `ests'[1,2]=abs((_b[FTHatfirst_job_trainA]-b_ft_first_job_train)/_se[FTHatfirst_job_trainA])

		reg first_job_pos_d FTHatfirst_job_pos_dA VTHatfirst_job_pos_dA sfup tfup i.round_2 i.idate_mm i.strata ${X_bl}, robust
		mat `ests'[1,3]=abs((_b[VTHatfirst_job_pos_dA]-b_vt_first_job_pos_d)/_se[VTHatfirst_job_pos_dA])
		mat `ests'[1,4]=abs((_b[FTHatfirst_job_pos_dA]-b_ft_first_job_pos_d)/_se[FTHatfirst_job_pos_dA])

		reg anyskills FTHatanyskillsA VTHatanyskillsA sfup tfup i.round_2 i.idate_mm i.strata ${X_bl}, robust
		mat `ests'[1,5]=abs((_b[VTHatanyskillsA]-b_vt_anyskills)/_se[VTHatanyskillsA])
		mat `ests'[1,6]=abs((_b[FTHatanyskillsA]-b_ft_anyskills)/_se[FTHatanyskillsA])

		reg score_all FTHatscore_allA VTHatscore_allA sfup tfup i.round_2 i.idate_mm i.strata ${X_bl}, robust
		mat `ests'[1,7]=abs((_b[VTHatscore_allA]-b_vt_score_all)/_se[VTHatscore_allA])
		mat `ests'[1,8]=abs((_b[FTHatscore_allA]-b_ft_score_all)/_se[FTHatscore_allA])

		reg index_new_tool_skills FTHatindex_new_tool_skillsA   VTHatindex_new_tool_skillsA sfup tfup i.round_2 i.idate_mm i.strata ${X_bl}, robust
		mat `ests'[1,9]=abs((_b[VTHatindex_new_tool_skillsA]-b_vt_index_new_tool_skills)/_se[VTHatindex_new_tool_skillsA])
		mat `ests'[1,10]=abs((_b[FTHatindex_new_tool_skillsA]-b_ft_index_new_tool_skills)/_se[FTHatindex_new_tool_skillsA])

	ereturn post `ests'
	end

	bootstrap _b, reps(1000) seed(1959) saving(RWboot_estim,replace): regset_oa

    *2. Export matrix of null resampling statistics (tNull) - already exported as MxS so should not transpose

	use RWboot_estim, clear
	keep _b_c1-_b_c10
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_SKILLS.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_SKILLS", replace wide
