***************************************************
***************************************************
** Table 3: ITT Estimates, Labor Market Outcomes **
** Table 4: ATE Estimates, Labor Market Outcomes **
***************************************************
***************************************************

use "${mystart}/Datasets/Panel Dataset_noBL.dta", clear

** i. Create variables **

** Worked in sector of training/matching in the last month
gen worked_lastmonth_vtimatch=(worked_lastmonth_match==1) if worked_lastmonth_match!=. & group_final_2==4
replace worked_lastmonth_vtimatch=(worked_lastmonth_vti==1) if worked_lastmonth_vti!=.&(group_final_2==1|group_final_2==2)
replace worked_lastmonth_vtimatch=(worked_lastmonth_pref==1 | worked_lastmonth_pref2==1) if (worked_lastmonth_pref!=.|worked_lastmonth_pref2!=.)&group_final_2==0

gen worked_lastmonth_vtimatch_bl=(worked_lastmonth_match_bl==1) if worked_lastmonth_match_bl!=. & group_final_2==4
replace worked_lastmonth_vtimatch_bl=(worked_lastmonth_vti_bl==1) if worked_lastmonth_vti_bl!=.&(group_final_2==1|group_final_2==2)
replace worked_lastmonth_vtimatch_bl=(worked_lastmonth_pref_bl==1 | worked_lastmonth_pref2_bl==1) if (worked_lastmonth_pref!=.|worked_lastmonth_pref2!=.)&group_final_2==0

** Hours worked last week in both wage and self-employment
rename hours_worked_lastweek_self hours_worked_lastweek_s
rename hours_worked_lastweek_self_bl hours_worked_lastweek_s_bl

replace hours_worked_lastweek=hours_worked_lastweek_s+hours_worked_lastweek
replace hours_worked_lastweek_bl=hours_worked_lastweek_s_bl+hours_worked_lastweek_bl

** Labor Market Index at Follow-up

	** step 1: demean outcomes and divide by SD in the control group

	foreach var of varlist paid_emp_lastmonth months_worked_lastyear hours_worked_lastweek earnings_lastmonth_def {
	gen `var'_z=.

	local i=1
	while `i'<=3 {
	sum `var' if followup==`i'
	local `var'_m=r(mean)
	sum `var' if group_final_2==0 & followup==`i'
	local `var'_sd=r(sd)
	replace `var'_z=((`var'-``var'_m')/``var'_sd') if followup==`i'
	local i=`i'+1
	}

	}

	gen var1=paid_emp_lastmonth_z
	gen var2=months_worked_lastyear_z
	gen var3=hours_worked_lastweek_z
	gen var4=earnings_lastmonth_def_z

	** step 2: calculate the var-cov matrix of the transformed outcomes and export the weight matrix 

	corr var1 var2 var3 var4, covariance

	matrix list r(C)
	matrix varcov = r(C)

	* Generate matrix for the number of observations

	count
	matrix n = [r(N)]

	* Generate a matrix for the number of variables in the index

	matrix m = [4]


	mata:

	N = st_matrix("n")
	M = st_matrix("m")
	V = st_matrix("varcov")

	M
	N
	V

	V_inv=invsym(V)
	V_inv

	ones = J(M,1,1)
	ones

	W=V_inv * ones
	W


	weight_var=J(N,M,1)
	for (i=1; i<=M; i++) {
		weight_var[|1,i \ N,i|]=W[i,1]*weight_var[|1,i \ N,i|]
	}

	st_matrix("weight",weight_var)

	end

	matrix list weight
	matrix colnames weight = w1 w2 w3 w4 

	svmat weight, names(col)


	** step 3: compute the index

	* Rescale weights to adjust for missing values

	local j=1
	while `j'<=4 {
	replace w`j'=. if var`j'==.
	local j=`j'+1
	}

	egen tot_w=rowtotal(w1 w2 w3 w4), missing

	local j=1
	while `j'<=4 {
	gen w`j'_res=w`j'/tot_w 
	local j=`j'+1
	}

	* Generate weighted variables

	local i=1
	while `i'<=4 {
	gen var`i'_w=var`i'*w`i'_res
	local i=`i'+1
	}

	* Generate final index

	egen index_z=rowtotal(var1_w var2_w var3_w var4_w), missing

	local i=1
	while `i'<=3 {
	sum index_z if group_final_2==0 & followup==`i'
	local index_z_m=r(mean)
	local index_z_sd=r(sd)
	replace index_z=((index_z-`index_z_m')/`index_z_sd') if followup==`i'
	local i=`i'+1
	}

	sum index_z

	drop var1 - var4_w


** Labor Market Index at Baseline 
* It excludes months worked in the last year as it is not measures at baseline

	** step 1: demean outcomes and divide by SD in the control group

	foreach var of varlist paid_emp_lastmonth_bl hours_worked_lastweek_bl earnings_lastmonth_def_bl {
	gen `var'_z=.

	local i=1
	while `i'<=3 {
	sum `var' if followup==`i'
	local `var'_m=r(mean)
	sum `var' if group_final_2==0 & followup==`i'
	local `var'_sd=r(sd)
	replace `var'_z=((`var'-``var'_m')/``var'_sd') if followup==`i'
	local i=`i'+1
	}

	}

	gen var1=paid_emp_lastmonth_bl_z
	gen var2=hours_worked_lastweek_bl_z
	gen var3=earnings_lastmonth_def_bl_z

	** step 2: calculate the var-cov matrix of the transformed outcomes and export the weight matrix 

	corr var1 var2 var3, covariance

	matrix list r(C)
	matrix varcov = r(C)


	* Generate matrix for the number of observations

	count
	matrix n = [r(N)]

	* Generate a matrix for the number of variables in the index

	matrix m = [3]


	mata:

	N = st_matrix("n")
	M = st_matrix("m")
	V = st_matrix("varcov")

	M
	N
	V

	V_inv=invsym(V)
	V_inv

	ones = J(M,1,1)
	ones

	W=V_inv * ones
	W


	weight_var=J(N,M,1)
	for (i=1; i<=M; i++) {
		weight_var[|1,i \ N,i|]=W[i,1]*weight_var[|1,i \ N,i|]
	}

	st_matrix("weight",weight_var)

	end

	matrix list weight
	matrix colnames weight = w1 w2 w3

	svmat weight, names(col)


	** step 3: compute the index

	* Rescale weights to adjust for missing values

	local j=1
	while `j'<=3 {
	replace w`j'=. if var`j'==.
	local j=`j'+1
	}

	egen tot_w=rowtotal(w1 w2 w3), missing

	local j=1
	while `j'<=3 {
	gen w`j'_res=w`j'/tot_w 
	local j=`j'+1
	}

	* Generate weighted variables

	local i=1
	while `i'<=3 {
	gen var`i'_w=var`i'*w`i'_res
	local i=`i'+1
	}

	* Generate final index

	egen index_z_bl=rowtotal(var1_w var2_w var3_w), missing

	local i=1
	while `i'<=3 {
	sum index_z_bl if group_final_2==0 & followup==`i'
	local index_z_bl_m=r(mean)
	local index_z_bl_sd=r(sd)
	replace index_z_bl=((index_z_bl-`index_z_bl_m')/`index_z_bl_sd') if followup==`i'
	local i=`i'+1
	}

	sum index_z_bl

	drop var1 - var3_w


**  Define globals for control variables
	
global X_bl "age_bl married_bl any_child_bl employed_bl score_high_bl"


** ii. Table **

** Tables 3 and 4 **

**set sample for regressions
foreach var of varlist paid_emp_lastmonth earnings_lastmonth_def worked_lastmonth_vtimatch index_z {
qui xi:reg `var' `var'_bl sfup tfup ib0.group_final_2_pooled i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
gen sample_`var'=e(sample)
}
*
foreach var of varlist hours_worked_lastweek {
qui xi:reg `var' `var'_bl tfup ib0.group_final_2_pooled i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&followup>1, robust
gen sample_`var'=e(sample)
}
*
foreach var of varlist months_worked_lastyear {
qui xi:reg `var' sfup tfup ib0.group_final_2_pooled i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
gen sample_`var'=e(sample)
}
*

gen complier_all=(t2_training_attended==1|t3_training_attended==1|t5_accepted==1) if t2_training_attended!=.| t3_training_attended!=.|t5_accepted!=.
gen complier_all_VT=(complier_all==1&(group_final_2==1|group_final_2==2))
gen complier_all_FT=(complier_all==1&group_final_2==4)

gen VT=(group_final_2==1|group_final_2==2)
gen FT=(group_final_2==4)

keep if group_final_2_pooled!=.&invpr_panel_incl!=.

gen VTsample=group_final_2_pooled<4
gen FTsample=group_final_2_pooled==0|group_final_2_pooled==4


* 3a 4a)Any paid work inthe last month
* 3d 4d)Total earnings in the last month [USD]
* 3e 4e)Labor market Index
* 3f 4f)Worked in sector of training/matching in the last month
local lhs "paid_emp_lastmonth earnings_lastmonth_def index_z worked_lastmonth_vtimatch"

foreach var of local lhs {
	*1st stages by treatment
	quietly reg complier_all_VT  i.VT `var'_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl} if VTsa==1, robust
	predict VTHat`var'A, xb
	quietly reg complier_all_FT  i.FT `var'_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl} if FTsa==1, robust
	predict FTHat`var'A, xb

	for var VTH* :replace X=0 if VT==0
	for var FTH* :replace X=0 if FT==0

	*ITT 
	reg `var' FT VT `var'_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
	test FT=VT
	sum `var' if FT==0&VT==0&e(sample)==1

	
	*ATE
	bootstrap , reps(1000) seed(435) strata(strata) nodots: reg `var' FTHat`var'A   VTHat`var'A `var'_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
	test FTHat`var'A  = VTHat`var'A
	
}
*

* 3b 4b)Number of months worked in the last year
local lhs "months_worked_lastyear"

foreach var of local lhs {
	*1st stages by treatment
	quietly reg complier_all_VT  i.VT sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl} if VTsa==1, robust
	predict VTHat`var'A, xb
	quietly reg complier_all_FT  i.FT sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl} if FTsa==1, robust
	predict FTHat`var'A, xb

	for var VTH* :replace X=0 if VT==0
	for var FTH* :replace X=0 if FT==0

	*ITT 
	reg `var' FT VT sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
	test FT=VT
	sum `var' if FT==0&VT==0&e(sample)==1

	
	*ATE
	bootstrap , reps(1000) seed(435) strata(strata) nodots: reg `var' FTHat`var'A   VTHat`var'A sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
	test FTHat`var'A  = VTHat`var'A
	
}
*

* 3c 4c)Hours worked in the last week
local lhs "hours_worked_lastweek"

foreach var of local lhs {
	*1st stages by treatment
	quietly reg complier_all_VT  i.VT `var'_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} if VTsa==1, robust
	predict VTHat`var'A, xb
	quietly reg complier_all_FT  i.FT `var'_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} if FTsa==1, robust
	predict FTHat`var'A, xb

	for var VTH* :replace X=0 if VT==0
	for var FTH* :replace X=0 if FT==0

	*ITT 
	reg `var' FT VT `var'_bl tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&followup>1, robust
	test FT=VT
	sum `var' if FT==0&VT==0&e(sample)==1

	
	*ATE
	bootstrap , reps(1000) seed(435) strata(strata) nodots: reg `var' FTHat`var'A   VTHat`var'A `var'_bl tfup  i.round_2 i.strata i.idate_mm ${X_bl} if followup>1, robust
	test FTHat`var'A  = VTHat`var'A
	
}
*

*** SAVE INFORMATION FOR ROMANO WOLF PVALUE CORRECTION ***

** Table 3: ITT Estimates, Labor Market Outcomes **

* Save Baseline coefficients

foreach var of varlist paid_emp_lastmonth hours_worked_lastweek earnings_lastmonth_def index_z worked_lastmonth_vtimatch {
reg `var' FT VT `var'_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
	matrix coeff=e(b)
	matrix varcov      = e(V)
	
	scalar b_vt_`var'=coeff[1,2]
	scalar b_ft_`var'  = coeff[1,1]

	scalar s_vt_`var'=sqrt(varcov[2,2])
	scalar s_ft_`var'  = sqrt(varcov[1,1])

	scalar t_vt_`var'=abs(b_vt_`var'/s_vt_`var')
	scalar t_ft_`var'  = abs(b_ft_`var'/s_ft_`var')

	}
*
foreach var of varlist months_worked_lastyear {
reg `var' FT VT sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
	matrix coeff=e(b)
	matrix varcov      = e(V)
	
	scalar b_vt_`var'=coeff[1,2]
	scalar b_ft_`var'  = coeff[1,1]

	scalar s_vt_`var'=sqrt(varcov[2,2])
	scalar s_ft_`var'  = sqrt(varcov[1,1])

	scalar t_vt_`var'=abs(b_vt_`var'/s_vt_`var')
	scalar t_ft_`var'  = abs(b_ft_`var'/s_ft_`var')

	}
*
foreach var of varlist hours_worked_lastweek {
reg `var' FT VT `var'_bl tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&followup>1, robust
	matrix coeff=e(b)
	matrix varcov      = e(V)
	
	scalar b_vt_`var'=coeff[1,2]
	scalar b_ft_`var'  = coeff[1,1]

	scalar s_vt_`var'=sqrt(varcov[2,2])
	scalar s_ft_`var'  = sqrt(varcov[1,1])

	scalar t_vt_`var'=abs(b_vt_`var'/s_vt_`var')
	scalar t_ft_`var'  = abs(b_ft_`var'/s_ft_`var')

	}
*

tempfile temp1
save "`temp1'"


** Table 3, Columns 1 to 4 **

* Export vector of test statistics (t) - already exported as Sx1 so should not transpose

	matrix t=(t_vt_paid_emp_lastmonth \ t_ft_paid_emp_lastmonth \ t_vt_months_worked_lastyear \ t_ft_months_worked_lastyear \ ///
	          t_vt_hours_worked_lastweek \ t_ft_hours_worked_lastweek \ t_vt_earnings_lastmonth_def \ t_ft_earnings_lastmonth_def)
	putexcel set "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT1_t.xls", replace
	putexcel A1=matrix(t)

	import excel using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT1_t.xls", clear
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT1_t.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT1_t", replace wide

	
* Bootstrapping

use "`temp1'", clear

char group_final_2_pooled[omit] 0

	*1. preparation for *bootstrap: define program to run all regressions within *bootstrap --> bb_`y'_`x' (boostrapped beta)
	
	capture program drop regset_oa
	program define regset_oa, eclass
	version 14
		
		tempname ests
		mat `ests'=J(1,8,.)

		reg paid_emp_lastmonth FT VT paid_emp_lastmonth_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
		mat `ests'[1,1]=abs((_b[VT]-b_vt_paid_emp_lastmonth)/_se[VT])
		mat `ests'[1,2]=abs((_b[FT]-b_ft_paid_emp_lastmonth)/_se[FT])

		reg months_worked_lastyear FT VT sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
		mat `ests'[1,3]=abs((_b[VT]-b_vt_months_worked_lastyear)/_se[VT])
		mat `ests'[1,4]=abs((_b[FT]-b_ft_months_worked_lastyear)/_se[FT])

		reg hours_worked_lastweek FT VT hours_worked_lastweek_bl tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&followup>1, robust
		mat `ests'[1,5]=abs((_b[VT]-b_vt_hours_worked_lastweek)/_se[VT])
		mat `ests'[1,6]=abs((_b[FT]-b_ft_hours_worked_lastweek)/_se[FT])

		reg earnings_lastmonth_def FT VT earnings_lastmonth_def_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
		mat `ests'[1,7]=abs((_b[VT]-b_vt_earnings_lastmonth_def)/_se[VT])
		mat `ests'[1,8]=abs((_b[FT]-b_ft_earnings_lastmonth_def)/_se[FT])

	ereturn post `ests'
	end

	bootstrap _b, reps(1000) seed(1959) saving(RWboot_estim,replace): regset_oa


	*2. Export matrix of null resampling statistics (tNull) - already exported as MxS so should not transpose

	clear

	use RWboot_estim
	keep _b_c1-_b_c8
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT1.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT1", replace wide


** Table 3, Columns 5 **
	
use "`temp1'", clear

* Export vector of test statistics (t) - already exported as Sx1 so should not transpose

	matrix t=(t_vt_index_z \ t_ft_index_z)
	putexcel set "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT2_t.xls", replace
	putexcel A1=matrix(t)

	import excel using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT2_t.xls", clear
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT2_t.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT2_t", replace wide

	
* Bootstrapping

use "`temp1'", clear

char group_final_2_pooled[omit] 0

	*1. preparation for *bootstrap: define program to run all regressions within *bootstrap --> bb_`y'_`x' (boostrapped beta)
	
	capture program drop regset_oa
	program define regset_oa, eclass
	version 14
		
		tempname ests
		mat `ests'=J(1,2,.)

		reg index_z FT VT index_z_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
		mat `ests'[1,1]=abs((_b[VT]-b_vt_index_z)/_se[VT])
		mat `ests'[1,2]=abs((_b[FT]-b_ft_index_z)/_se[FT])

	ereturn post `ests'
	end

	bootstrap _b, reps(1000) seed(1959) saving(RWboot_estim,replace): regset_oa

	*2. Export matrix of null resampling statistics (tNull) - already exported as MxS so should not transpose

	clear

	use RWboot_estim
	keep _b_c1-_b_c2
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT2.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT2", replace wide


** Table 3, Columns 6 **
	
use "`temp1'", clear

* Export vector of test statistics (t) - already exported as Sx1 so should not transpose

	matrix t=(t_vt_worked_lastmonth_vtimatch \ t_ft_worked_lastmonth_vtimatch)
	putexcel set "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT3_t.xls", replace
	putexcel A1=matrix(t)

	import excel using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT3_t.xls", clear
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT3_t.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT3_t", replace wide

	
* Bootstrapping

use "`temp1'", clear

char group_final_2_pooled[omit] 0

	*1. preparation for *bootstrap: define program to run all regressions within *bootstrap --> bb_`y'_`x' (boostrapped beta)
	
	capture program drop regset_oa
	program define regset_oa, eclass
	version 14
		
		tempname ests
		mat `ests'=J(1,2,.)

		reg worked_lastmonth_vtimatch FT VT worked_lastmonth_vtimatch_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
		mat `ests'[1,1]=abs((_b[VT]-b_vt_worked_lastmonth_vtimatch)/_se[VT])
		mat `ests'[1,2]=abs((_b[FT]-b_ft_worked_lastmonth_vtimatch)/_se[FT])

	ereturn post `ests'
	end

	bootstrap _b, reps(1000) seed(1959) saving(RWboot_estim,replace): regset_oa


	*2. Export matrix of null resampling statistics (tNull) - already exported as MxS so should not transpose

	clear

	use RWboot_estim
	keep _b_c1-_b_c2
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT3.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ITT3", replace wide



** Table 4: ATE Estimates, Labor Market Outcomes **

use "`temp1'", clear

* Save Baseline coefficients

foreach var of varlist paid_emp_lastmonth hours_worked_lastweek earnings_lastmonth_def index_z worked_lastmonth_vtimatch {
reg `var' FTHat`var'A   VTHat`var'A `var'_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
	matrix coeff=e(b)
	matrix varcov      = e(V)
	
	scalar b_vt_`var'=coeff[1,2]
	scalar b_ft_`var'  = coeff[1,1]

	scalar s_vt_`var'=sqrt(varcov[2,2])
	scalar s_ft_`var'  = sqrt(varcov[1,1])

	scalar t_vt_`var'=abs(b_vt_`var'/s_vt_`var')
	scalar t_ft_`var'  = abs(b_ft_`var'/s_ft_`var')

	}
*
foreach var of varlist months_worked_lastyear {
reg `var' FTHat`var'A   VTHat`var'A sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
	matrix coeff=e(b)
	matrix varcov      = e(V)
	
	scalar b_vt_`var'=coeff[1,2]
	scalar b_ft_`var'  = coeff[1,1]

	scalar s_vt_`var'=sqrt(varcov[2,2])
	scalar s_ft_`var'  = sqrt(varcov[1,1])

	scalar t_vt_`var'=abs(b_vt_`var'/s_vt_`var')
	scalar t_ft_`var'  = abs(b_ft_`var'/s_ft_`var')

	}
*
foreach var of varlist hours_worked_lastweek {
reg `var' FTHat`var'A   VTHat`var'A `var'_bl tfup  i.round_2 i.strata i.idate_mm ${X_bl} if followup>1, robust
	matrix coeff=e(b)
	matrix varcov      = e(V)
	
	scalar b_vt_`var'=coeff[1,2]
	scalar b_ft_`var'  = coeff[1,1]

	scalar s_vt_`var'=sqrt(varcov[2,2])
	scalar s_ft_`var'  = sqrt(varcov[1,1])

	scalar t_vt_`var'=abs(b_vt_`var'/s_vt_`var')
	scalar t_ft_`var'  = abs(b_ft_`var'/s_ft_`var')

	}
*

tempfile temp2
save "`temp2'"


** Table 4, Columns 1 to 4 **

* Export vector of test statistics (t) - already exported as Sx1 so should not transpose

	matrix t=(t_vt_paid_emp_lastmonth \ t_ft_paid_emp_lastmonth \ t_vt_months_worked_lastyear \ t_ft_months_worked_lastyear \ ///
	          t_vt_hours_worked_lastweek \ t_ft_hours_worked_lastweek \ t_vt_earnings_lastmonth_def \ t_ft_earnings_lastmonth_def)
	putexcel set "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE1_t.xls", replace
	putexcel A1=matrix(t)

	import excel using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE1_t.xls", clear
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE1_t.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE1_t", replace wide

	
* Bootstrapping

use "`temp2'", clear

char group_final_2_pooled[omit] 0

	*1. preparation for *bootstrap: define program to run all regressions within *bootstrap --> bb_`y'_`x' (boostrapped beta)
	
	capture program drop regset_oa
	program define regset_oa, eclass
	version 14
		
		tempname ests
		mat `ests'=J(1,8,.)

		reg paid_emp_lastmonth FTHatpaid_emp_lastmonthA   VTHatpaid_emp_lastmonthA paid_emp_lastmonth_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
		mat `ests'[1,1]=abs((_b[VTHatpaid_emp_lastmonthA]-b_vt_paid_emp_lastmonth)/_se[VTHatpaid_emp_lastmonthA])
		mat `ests'[1,2]=abs((_b[FTHatpaid_emp_lastmonthA]-b_ft_paid_emp_lastmonth)/_se[FTHatpaid_emp_lastmonthA])

		reg months_worked_lastyear FTHatmonths_worked_lastyearA   VTHatmonths_worked_lastyearA sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
		mat `ests'[1,3]=abs((_b[VTHatmonths_worked_lastyearA]-b_vt_months_worked_lastyear)/_se[VTHatmonths_worked_lastyearA])
		mat `ests'[1,4]=abs((_b[FTHatmonths_worked_lastyearA]-b_ft_months_worked_lastyear)/_se[FTHatmonths_worked_lastyearA])

		reg hours_worked_lastweek FTHathours_worked_lastweekA   VTHathours_worked_lastweekA hours_worked_lastweek_bl tfup  i.round_2 i.strata i.idate_mm ${X_bl} if followup>1, robust
		mat `ests'[1,5]=abs((_b[VTHathours_worked_lastweekA]-b_vt_hours_worked_lastweek)/_se[VTHathours_worked_lastweekA])
		mat `ests'[1,6]=abs((_b[FTHathours_worked_lastweekA]-b_ft_hours_worked_lastweek)/_se[FTHathours_worked_lastweekA])

		reg earnings_lastmonth_def FTHatearnings_lastmonth_defA   VTHatearnings_lastmonth_defA earnings_lastmonth_def_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
		mat `ests'[1,7]=abs((_b[VTHatearnings_lastmonth_defA]-b_vt_earnings_lastmonth_def)/_se[VTHatearnings_lastmonth_defA])
		mat `ests'[1,8]=abs((_b[FTHatearnings_lastmonth_defA]-b_ft_earnings_lastmonth_def)/_se[FTHatearnings_lastmonth_defA])

	ereturn post `ests'
	end

	bootstrap _b, reps(1000) seed(1959) saving(RWboot_estim,replace): regset_oa


	*2. Export matrix of null resampling statistics (tNull) - already exported as MxS so should not transpose

	clear

	use RWboot_estim
	keep _b_c1-_b_c8
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE1.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE1", replace wide



** Table 4, Columns 5 **
	
use "`temp2'", clear

* Export vector of test statistics (t) - already exported as Sx1 so should not transpose

	matrix t=(t_vt_index_z \ t_ft_index_z)
	putexcel set "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE2_t.xls", replace
	putexcel A1=matrix(t)

	import excel using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE2_t.xls", clear
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE2_t.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE2_t", replace wide

	
* Bootstrapping

use "`temp2'", clear

char group_final_2_pooled[omit] 0

	*1. preparation for *bootstrap: define program to run all regressions within *bootstrap --> bb_`y'_`x' (boostrapped beta)
	
	capture program drop regset_oa
	program define regset_oa, eclass
	version 14
		
		tempname ests
		mat `ests'=J(1,2,.)

		reg index_z FTHatindex_zA   VTHatindex_zA index_z_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
		mat `ests'[1,1]=abs((_b[VTHatindex_zA]-b_vt_index_z)/_se[VTHatindex_zA])
		mat `ests'[1,2]=abs((_b[FTHatindex_zA]-b_ft_index_z)/_se[FTHatindex_zA])

	ereturn post `ests'
	end

	bootstrap _b, reps(1000) seed(1959) saving(RWboot_estim,replace): regset_oa


	*2. Export matrix of null resampling statistics (tNull) - already exported as MxS so should not transpose

	clear

	use RWboot_estim
	keep _b_c1-_b_c2
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE2.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE2", replace wide



** Table 4, Columns 6 **
	
use "`temp2'", clear

* Export vector of test statistics (t) - already exported as Sx1 so should not transpose

	matrix t=(t_vt_worked_lastmonth_vtimatch \ t_ft_worked_lastmonth_vtimatch)
	putexcel set "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE3_t.xls", replace
	putexcel A1=matrix(t)

	import excel using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE3_t.xls", clear
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE3_t.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE3_t", replace wide

	
* Bootstrapping

use "`temp2'", clear

char group_final_2_pooled[omit] 0

	*1. preparation for *bootstrap: define program to run all regressions within *bootstrap --> bb_`y'_`x' (boostrapped beta)
	
	capture program drop regset_oa
	program define regset_oa, eclass
	version 14
		
		tempname ests
		mat `ests'=J(1,2,.)

		reg worked_lastmonth_vtimatch FTHatworked_lastmonth_vtimatchA   VTHatworked_lastmonth_vtimatchA worked_lastmonth_vtimatch_bl sfup tfup  i.round_2 i.strata i.idate_mm ${X_bl}, robust
		mat `ests'[1,1]=abs((_b[VTHatworked_lastmonth_vtimatchA]-b_vt_worked_lastmonth_vtimatch)/_se[VTHatworked_lastmonth_vtimatchA])
		mat `ests'[1,2]=abs((_b[FTHatworked_lastmonth_vtimatchA]-b_ft_worked_lastmonth_vtimatch)/_se[FTHatworked_lastmonth_vtimatchA])

	ereturn post `ests'
	end

	bootstrap _b, reps(1000) seed(1959) saving(RWboot_estim,replace): regset_oa


* Export matrix of null resampling statistics (tNull) - already exported as MxS so should not transpose

	clear

	use RWboot_estim
	keep _b_c1-_b_c2
	outsheet using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE3.csv", comma nonames replace
	outfile using "${mystart}\Do-files\Data Analysis Files\Romano Wolf\Datasets\RWboot_LABOR_ATE3", replace wide

