********************************************
********************************************
** Table 5: ITT Estimates, Labor Mobility **
********************************************
********************************************

use "${mystart}/Datasets/Spell Dataset.dta", clear
*  This dataset has less observations than the main dataset because:
*  i. observations with inconsistent data on spells across follow-ups that could not be reconciled in any sensible way have been dropped
* ii. observations with missing earnings for any employment spell have been dropped

** i. Create variables **

** Merge with main dataset to obtain control variables

gen followup=1
merge 1:1 idno followup using "${mystart}/Datasets/Panel Dataset_noBL.dta", keepusing(round_2 married_bl any_child_bl employed_bl score_high_bl)
drop if _m!=3
drop _m

** Drop individuals in the Untrained, Match treatment

codebook group_final_2
drop if group_final_2==3

** Number of transitions

egen u2j=rowmax(u2j_*)
egen j2j=rowmax(j2j_*)
egen j2u=rowmax(j2u_*)

egen u2j_num=rowtotal(u2j_*), missing
egen j2j_num=rowtotal(j2j_*), missing
egen j2u_num=rowtotal(j2u_*), missing

forval i=1(1)9 {
replace spell_duration_`i'=spell_duration_`i'/30
}

** Employment spells

forval i=1(1)9 {
gen spell_emp_`i'=(spell_type_`i'==1|spell_type_`i'==2) if spell_type_1!=.
}

egen num_spell_emp=rowtotal(spell_emp_1 spell_emp_2 spell_emp_3 spell_emp_4 spell_emp_5 spell_emp_6 spell_emp_7 spell_emp_8 spell_emp_9), missing


** Spell duration

forval i=1(1)9 {
gen spell_duration_emp_`i'=spell_duration_`i'
replace spell_duration_emp_`i'=. if spell_emp_`i'!=1
}

egen spell_duration_mean=rowmean(spell_duration_emp_*)
egen spell_duration_sum=rowtotal(spell_duration_emp_*), missing
gen spell_duration_sum_0=spell_duration_sum
replace spell_duration_sum_0=0 if spell_duration_sum_0==.&num_spell_emp==0


** ii. Table **

global X_bl "age_bl married_bl any_child_bl employed_bl score_high_bl"

**set sample for regressions
char tr_group[omit]0 
qui xi:reg spell_emp_1 i.tr_group ${X_bl} i.strata round_2, robust
gen sample=e(sample)

** 5a) Number of non-casual work spells
xi:reg num_spell_emp i.tr_group ${X_bl} i.strata round_2 if sample==1, robust
sum num_spell_emp if e(sample)==1&tr_group==0
test _Itr_group_1=_Itr_group_3

** 5c) Total months of non-casual work
xi:reg spell_duration_sum_0 i.tr_group ${X_bl} i.strata round_2 if sample==1, robust
sum spell_duration_sum_0 if e(sample)==1&tr_group==0
test _Itr_group_1=_Itr_group_3

* 5c) Number of non-casual work spells
xi:reg spell_emp_1 i.tr_group ${X_bl} i.strata round_2 if sample==1, robust
sum spell_emp_1 if e(sample)==1&tr_group==0
test _Itr_group_1=_Itr_group_3

* 5d) Number of UJ transitions
xi:reg u2j_num i.tr_group ${X_bl} i.strata round_2 if sample==1&spell_emp_1==0, robust
sum u2j_num if e(sample)==1&tr_group==0
test _Itr_group_1=_Itr_group_3

* 5e) Number of JJ transitions
xi:reg j2j_num i.tr_group ${X_bl} i.strata round_2 if sample==1&spell_emp_1==1, robust
sum j2j_num if e(sample)==1&tr_group==0
test _Itr_group_1=_Itr_group_3

* 5f) Number of JU transitions
xi:reg j2u_num i.tr_group ${X_bl} i.strata round_2 if sample==1&spell_emp_1==1, robust
sum j2u_num if e(sample)==1&tr_group==0
test _Itr_group_1=_Itr_group_3
