*************************************************
*************************************************
** Table 7: Employment and Other Firm Outcomes **
*************************************************
*************************************************

use  "${mystart}/Datasets/Firm Panel Dataset.dta", clear

** i. Create variables **
** ii. Table **

**set sample for regressions

global X_firm_bl "tot_emp_bl owner_sex_2 bus_years_est bus_years_sq owner_edu_years"

foreach var of varlist tot_emp_ l_bus_profit_av_def_ {
qui xi:reg `var' `var'bl sfup tfup fofup FT ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_, vce(cluster branch_trade)
gen s_`var'_all=e(sample)
}
*
foreach var of varlist n_new_emp n_left_emp {
qui xi:reg `var'  sfup tfup fofup FT ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_, vce(cluster branch_trade)
gen s_`var'_all=e(sample)
}
*

*** PANEL A: ITT Estimates ***

*** SHORT TERM

* 7a) Number of Employees
* 7d) Log (Average Monthly Profits)
foreach var of varlist tot_emp_ l_bus_profit_av_def_ {
sum `var' if treatment==1 & s_`var'_all==1 & followup==1
xi:reg `var' FT `var'bl ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ [pweight=invpr_panel_incl] if s_`var'_all==1 & followup==1, vce(cluster branch_trade)
}
*
sum bus_profit_av_def_ if treatment==1 & s_l_bus_profit_av_def__all==1 & followup==1

* 7b) Number of Post-intervention Hires
* 7c) Number of Post-intervention Fires
foreach var of varlist n_new_emp n_left_emp {
sum `var' if treatment==1 & s_`var'_all==1 & followup==1
xi:reg `var' FT ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ [pweight=invpr_panel_incl] if s_`var'_all==1 & followup==1, vce(cluster branch_trade)
}
*

** Lee Bounds

foreach var of varlist tot_emp_ n_new_emp n_left_emp l_bus_profit_av_def_ {
leebounds `var' FT if followup==1, cie tight(_Itrade_bl_2 - _Itrade_bl_8)
}
*

*** LONG TERM

* 7e) Number of Employees
* 7h) Log (Average Monthly Profits)
foreach var of varlist tot_emp_ l_bus_profit_av_def_ {
sum `var' if treatment==1 & s_`var'_all==1 & followup>1
xi:reg `var' FT tfup fofup `var'bl ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ [pweight=invpr_panel_incl] if s_`var'_all==1 & followup>1, vce(cluster branch_trade)
}
*
sum bus_profit_av_def_ if treatment==1 & s_l_bus_profit_av_def__all==1 & followup>1

* 7f) Number of Post-intervention Hires
* 7g) Number of Post-intervention Fires
foreach var of varlist n_new_emp n_left_emp {
sum `var' if treatment==1 & s_`var'_all==1 & followup>1
xi:reg `var' FT tfup fofup ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ [pweight=invpr_panel_incl] if s_`var'_all==1 & followup>1, vce(cluster branch_trade)
}
*

** Lee Bounds

foreach var of varlist tot_emp_ n_new_emp n_left_emp l_bus_profit_av_def_ {
leebounds `var' FT if followup>1, cie tight(sfup tfup fofup _Itrade_bl_2 - _Itrade_bl_8)
}
*


*** PANEL B: ATE Estimates ***

*** SHORT TERM 

* 7a) Number of Employees
* 7d) Log (Average Monthly Profits)
foreach var of varlist tot_emp_ l_bus_profit_av_def_ {
xi:ivregress 2sls `var' `var'bl ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ (treatment_takeup_TA5 = FT `var'bl ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_) [pweight=invpr_panel_incl] if s_`var'_all==1 & followup==1, vce(cluster branch_trade)
}

* 7b) Number of Post-intervention Hires
* 7c) Number of Post-intervention Fires
foreach var of varlist n_new_emp n_left_emp {
xi:ivregress 2sls `var' ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ (treatment_takeup_TA5 = FT ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_) [pweight=invpr_panel_incl] if s_`var'_all==1 & followup==1, vce(cluster branch_trade)
}


*** LONG TERM

* 7e) Number of Employees
* 7h) Log (Average Monthly Profits)
foreach var of varlist tot_emp_ l_bus_profit_av_def_ {
xi:ivregress 2sls `var' `var'bl tfup fofup ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ (treatment_takeup_TA5 = FT tfup fofup `var'bl ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_) [pweight=invpr_panel_incl] if s_`var'_all==1 & followup>1, vce(cluster branch_trade)
}

* 7f) Number of Post-intervention Hires
* 7g) Number of Post-intervention Fires
foreach var of varlist n_new_emp n_left_emp {
xi:ivregress 2sls `var' tfup fofup ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_ (treatment_takeup_TA5 = FT tfup fofup ${X_firm_bl} i.branch_bl i.trade_bl i.interview_month_) [pweight=invpr_panel_incl] if s_`var'_all==1 & followup>1, vce(cluster branch_trade)
}
*
