************************************************
************************************************
** Table A13: Heterogeneous Impacts on Skills **
************************************************
************************************************

use "${mystart}/Datasets/Panel Dataset_noBL.dta", clear

** i. Create variables **

* Compliance
gen complier_all=(t2_training_attended==1|t3_training_attended==1|t5_accepted==1) if t2_training_attended!=.| t3_training_attended!=.|t5_accepted!=.
gen complier_all_VT=(complier_all==1&(group_final_2==1|group_final_2==2))
gen complier_all_FT=(complier_all==1&group_final_2==4)

gen VT=(group_final_2==1|group_final_2==2)
gen FT=(group_final_2==4)

keep if group_final_2_pooled!=.&invpr_panel_incl!=.

gen VTsample=group_final_2_pooled<4
gen FTsample=group_final_2_pooled==0|group_final_2_pooled==4

* Raven Matrices
tab cog_right_n if followup==1
gen cog_high=(cog_right_n>=5) if cog_right_n!=.
bysort idno: egen cog_high_high=max(cog_high)
replace cog_high=cog_high_high
drop cog_high_high
label var cog_high "high score in Raven matrices test'"

* Patience
gen     patience_bl=1 if risk_patience_1mon_bl==1 & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)
replace patience_bl=2 if risk_patience_6mon_bl==1  & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)
replace patience_bl=3 if risk_patience_12mon_bl==1 & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)
replace patience_bl=4 if risk_patience_12mon_bl==2 & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)

tab patience_bl if followup==1
gen patience_high_bl=(patience_bl>1) if patience_bl!=.
tab patience_high_bl if followup==1
label var patience_bl "patience level - 1 to 4 scale (higher number=more patient)"
label var patience_high_bl "patience level above/below median"
label define lpatience_high 0 "below median" 1 "above median"
label values patience_high_bl lpatience_high


** ii. Table **

global X_bl "age_bl married_bl any_child_bl employed_bl score_high_bl"

* A13a) Raven Matrices
local lhs "score_all"

foreach var of local lhs {
	
*1st stages by treatment
quietly reg complier_all_VT  VT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if VTsa==1, robust
predict VTHat`var'A, xb
quietly reg complier_all_FT  FT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if FTsa==1, robust
predict FTHat`var'A, xb

*1st stages by treatment, cog score at baseline
gen VTHat`var'=.
gen FTHat`var'=.

quietly reg complier_all_VT  VT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if cog_high==1&VTsa==1, robust
predict VTHat`var'RH,xb
replace VTHat`var'RH=0 if cog_high==0

quietly reg complier_all_VT  VT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if cog_high==0&VTsa==1, robust
predict VTHat`var'RL,xb
replace VTHat`var'RL=0 if cog_high==1

quietly reg complier_all_FT  FT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if cog_high==1&FTsa==1, robust
predict FTHat`var'RH,xb
replace FTHat`var'RH=0 if cog_high==0

quietly reg complier_all_FT  FT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if cog_high==0&FTsa==1, robust
predict FTHat`var'RL,xb
replace FTHat`var'RL=0 if cog_high==1

for var  FTHat`var'  VTHat`var':replace X=XRL if cog_high==0
for var  FTHat`var'  VTHat`var':replace X=XRH if cog_high==1

for var VTH* :replace X=0 if VT==0
for var FTH* :replace X=0 if FT==0


*ATE by cognitive ability

bootstrap , reps(1000) strata(strata) seed(643) nodots: reg `var' FTHat`var'RL  FTHat`var'RH VTHat`var'RL  VTHat`var'RH cog_high sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} 
test FTHat`var'RL = FTHat`var'RH
test VTHat`var'RL = VTHat`var'RH
sum `var' if e(sample)==1
}
*

drop VTHatscore_allA - FTHatscore_allRL


* A13b) Patience
local lhs "score_all"

foreach var of local lhs {
	
*1st stages by treatment
quietly reg complier_all_VT  VT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if VTsa==1, robust
predict VTHat`var'A, xb
quietly reg complier_all_FT  FT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if FTsa==1, robust
predict FTHat`var'A, xb

*1st stages by treatment, patience at baseline
gen VTHat`var'=.
gen FTHat`var'=.

quietly reg complier_all_VT  VT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if patience_high_bl==1&VTsa==1, robust
predict VTHat`var'PH,xb
replace VTHat`var'PH=0 if patience_high_bl==0

quietly reg complier_all_VT  VT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if patience_high_bl==0&VTsa==1, robust
predict VTHat`var'PL,xb
replace VTHat`var'PL=0 if patience_high_bl==1

quietly reg complier_all_FT  FT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if patience_high_bl==1&FTsa==1, robust
predict FTHat`var'PH,xb
replace FTHat`var'PH=0 if patience_high_bl==0

quietly reg complier_all_FT  FT sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} if patience_high_bl==0&FTsa==1, robust
predict FTHat`var'PL,xb
replace FTHat`var'PL=0 if patience_high_bl==1

for var  FTHat`var'  VTHat`var':replace X=XPL if patience_high_bl==0
for var  FTHat`var'  VTHat`var':replace X=XPH if patience_high_bl==1

for var VTH* :replace X=0 if VT==0
for var FTH* :replace X=0 if FT==0


*ATE by patience

bootstrap , reps(1000) strata(strata) seed(643) nodots: reg `var' FTHat`var'PL  FTHat`var'PH VTHat`var'PL  VTHat`var'PH patience_high_bl sfup tfup i.round_2 i.idate_mm i.strata ${X_bl} 
test FTHat`var'PL = FTHat`var'PH
test VTHat`var'PL = VTHat`var'PH
sum `var' if e(sample)==1
}
*
