***********************************
***********************************
** Table A2: External Validity ***
***********************************
***********************************

use "${mystart}/Datasets/Panel Dataset", clear

****************
*** BASELINE ***
****************

** i. Generate variables **

** Only keep individuals aged 18 to 25

keep if age_bl>=18 & age_bl<=25

** ii. Table **

* A2a)Age
* A2b)Gender
* A2c)Married
* A2d)Currently in school
* A2e)Years of education
* A2f)Ever attended vocational training
* A2g)Has worked in the last week
* A2h)Wage employment in the last week
* A2i)Casual employment in the last week
* A2l)Total earnings from wage employment in last month
	 
* 1. Number of workers
count if followup==0
*1608

* 2. Age [Years]
sum age_bl if followup==0

	
* 3. Gender [Male=1]
recode sex_bl (1=0) (0=1)	
sum sex_bl if followup==0

* 4. Married
sum married if followup==0


* 5a. Currently in school
sum in_school if followup==0


* 5b. Years of education
gen edu_years=edu_level
replace edu_years=13 if edu_years==14
sum edu_years if followup==0

	
* 6. Ever attended vocational training	
sum vocational_past if followup==0


* 7. Currently working [Yes=1]	
sum working if followup==0


* 8. Has had any wage employment in the last week	
gen worked_lastweek_empl_bl=1 if working==1 & most_recent_work_status==1 & casual_lastmonth_bl!=1 & followup==0
replace worked_lastweek_empl_bl=0 if (working==0 | (working==1 & worked_lastweek_empl_bl==.)) & followup==0
sum worked_lastweek_empl_bl if followup==0


* 9. Has done any casual work in the last week
gen worked_lastweek_casual_bl=1 if working==1 & casual_lastmonth_bl==1 & followup==0
replace worked_lastweek_casual_bl=0 if (working==0 | (working==1 & worked_lastweek_casual_bl==.)) & followup==0
sum worked_lastweek_casual_bl if followup==0


* 10. Total earnings in the last month [UGX]
sum earnings_lastmonth_wemp_def if followup==0


************
*** UNHS ***
************

*** The code below replicates PANELS B and C of Table A2. However, we do not have the right to share the dataset

/*
use "${mystart}/Datasets/UNHS 2012_13.dta", clear
count
*36,606 obs

** i. Generate variables **

** Only keep individuals aged 18 to 25
	 
keep if (r07>=18 & r07<=25)

** Identify labour market active individuals (individuals employed or actively seeking employment)

*working in the last week
gen labour_active=1 if A1A==1 | A1B==1 | A1C==1 | A1D==1 | A1E==1 | A4==1 | A4==2 | A4==3 |  C01==1
replace labour_active=0 if labour_active==. & (A1A!=. | A1B!=. | A1C!=. | A1D!=. | A1E!=. | A2==2 | A4!=.)

*temporarily absent
replace labour_active=1 if A6>=1 & A6<=6

*looking for a job
replace labour_active=1 if G1A==1 | G1A==2 | G3A==1 | G3B==1

tab labour_active, m


** ii. Table **
	 
* 1. Number of workers
count
*4696 obs

count if labour_active==1
*3456 obs


* 2. Age [Years]
sum r07 [aweight=wgt_hh]
sum r07 [aweight=wgt_hh] if labour_active==1

	
* 3. Gender [Male=1]	
recode r02 (2=0)
sum r02 [aweight=wgt_hh]
sum r02 [aweight=wgt_hh] if labour_active==1


* 4. Married
gen married=1 if (r09==1 | r09==2)
replace married=0 if (r09==3 | r09==4 | r09==5)
sum married [aweight=wgt_hh]
sum married [aweight=wgt_hh] if labour_active==1

	
* 5a. Currently in school
gen curr_school=1 if e03==3
replace curr_school=0 if e03==1 | e03==2
sum curr_school [aweight=wgt_hh]
sum curr_school [aweight=wgt_hh] if labour_active==1

* 5b. Years of education
recode e05 (10=0) (11=1) (12=2) (13=3) (14=4) (15=5) (16=6) (17=7) (21=8) (22=9) (23=10) (31=8) (32=9) (33=10) (34=11) (35=12) (36=13) (41=9) (51=15) (61=16) (98=.), gen(e05_years)
recode e10 (1=0) (10=1) (11=2) (12=3) (13=4) (14=5) (15=6) (16=7) (30=8) (31=9) (32=10) (33=11) (34=12) (35=13) (40=9) (50=15) (60=16) (98=.), gen(e10_years)

gen edu_years=0 if e03==1
replace edu_years=e05_years if e03==2
replace edu_years=e10_years if e03==3
replace edu_years=. if edu_years==36

sum edu_years [aweight=wgt_hh]
sum edu_years [aweight=wgt_hh] if labour_active==1

* 6. Ever attended vocational training	
gen attended_voc=1 if e05==41 | e05==51 | e10==40 | e10==50
replace attended_voc=0 if attended_voc==. & (e05!=. | e10!=. | e03==1)
sum attended_voc [aweight=wgt_hh]
sum attended_voc [aweight=wgt_hh] if labour_active==1

* 7. Has worked in the last week [Yes=1]	
	
	* A1A - In the last week, did you work for a wage, salary, commission or any payment in kind including doing paid domestic work, even if it was for one hour?
	* A1B - In the last week, did you run a business of any size, for yourself or with one or more partners, even if it was for one hour? 
	* A1C - In the last week, did you help without being paid in any kind of business run by your househols, even if it was for one hour?
	* A1D - In the last week, were you a memeber of a producers' cooperative?
	* A1E - In the last week, were you volunteer (Unpaid workers)?
	* A02 - In the last week, did you work on your household's farm?
	* A04 - In general, are the products obtained from this land for sale/barter or mainly for your own family use?

*working
gen worked_lastweek=1 if A1A==1 | A1B==1 | A1C==1 |A1D==1 | A1E==1 | A4==1 | A4==2 | A4==3 | C01==1
replace worked_lastweek=0 if worked_lastweek==. & (A1A!=. | A1B!=. | A1C!=. | A1D!=. | A1E!=. | A2==2 | A4!=.)

sum worked_lastweek [aweight=wgt_hh]
sum worked_lastweek [aweight=wgt_hh] if labour_active==1


* 8. Has done any casual work in the last week

	* B01 - main activity
	* C04 - secondary activity
	
replace B01="" if B01==" "
replace C04="" if C04==" "	

gen casual_UNHS_main=.
replace casual_UNHS_main=1 if B01=="CASUAL LABOURERS"
replace casual_UNHS_main=1 if B01=="1SUB FARMER"
replace casual_UNHS_main=1 if B01=="1SUBSISTANCE FARMER"
replace casual_UNHS_main=1 if B01=="AGRIC CASUAL LABOUR"
replace casual_UNHS_main=1 if B01=="AGRIC CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="AGRIC CASUAL LAUBOURER"
replace casual_UNHS_main=1 if B01=="AGRIC FARM LABOURER"
replace casual_UNHS_main=1 if B01=="AGRIC LABOURER"
replace casual_UNHS_main=1 if B01=="AGRICTURAL CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURA  LABOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL FARM LABOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL FARM LABOURER R"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL HEALTH OFFICER"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL LABOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL LABOURING"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL LARBOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL LSBOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURAL PRODUCE SELLER"
replace casual_UNHS_main=1 if B01=="AGRICULTURE"
replace casual_UNHS_main=1 if B01=="AGRICULTURE CASUAL LABOUR"
replace casual_UNHS_main=1 if B01=="AGRICULTURE CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="AGRICULTURE PRODUCE DEALER"
replace casual_UNHS_main=1 if B01=="AGRICULTURE PRODUCE SALESMAN"
replace casual_UNHS_main=1 if B01=="CARRYING FIREWOOD FOR PEOPLE"
replace casual_UNHS_main=1 if B01=="CASAUL CROP LABOURER"
replace casual_UNHS_main=1 if B01=="CASAUL LABOUR"
replace casual_UNHS_main=1 if B01=="CASAUL LABOURER"
replace casual_UNHS_main=1 if B01=="CASH CROP GROWER"
replace casual_UNHS_main=1 if B01=="CASU AL LABOURER"
replace casual_UNHS_main=1 if B01=="CASUA WORK AT MOVIT COMPANY"
replace casual_UNHS_main=1 if B01=="CASUAL"
replace casual_UNHS_main=1 if B01=="CASUAL  CROP  LABOURER"
replace casual_UNHS_main=1 if B01=="CASUAL  LABOURER"
replace casual_UNHS_main=1 if B01=="CASUAL  WORKER"
replace casual_UNHS_main=1 if B01=="CASUAL AGRIC LABOURER"
replace casual_UNHS_main=1 if B01=="CASUAL CROP LABOURER"
replace casual_UNHS_main=1 if B01=="CASUAL FORESTRY LABOURER"
replace casual_UNHS_main=1 if B01=="CASUAL LABORER"
replace casual_UNHS_main=1 if B01=="CASUAL LABORER IN SUBSISATNCE"
replace casual_UNHS_main=1 if B01=="CASUAL LABOUR(CROP GROWING)"
replace casual_UNHS_main=1 if B01=="CASUAL LABOUREE"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER CROP FARMING"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER DIGGING"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER FISHING"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER IN CROP FARMIN"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER IN FISHING"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER IN STONE QUARR"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURER SUBSISTENCE FA"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURERE IN LOADING AN"
replace casual_UNHS_main=1 if B01=="CASUAL LABOURURER"
replace casual_UNHS_main=1 if B01=="CASUAL LARBOURER"
replace casual_UNHS_main=1 if B01=="CASUAL WORK"
replace casual_UNHS_main=1 if B01=="CASUAL WORK AT MOVIT COMPANY"
replace casual_UNHS_main=1 if B01=="CASUAL WORKER"
replace casual_UNHS_main=1 if B01=="CASUAL WORKER IN CONSTRUCTION"
replace casual_UNHS_main=1 if B01=="CASUALA LABOURER"
replace casual_UNHS_main=1 if B01=="CASUALLABOURER"
replace casual_UNHS_main=1 if B01=="CASUL LABOURER"
replace casual_UNHS_main=1 if B01=="CASURL ULBOURBZ"
replace casual_UNHS_main=1 if B01=="CATTLE KEEPER"
replace casual_UNHS_main=1 if B01=="CATTLE KEEPER (PAID)"
replace casual_UNHS_main=1 if B01=="CATTLE LABOURER"
replace casual_UNHS_main=1 if B01=="CATTLE REARER"
replace casual_UNHS_main=1 if B01=="CAUSUAL LABOURER"
replace casual_UNHS_main=1 if B01=="COMMERCIAL CROP FARMER"
replace casual_UNHS_main=1 if B01=="COMMERCIAL CROP FARMING"
replace casual_UNHS_main=1 if B01=="COMMERCIAL CROP GROWING"
replace casual_UNHS_main=1 if B01=="COMMERCIAL FARMER"
replace casual_UNHS_main=1 if B01=="COMMERCIAL FARMER HELPER"
replace casual_UNHS_main=1 if B01=="COMMERCIAL FARMING"
replace casual_UNHS_main=1 if B01=="COMMERCILA HELPER FARMER"
replace casual_UNHS_main=1 if B01=="COMMMERCIAL CROP GROWING"
replace casual_UNHS_main=1 if B01=="COMMMERCIAL FARMER"
replace casual_UNHS_main=1 if B01=="CONSTRUCTION CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="CONSTRUCTION HELPER"
replace casual_UNHS_main=1 if B01=="CONSTRUCTION PORTER BRIDGES"
replace casual_UNHS_main=1 if B01=="CONSTRUCTION POTTER"
replace casual_UNHS_main=1 if B01=="CROP"
replace casual_UNHS_main=1 if B01=="CROP  FARM LABOURER"
replace casual_UNHS_main=1 if B01=="CROP  FARMER"
replace casual_UNHS_main=1 if B01=="CROP AND LIVESTOCK LABOURER"
replace casual_UNHS_main=1 if B01=="CROP CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="CROP CULTIVATION SUBSISTENCE"
replace casual_UNHS_main=1 if B01=="CROP FARM  LABOURER"
replace casual_UNHS_main=1 if B01=="CROP FARM CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="CROP FARM LABOUR"
replace casual_UNHS_main=1 if B01=="CROP FARM LABOURER"
replace casual_UNHS_main=1 if B01=="CROP FARMER"
replace casual_UNHS_main=1 if B01=="CROP FARMING"
replace casual_UNHS_main=1 if B01=="CROP FARMLABOURER"
replace casual_UNHS_main=1 if B01=="CROP FRAM LABOURER"
replace casual_UNHS_main=1 if B01=="CROP LABOURER"
replace casual_UNHS_main=1 if B01=="CROP PRODUCE SELLER"
replace casual_UNHS_main=1 if B01=="CROPFARMER"
replace casual_UNHS_main=1 if B01=="CULTIVATION HARVESTING"
replace casual_UNHS_main=1 if B01=="CUSUAL LABOURER BRICK MAKING"
replace casual_UNHS_main=1 if B01=="CUTTING AND SELLING GRASS"
replace casual_UNHS_main=1 if B01=="DUCK KEEPING"
replace casual_UNHS_main=1 if B01=="E  PORTER AT A CONSTRUCTION SI"
replace casual_UNHS_main=1 if B01=="ELEMENTARY CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="ELEMENTARY JOBS"
replace casual_UNHS_main=1 if B01=="FARM LABOURER"
replace casual_UNHS_main=1 if B01=="FARMER"
replace casual_UNHS_main=1 if B01=="FARMER MIXED"
replace casual_UNHS_main=1 if B01=="FARMING"
replace casual_UNHS_main=1 if B01=="FARMING G.NUTS,MILLET"
replace casual_UNHS_main=1 if B01=="FETCHING WATER"
replace casual_UNHS_main=1 if B01=="GROWING AND CROP REARING ANIMA"
replace casual_UNHS_main=1 if B01=="GROWING CROPS"
replace casual_UNHS_main=1 if B01=="GROWING CROPS."
replace casual_UNHS_main=1 if B01=="HELPER CASUAL CROP LABOUR"
replace casual_UNHS_main=1 if B01=="HELPER COMERCIAL CROP FARMING"
replace casual_UNHS_main=1 if B01=="HELPER COMMERCIAL CROP FARMING"
replace casual_UNHS_main=1 if B01=="HELPER COMMMERCIAL CROP FARMIN"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTANCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTANCE FARMING"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTANCE MIXED FARME"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTANCE MIXED FARMI"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTENCE CROP  FARMI"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTENCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTENCE CROP FARMIN"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTENCE FARMING"
replace casual_UNHS_main=1 if B01=="HELPER SUBSISTENCE MIXED FARMI"
replace casual_UNHS_main=1 if B01=="HELPING CATTLE KEEPING"
replace casual_UNHS_main=1 if B01=="HELPING IN CROP FARMING"
replace casual_UNHS_main=1 if B01=="HERDS MAN"
replace casual_UNHS_main=1 if B01=="HERDS WOMAN"
replace casual_UNHS_main=1 if B01=="HERDSBOY"
replace casual_UNHS_main=1 if B01=="HERDSMAN"
replace casual_UNHS_main=1 if B01=="HEROSMAN"
replace casual_UNHS_main=1 if B01=="LABOURER"
replace casual_UNHS_main=1 if B01=="LABOURER CATTLE"
replace casual_UNHS_main=1 if B01=="LABOURER CROP FARMING"
replace casual_UNHS_main=1 if B01=="LIVESTOCK FARM LABOURER"
replace casual_UNHS_main=1 if B01=="LIVESTOCK FARMER"
replace casual_UNHS_main=1 if B01=="LIVESTOCK FARMING"
replace casual_UNHS_main=1 if B01=="LOADER"
replace casual_UNHS_main=1 if B01=="M I XED SUBSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="MIXED"
replace casual_UNHS_main=1 if B01=="MIXED   SUBSISTANCE FARMER"
replace casual_UNHS_main=1 if B01=="MIXED CROP AND LIVESTOCK FARM"
replace casual_UNHS_main=1 if B01=="MIXED CROP FARMER"
replace casual_UNHS_main=1 if B01=="MIXED CROP LIVESTOCK FARMER"
replace casual_UNHS_main=1 if B01=="MIXED FARMER"
replace casual_UNHS_main=1 if B01=="MIXED FARMER."
replace casual_UNHS_main=1 if B01=="MIXED FARMING"
replace casual_UNHS_main=1 if B01=="MIXED SUB FARMER"
replace casual_UNHS_main=1 if B01=="MIXED SUBSISTANCE FARMER"
replace casual_UNHS_main=1 if B01=="MIXED SUBSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="MIXED SUBSISTENCE FARMING"
replace casual_UNHS_main=1 if B01=="P EASANT FARMER"
replace casual_UNHS_main=1 if B01=="PEASANT  FARMER"
replace casual_UNHS_main=1 if B01=="PEASANT FARMER"
replace casual_UNHS_main=1 if B01=="PEASNAT FARMER"
replace casual_UNHS_main=1 if B01=="PEASTANT FARMER"
replace casual_UNHS_main=1 if B01=="PERSONAL SERVICE WORKER"
replace casual_UNHS_main=1 if B01=="PORTER"
replace casual_UNHS_main=1 if B01=="PORTER AT A CONSTRUCTION SITE"
replace casual_UNHS_main=1 if B01=="PORTER AT CONSTRUCTION SITES"
replace casual_UNHS_main=1 if B01=="POTER"
replace casual_UNHS_main=1 if B01=="POTER AT A CONSTRUCTION SITE"
replace casual_UNHS_main=1 if B01=="POTTER"
replace casual_UNHS_main=1 if B01=="S IUBSISTENCEN MIXED FARMER"
replace casual_UNHS_main=1 if B01=="S UBSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUB AGRIC"
replace casual_UNHS_main=1 if B01=="SUB CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUB CROP FARMING"
replace casual_UNHS_main=1 if B01=="SUB FARMER"
replace casual_UNHS_main=1 if B01=="SUB MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBISTANCE MIXED CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBISTENCE MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBS CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBS ISTENCE CROP FARM HE L PE"
replace casual_UNHS_main=1 if B01=="SUBS ISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSI STENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSIATANCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSIOSTENCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISITENCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISSTANCE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTAENCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCCE FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE  CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE  CROP FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE  FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE  MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CROP  FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CROP FARM HELPER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CROP FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CROP FRAMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CROP HELPER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE CROP NFARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE FARM"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE FARMNG"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE FRAMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE FRAMER CROP"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE FRMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE LIVESTOCK FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE LIVESTOCK LABOURER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED  FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED CROP AND ANI"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED CROP AND LIV"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED CROP AND LVE"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE MIXED FRAMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANCE4 FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTANEC FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTEIOE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTEMCE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTEN CE   CROP  FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTEN MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENC CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENC E FARM ER"
replace casual_UNHS_main=1 if B01=="SUBSISTENC FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENC FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENC MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCA CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE   FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE  CROP  FARM ER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE  CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE  FARM ER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE  FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE  FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE  MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE  MIXED FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE AGRICULTURE"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE ANIMAL FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE ANIMALS FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE C RO P FA RME R"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CASUAL LABOURER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP  FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP AND LIVESTOCK"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP FAMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP FARM ER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP FARM HELPER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP FARMEER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROP,ANIMAL FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE CROPN FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARM LABOURER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMER (CROP)"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMER CASUAL LABO"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMER CROP"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMER HELPER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMER MIXED"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMERR"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE FARMING HELPER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE LIVESTOCK FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE M I XED FA RM ER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE M I XED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXE D FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED  FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED CROP"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED CROP AND LIV"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED CROP FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED CROP LIVESTO"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXED FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCE MIXEED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCEE FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENCEFARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENCEMIX ED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENEC CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENEC FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTENEC FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTENNCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSISTNCE FARMING"
replace casual_UNHS_main=1 if B01=="SUBSISTNCE MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSITANCE CROP FARM HELPER"
replace casual_UNHS_main=1 if B01=="SUBSITANCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSITANCE FARMING"
replace casual_UNHS_main=1 if B01=="SUBSITENCE LIVE STOCK FARMER"
replace casual_UNHS_main=1 if B01=="SUBSSISTENCE CROP FFARMER"
replace casual_UNHS_main=1 if B01=="SUBSSISTENCE MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUBSTENCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUBSWISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUBUSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUGAR CANE GROWER"
replace casual_UNHS_main=1 if B01=="SUNSISTENCE MIXED FARMER"
replace casual_UNHS_main=1 if B01=="SUPPLIER OF AGRIC PRODUCTS"
replace casual_UNHS_main=1 if B01=="SUSBSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUSISTANCE FARMER"
replace casual_UNHS_main=1 if B01=="SUSISTENCE FARMER"
replace casual_UNHS_main=1 if B01=="SUSUBSISTENCE CROP FARMER"
replace casual_UNHS_main=1 if B01=="SUUBSISTANCE MIXED CROP AND LI"
replace casual_UNHS_main=1 if B01=="TRUCK   OFF LOADER IN MARKET"
replace casual_UNHS_main=1 if B01=="TURN BOY"
replace casual_UNHS_main=1 if B01=="TURN BOY FOR A PRIVATE TRUCK"
replace casual_UNHS_main=1 if B01=="TURN BOY ON A TRUCK"
replace casual_UNHS_main=1 if B01=="TURN BOY ON LORRY"
replace casual_UNHS_main=1 if B01=="UCAASUAL LABOURER"
replace casual_UNHS_main=0 if casual_UNHS_main==. & B01!=""

** second occupation

gen casual_UNHS_oth=.
replace casual_UNHS_oth=1 if C04=="AGRIC CASUAL LABOURER"
replace casual_UNHS_oth=1 if C04=="AGRIC LABOURER"
replace casual_UNHS_oth=1 if C04=="AGRICLABOURER"
replace casual_UNHS_oth=1 if C04=="AGRICULTURAL CASUAL LABOURER"
replace casual_UNHS_oth=1 if C04=="AGRICULTURAL LABOUR"
replace casual_UNHS_oth=1 if C04=="AGRICULTURAL LABOURER"
replace casual_UNHS_oth=1 if C04=="AGRICULTURALCASUALABOURER"
replace casual_UNHS_oth=1 if C04=="AGRICULTURALLABOURER"
replace casual_UNHS_oth=1 if C04=="AGRICULTURE CASUAL LOBOURER"
replace casual_UNHS_oth=1 if C04=="AGRICULTURECASUALLABOURER"
replace casual_UNHS_oth=1 if C04=="CASAUL LABOURER"
replace casual_UNHS_oth=1 if C04=="CASIUALLABOURER"
replace casual_UNHS_oth=1 if C04=="CASUAL"
replace casual_UNHS_oth=1 if C04=="CASUAL AGRIC LABOURER"
replace casual_UNHS_oth=1 if C04=="CASUAL AGRICULTURAL LABOURER"
replace casual_UNHS_oth=1 if C04=="CASUAL CROP LABOURER"
replace casual_UNHS_oth=1 if C04=="CASUAL LABORER"
replace casual_UNHS_oth=1 if C04=="CASUAL LABOURER"
replace casual_UNHS_oth=1 if C04=="CASUAL LABOURER IN CROP FARMIN"
replace casual_UNHS_oth=1 if C04=="CASUAL LABOURER IN DIGGING"
replace casual_UNHS_oth=1 if C04=="CASUAL LABOURER IN SUBSISTENCE"
replace casual_UNHS_oth=1 if C04=="CASUAL LABOURER IN THE GARDEN"
replace casual_UNHS_oth=1 if C04=="CASUAL LABOURER ON FARM"
replace casual_UNHS_oth=1 if C04=="CASUAL LABOURER SUB FARMING"
replace casual_UNHS_oth=1 if C04=="CASUAL WORKER"
replace casual_UNHS_oth=1 if C04=="CASUALCROPLABOURER"
replace casual_UNHS_oth=1 if C04=="CASUALLABORERINSUBSISTENCECROP"
replace casual_UNHS_oth=1 if C04=="CASUALLABOUR"
replace casual_UNHS_oth=1 if C04=="CASUALLABOURER"
replace casual_UNHS_oth=1 if C04=="CASUALLARBOURER"
replace casual_UNHS_oth=1 if C04=="CASUALWORKER"
replace casual_UNHS_oth=1 if C04=="CATTLE KEEPER"
replace casual_UNHS_oth=1 if C04=="CATTLE REARING"
replace casual_UNHS_oth=1 if C04=="CATTLEKEEPER"
replace casual_UNHS_oth=1 if C04=="CATTLESELLER"
replace casual_UNHS_oth=1 if C04=="CAUSAL LABOURER"
replace casual_UNHS_oth=1 if C04=="CAUSAL LABOURER TRANSPORT"
replace casual_UNHS_oth=1 if C04=="CAUSUALLABOURER"
replace casual_UNHS_oth=1 if C04=="CONSTRUCTIONCASUALLABOURER"
replace casual_UNHS_oth=1 if C04=="CROP FARM CASUAL LABOURER"
replace casual_UNHS_oth=1 if C04=="CROP FARM LABOURER"
replace casual_UNHS_oth=1 if C04=="CROP FARMER"
replace casual_UNHS_oth=1 if C04=="CROP FARMER LABOURER"
replace casual_UNHS_oth=1 if C04=="CROPFARMER"
replace casual_UNHS_oth=1 if C04=="CROPFARMLABOURER"
replace casual_UNHS_oth=1 if C04=="CROPFARMLABOURING"
replace casual_UNHS_oth=1 if C04=="CROPLABOURER"
replace casual_UNHS_oth=1 if C04=="DIGGING FOR CASH WITH OX PLOUG"
replace casual_UNHS_oth=1 if C04=="DIGGING ON OWN GARDEN"
replace casual_UNHS_oth=1 if C04=="FARM LABOURER"
replace casual_UNHS_oth=1 if C04=="FARMER"
replace casual_UNHS_oth=1 if C04=="FARMER MIXED"
replace casual_UNHS_oth=1 if C04=="FARMLABOURER"
replace casual_UNHS_oth=1 if C04=="FETCHING AND SELLING WATER"
replace casual_UNHS_oth=1 if C04=="FETCHINGANDSELLINGWATER"
replace casual_UNHS_oth=1 if C04=="GARDENCASUALLABOURER"
replace casual_UNHS_oth=1 if C04=="HELPER IN BUILDING HOUSES"
replace casual_UNHS_oth=1 if C04=="HELPERINBREWINGMALTLIQUOR"
replace casual_UNHS_oth=1 if C04=="HELPERSUBSISTENCCROPFARMING"
replace casual_UNHS_oth=1 if C04=="HELPERSUBSISTENCECROPFARMING"
replace casual_UNHS_oth=1 if C04=="HELPERSUBSISTENCEMIXEDFARMING"
replace casual_UNHS_oth=1 if C04=="LIVESTOCK FARMING"
replace casual_UNHS_oth=1 if C04=="LIVESTOCK KEEPER"
replace casual_UNHS_oth=1 if C04=="MIOXED SUBSISTENCE FARMER"
replace casual_UNHS_oth=1 if C04=="MIXED FARMER"
replace casual_UNHS_oth=1 if C04=="MIXED FARMING"
replace casual_UNHS_oth=1 if C04=="MIXED SUBSISTANCE FARMER"
replace casual_UNHS_oth=1 if C04=="MIXED SUBSISTENCE FARMER"
replace casual_UNHS_oth=1 if C04=="MIXEDSUBSISTENCEFARMER"
replace casual_UNHS_oth=1 if C04=="MIXES SUBSISTENCE FARMER"
replace casual_UNHS_oth=1 if C04=="PORTER"
replace casual_UNHS_oth=1 if C04=="POTTER"
replace casual_UNHS_oth=1 if C04=="SSUBISTENCEMIXEDFARMER"
replace casual_UNHS_oth=1 if C04=="SUB CROP FARMER"
replace casual_UNHS_oth=1 if C04=="SUB FARMER"
replace casual_UNHS_oth=1 if C04=="SUB MIXED FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSCROPFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSIOSTENCEMIXEDFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCE CROP FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCE CROP LABOURER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCE FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCE FARMING"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCE LIVESTOCK FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCECASUALLABOURER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCECROPFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCECROPLABOURER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCEFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCEFARMING"
replace casual_UNHS_oth=1 if C04=="SUBSISTANCEMIXEDFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENC FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCCROPFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE CROP FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE CROP FARMERS"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE CROP FARMING"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE CROP LABOURER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE FARMING"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE FRAMING"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE LIVESTOCK FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCE MIXED FARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCECASUALLABOURER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCECROPFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCECROPFARMING"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCECROPLABOURER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCEFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCEFARMERCROP"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCEFARMING"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCEFISHER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCELIVESTOCKFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCEMIXEDFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSISTENCEMIXEDFARMING"
replace casual_UNHS_oth=1 if C04=="SUBSSITENCEFARMER"
replace casual_UNHS_oth=1 if C04=="SUBSTENCEFARMER"
replace casual_UNHS_oth=1 if C04=="SUSISTENCE FARMER"
replace casual_UNHS_oth=0 if casual_UNHS_oth==. & C04!=""

gen worked_lastweek_casual=1 if worked_lastweek==1 & (casual_UNHS_main==1 | casual_UNHS_oth==1)
replace worked_lastweek_casual=0 if worked_lastweek_casual==. & worked_lastweek!=.
sum worked_lastweek_casual [aweight=wgt_hh]
sum worked_lastweek_casual [aweight=wgt_hh] if labour_active==1

gen worked_lastweek_casual_emp=1 if worked_lastweek==1 & (((A1A==1 | A1C==1 | A1E==1) &casual_UNHS_main==1) | ((C08==1 | C08==4 | C08==6) & casual_UNHS_oth==1))
replace worked_lastweek_casual_emp=0 if worked_lastweek_casual_emp==. & worked_lastweek!=.


* 9. Has had any wage/self employment in the last week	

	* A1A - In the last week, did you work for a wage, salary, commission or any payment in kind including doing paid domestic work, even if it was for one hour?

gen worked_lastweek_emp=1 if worked_lastweek==1 & (((A1A==1 | A1C==1 | A1E==1) & casual_UNHS_main!=1) | ((C08==1 | C08==4 | C08==6) & casual_UNHS_oth!=1))
replace worked_lastweek_emp=0 if worked_lastweek_emp==. & worked_lastweek!=.
sum worked_lastweek_emp [aweight=wgt_hh]
sum worked_lastweek_emp [aweight=wgt_hh] if labour_active==1

gen worked_lastweek_emp_any=1 if worked_lastweek==1 & (A1A==1 | A1C==1 | A1E==1 | C08==1 | C08==4 | C08==6)
replace worked_lastweek_emp_any=0 if worked_lastweek_emp_any==. & worked_lastweek!=.
sum worked_lastweek_emp_any [aweight=wgt_hh]
sum worked_lastweek_emp_any [aweight=wgt_hh] if labour_active==1

gen emp_main=(A1A==1 | A1C==1 | A1E==1)  if A1A!=. | A1C!=. | A1E!=.
gen emp_oth=(C08==1 | C08==4 | C08==6) if C08!=.

	* A1B - In the last week, did you run a business of any size, for yourself or with one or more partners, even if it was for one hour? 

gen worked_lastweek_self=1 if worked_lastweek==1 & ((A1B==1 & casual_UNHS_main!=1) | ((C08==2 | C08==3) & casual_UNHS_oth!=1))
replace worked_lastweek_self=0 if worked_lastweek_self==. & worked_lastweek!=.
sum worked_lastweek_self [aweight=wgt_hh]
sum worked_lastweek_self [aweight=wgt_hh] if labour_active==1

gen self_main=(A1B==1) if A1B!=.
gen self_oth=(C08==2) if C08!=.


* 10. Total earnings in the last month [USD] (from non-casual occupations)

	* B5 - In this job/activity, were you employee, employer etc.?
	* F2 - What is the set rate you are paid?
	* F3 - What is the periodicity of this?
	* F8 - What is the estimated value of these payments in kind?
	* F9 - Per Unit (circle)
	* D1 - How many hours do you usually work per week? In your main job/activity
	* C8 - In this job/activity, were you employee, employer etc.?
	* F11 - What is the set rate you are paid?
	* F12 - What is the periodicity of this?
	* F16 - What is the estimated value of these payments in kind?
	* F17 - Per Unit (circle)
	* D1 - How many hours do you usually work per week? In any other job/activity

** Generate days worked last week
*main job
foreach var of varlist D2AA D2BA D2CA D2DA D2EA D2FA D2GA {
gen `var'_any=(`var'>0) if `var'!=.
}
egen    days_lastweek_main=rowtotal(D2AA_any - D2GA_any), missing
replace days_lastweek_main=0 if worked_lastweek==0

*other job
foreach var of varlist D2AB D2BB D2CB D2DB D2EB D2FB D2GB {
gen `var'_any=(`var'>0) if `var'!=.
}
egen    days_lastweek_oth=rowtotal(D2AB_any - D2GB_any), missing
replace days_lastweek_oth=0 if worked_lastweek==0 | C01==2


** Generate total earnings
*main job
gen     tot_earn_lastmonth_main=0 if A1A!=1 & A1E!=1 
replace tot_earn_lastmonth_main=0 if A1E==1
replace tot_earn_lastmonth_main=F2*D1A*(30/7) if F3==1 & A1A==1
replace tot_earn_lastmonth_main=F2*days_lastweek_main*(30/7) if F3==2 & A1A==1
replace tot_earn_lastmonth_main=F2*(30/7) if F3==3 & A1A==1
replace tot_earn_lastmonth_main=F2*(30/14) if F3==4 & A1A==1
replace tot_earn_lastmonth_main=F2*2 if F3==5 & A1A==1
replace tot_earn_lastmonth_main=F2 if F3==6 & A1A==1
replace tot_earn_lastmonth_main=F2/12 if F3==7 & A1A==1

*other job
gen     tot_earn_lastmonth_oth=0 if C08!=1 & C08!=6
replace tot_earn_lastmonth_oth=0 if C08==1
replace tot_earn_lastmonth_oth=F11*D1B*(30/7) if F12==1
replace tot_earn_lastmonth_oth=F11*days_lastweek_oth*(30/7) if F12==2
replace tot_earn_lastmonth_oth=F11*(30/7) if F12==3
replace tot_earn_lastmonth_oth=F11*(30/14) if F12==4
replace tot_earn_lastmonth_oth=F11*2 if F12==5
replace tot_earn_lastmonth_oth=F11 if F12==6
replace tot_earn_lastmonth_oth=F11/12 if F12==7


** Generate total inkind payments
*main job
gen     inkind_earn_lastmonth_main=F8*D1A*(30/7) if F9==1 & A1A==1
replace inkind_earn_lastmonth_main=F8*days_lastweek_main*(30/7) if F9==2 & A1A==1
replace inkind_earn_lastmonth_main=F8*(30/7) if F9==3 & A1A==1
replace inkind_earn_lastmonth_main=F8*(30/14) if F9==4 & A1A==1
replace inkind_earn_lastmonth_main=F8*2 if F9==5 & A1A==1
replace inkind_earn_lastmonth_main=F8 if F9==6 & A1A==1
replace inkind_earn_lastmonth_main=F8/12 if F9==7 & A1A==1

*other job
gen     inkind_earn_lastmonth_oth=F16*D1A*(30/7) if F17==1 & A1A==1
replace inkind_earn_lastmonth_oth=F16*days_lastweek_oth*(30/7) if F17==2 & A1A==1
replace inkind_earn_lastmonth_oth=F16*(30/7) if F17==3 & A1A==1
replace inkind_earn_lastmonth_oth=F16*(30/14) if F17==4 & A1A==1
replace inkind_earn_lastmonth_oth=F16*2 if F17==5 & A1A==1
replace inkind_earn_lastmonth_oth=F16 if F17==6 & A1A==1
replace inkind_earn_lastmonth_oth=F16/12 if F17==7 & A1A==1


** TOTAL EARNINGS

egen tot_earn_any_lastmonth=rowtotal(tot_earn_lastmonth_main tot_earn_lastmonth_oth inkind_earn_lastmonth_main inkind_earn_lastmonth_oth), missing
tab tot_earn_any_lastmonth

*trim top 1%
replace tot_earn_any_lastmonth=. if tot_earn_any_lastmonth>=600000

egen tot_earn_lastmonth=rowtotal(tot_earn_lastmonth_main tot_earn_lastmonth_oth inkind_earn_lastmonth_main inkind_earn_lastmonth_oth), missing
tab tot_earn_lastmonth

*trim top 1%
replace tot_earn_lastmonth=. if tot_earn_lastmonth>=514000


** TOTAL DEFLATED EARNINGS

gen tot_earn_any_lastmonth_def=(tot_earn_any_lastmonth/2493.73)
sum tot_earn_any_lastmonth_def [aweight=wgt_hh]
sum tot_earn_any_lastmonth_def [aweight=wgt_hh] if labour_active==1
*/
