***********************************************************
***********************************************************
** Table A7: Compliance with the Firm Training Treatment **
***********************************************************
***********************************************************

use "${mystart}/Datasets/Panel Dataset_noBL.dta", clear


** i. Create variables **

** Compliance

gen complier_all=(t2_training_attended==1|t3_training_attended==1|t5_accepted==1) if t2_training_attended!=.| t3_training_attended!=.|t5_accepted!=.
gen complier_all_VT=(complier_all==1&(group_final_2==1|group_final_2==2))
gen complier_all_FT=(complier_all==1&group_final_2==4)

gen VT=(group_final_2==1|group_final_2==2)
gen FT=(group_final_2==4)

gen     complier_FT_vs_VT=.
replace complier_FT_vs_VT=1 if complier_all_FT==1
replace complier_FT_vs_VT=0 if complier_all_VT==1
label var complier_FT_vs_VT "dummy=1 if FT complier; =0 if VT complier"

** Worker Characteristics at baseline

* Patience
gen     patience_bl=1 if risk_patience_1mon_bl==1 & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)
replace patience_bl=2 if risk_patience_6mon_bl==1  & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)
replace patience_bl=3 if risk_patience_12mon_bl==1 & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)
replace patience_bl=4 if risk_patience_12mon_bl==2 & (risk_patience_1mon_bl!=.|risk_patience_6mon_bl!=.|risk_patience_12mon_bl!=.)

tab patience_bl if followup==1
gen patience_high_bl=(patience_bl>1) if patience_bl!=.
tab patience_high_bl if followup==1
label var patience_bl "patience level - 1 to 4 scale (higher number=more patient)"
label var patience_high_bl "patience level above/below median"
label define lpatience_high 0 "below median" 1 "above median"
label values patience_high_bl lpatience_high

* Risk
gen     risk_bl=1 if risk_lottery_30k_bl==2 & (risk_lottery_100k_bl!=.|risk_lottery_60k_bl!=.|risk_lottery_30k_bl!=.)
replace risk_bl=2 if risk_lottery_30k_bl==1 & (risk_lottery_100k_bl!=.|risk_lottery_60k_bl!=.|risk_lottery_30k_bl!=.)
replace risk_bl=3 if risk_lottery_60k_bl==1 & (risk_lottery_100k_bl!=.|risk_lottery_60k_bl!=.|risk_lottery_30k_bl!=.)
replace risk_bl=4 if risk_lottery_100k_bl==1 & (risk_lottery_100k_bl!=.|risk_lottery_60k_bl!=.|risk_lottery_30k_bl!=.)

tab risk_bl if followup==1
gen risk_high_bl=(risk_bl>2) if risk_bl!=.
tab risk_high if followup==1
label var risk_bl "risk level - 1 to 4 scale (higher number=more risky)"
label var risk_high_bl "risk level above/below median"
label define lrisk_high 0 "below median" 1 "above median"
label values risk_high_bl lrisk_high

* Years of education
gen edu_years_bl=edu_level_bl
label var edu_years_bl "years of education"
replace edu_years_bl=13 if edu_years_bl==14

* Ideal job
gen ideal_job_emp_bl=(ideal_job_emp_self_bl==1) if ideal_job_emp_self_bl!=.
label var ideal_job_emp_bl "ideal job"
label define lideal_job_emp_bl 1 "employed" 0 "self-employed"
label values ideal_job_emp_bl lideal_job_emp_bl

* Literacy and numeracy Test
rename correct_answers_bl score_bl

tab score_bl if followup==1
gen score_high_quart_bl=(score_bl>=8) if score_bl!=.
label var score_high_quart_bl "literacy and numeracy test in top quartile"

tab score_bl if followup==1
gen score_high_dec_bl=(score_bl>=9) if score_bl!=.
label var score_high_dec_bl "literacy and numeracy test in top decile"

** generate interactions with treatment
foreach var of varlist sex_bl age_bl any_child_bl education_bl score_high_bl employed_bl ideal_job_emp_bl risk_high_bl patience_high_bl emp_aug_2013 {
gen `var'_FT=`var'*FT
gen `var'_VT=`var'*VT
}
*

** Firm Characteristics

** average measures of profit and capital per worker
gen owner_edu_years=.
gen firm_size_bl=.
gen l_profit_worker=.
gen l_capital_worker=.

foreach var of varlist owner_edu_years firm_size_bl l_profit_worker l_capital_worker {
egen `var'_av=rowmean(`var'_1 `var'_2 `var'_3 `var'_4 `var'_5 `var'_6 `var'_7 `var'_8 `var'_9 `var'_10)
}
*

** replace missing values with zeros and generate dummies for missing values
foreach var of varlist emp_aug_2013 num_matched num_matched_high owner_edu_years_av firm_size_bl_av l_profit_worker_av l_capital_worker_av branch_match trade_2_match {
gen `var'_nomiss=`var'
replace `var'_nomiss=0 if `var'==.
gen `var'_miss=(`var'==.)
}


** ii. Table **

global X_bl "age_bl married_bl any_child_bl employed_bl score_high_bl"

* A7a) Worker Characteristics
xi:reg  complier_all_FT sex_bl age_bl any_child_bl  education_bl score_high_bl employed_bl ideal_job_emp_bl risk_high_bl patience_high_bl emp_aug_2013_nomiss i.region_bl emp_aug_2013_miss if followup==1&group_final_2_pooled==4, robust
sum complier_all_FT if followup==1&group_final_2_pooled==4
test sex_bl=age_bl=any_child_bl=education_bl=score_high_bl=employed_bl=ideal_job_emp_bl=risk_high_bl=patience_high_bl=emp_aug_2013_nomiss=0
di e(r2_a)


* A7b) Worker and Program Characteristics
xi:reg  complier_all_FT sex_bl age_bl any_child_bl  education_bl score_high_bl employed_bl ideal_job_emp_bl risk_high_bl patience_high_bl emp_aug_2013_nomiss i.round_2 num_matched_high_nomiss i.region_bl i.branch_match_nomiss i.trade_2_match_nomiss emp_aug_2013_miss i.branch_match_miss  i.trade_2_match_miss num_matched_high_miss if followup==1&group_final_2_pooled==4, robust
sum complier_all_FT if followup==1&group_final_2_pooled==4
test sex_bl=age_bl=any_child_bl=education_bl=score_high_bl=employed_bl=ideal_job_emp_bl=risk_high_bl=patience_high_bl=emp_aug_2013_nomiss=0
di e(r2_a)


* A7c) Worker, Program and Firm Characteristics
xi:reg  complier_all_FT sex_bl age_bl any_child_bl  education_bl score_high_bl employed_bl ideal_job_emp_bl risk_high_bl patience_high_bl emp_aug_2013_nomiss i.round_2 i.region_bl i.branch_match_nomiss  i.trade_2_match_nomiss num_matched_high_nomiss firm_size_bl_av_nomiss l_profit_worker_av_nomiss l_capital_worker_av_nomiss emp_aug_2013_miss i.branch_match_miss  i.trade_2_match_miss num_matched_high_miss firm_size_bl_av_miss l_profit_worker_av_miss l_capital_worker_av_miss if followup==1&group_final_2_pooled==4, robust
sum complier_all_FT if followup==1&group_final_2_pooled==4
test sex_bl=age_bl=any_child_bl=education_bl=score_high_bl=employed_bl=ideal_job_emp_bl=risk_high_bl=patience_high_bl=emp_aug_2013_nomiss=0
test firm_size_bl_av_nomiss=l_profit_worker_av_nomiss=l_capital_worker_av_nomiss=0
di e(r2_a)


* A7d) Firm Fixed Effects

** Do not have firm ID from workers' follow-ups, so need to rely on process reports and firms' first follow-up

** Generate file with IDs of the firms the worker has been matched with
keep if followup==1&group_final_2_pooled==4
keep idno bid_* complier_all_FT sex_bl age_bl married_bl any_child_bl education_bl score_high_bl score_high_dec_bl employed_bl ideal_job_emp_bl risk_high_bl patience_high_bl emp_aug_2013_nomiss round_2 region_bl num_matched_high_nomiss firm_size_bl_av_nomiss l_profit_worker_av_nomiss l_capital_worker_av_nomiss branch_match_nomiss trade_2_match_nomiss firm_size_bl_av_miss l_profit_worker_av_miss l_capital_worker_av_miss num_matched_high_miss branch_match_miss emp_aug_2013_miss trade_2_match_miss

reshape long bid_, i(idno) j(match_num)

rename bid_ bid
order idno bid match_num

drop if bid==.
count
*514 matched

** Merge with process reports
merge 1:1 idno bid using "${mystart}/Datasets/Process Report FT - Outcome.dta", keepusing(accepted)
keep if _merge==1 | _merge==3
drop _merge

order accepted, after(bid)
rename accepted accepted_process

tempfile temp1
save `temp1'

** Merge with firm first follow-up

*First, need to reshape first follow-up at the match level
use "${mystart}/Datasets/Firm First Follow-up.dta", clear

keep bid s3119_0 s3119_1

reshape long s3119_, i(bid) j(match_num)

rename s3119_ idno
gen accepted_ffup=1 if idno!=.

drop match_num
keep if accepted_ffup==1
sort idno bid

tempfile temp2
save `temp2'

*Merge into main dataset

use `temp1', clear

merge 1:1 idno bid using `temp2', keepusing(accepted_ffup)
keep if _merge==1|_merge==3
drop _merge

order idno bid accepted_process accepted_ffup

count

** Generate variable for compliance
gen accepted=1 if accepted_process==1|accepted_ffup==1
gen match_hire=0
replace match_hire=1 if accepted==1&complier_all_FT==1

bys bid: gen workers_matched=_N
bys idno: gen firms_matched=_N
replace match_hire=1 if complier_all_FT==1&firms_matched==1

tab match_hire

** Drop matches for which don't have firm ID
bys idno: egen max_match_hire=max(match_hire)
bys idno: egen max_accepted=max(accepted)
drop if complier_all_FT==1&max_match_hire==0

order match_hire, after(complier_all_FT)
sort idno bid

areg  match_hire sex_bl age_bl any_child_bl education_bl score_high_bl employed_bl ideal_job_emp_bl risk_high_bl patience_high_bl emp_aug_2013_nomiss num_matched_high_nomiss i.region_bl i.round_2 emp_aug_2013_miss num_matched_high_miss, absorb(bid) cluster(bid)
*partial rsquared of firms fixed effets and worker chars estimated from the same regression, conclude worker characteristics do not matter much
test sex_bl=age_bl=any_child_bl=education_bl=score_high_bl=employed_bl=ideal_job_emp_bl=risk_high_bl=patience_high_bl=emp_aug_2013_nomiss=0
di e(r2_a)

