***********************************
***********************************
** Table A8: Worker Expectations **
***********************************
***********************************

** Generate average expected earnings in ideal occupation if receives training at baseline
*  assuming triangular distribution, and compare to case when they don't receive training

use "${mystart}/Datasets/Panel Dataset.dta", clear

keep if followup==0
count
*1714 obs

** i. Create variables **

*** Identify ideal occupation
gen occ_1_ideal=1 if occ_1==ideal_job_type
gen occ_2_ideal=1 if occ_2==ideal_job_type
gen occ_3_ideal=1 if occ_3==ideal_job_type


*** Expectations with training

*probability of finding a job
gen     prob_1month_vtp_ideal=prob_1month_vtp_1 if occ_1_ideal==1
replace prob_1month_vtp_ideal=prob_1month_vtp_2 if occ_2_ideal==1
replace prob_1month_vtp_ideal=prob_1month_vtp_3 if occ_3_ideal==1

gen     prob_6month_vtp_ideal=prob_6month_vtp_1 if occ_1_ideal==1
replace prob_6month_vtp_ideal=prob_6month_vtp_2 if occ_2_ideal==1
replace prob_6month_vtp_ideal=prob_6month_vtp_3 if occ_3_ideal==1

gen     prob_12month_vtp_ideal=prob_12month_vtp_1 if occ_1_ideal==1
replace prob_12month_vtp_ideal=prob_12month_vtp_2 if occ_2_ideal==1
replace prob_12month_vtp_ideal=prob_12month_vtp_3 if occ_3_ideal==1

foreach var of varlist prob_1month_vtp_ideal prob_6month_vtp_ideal prob_12month_vtp_ideal {
replace `var'=`var'/10
sum `var'
}

*average expected earnings
local i=1
while `i'<=3 {
replace pr_av_amount_vtp_`i'=pr_av_amount_vtp_`i'/10
gen av_exp_earnings_vtp_`i'=((1-pr_av_amount_vtp_`i')/3)*(2*min_amount_vtp_`i'+max_amount_vtp_`i')+(pr_av_amount_vtp_`i'/3)*(min_amount_vtp_`i'+2*max_amount_vtp_`i')
local i=`i'+1
}
*

gen     av_exp_earnings_vtp_ideal=av_exp_earnings_vtp_1 if occ_1_ideal==1
replace av_exp_earnings_vtp_ideal=av_exp_earnings_vtp_2 if occ_2_ideal==1
replace av_exp_earnings_vtp_ideal=av_exp_earnings_vtp_3 if occ_3_ideal==1

*deflated expected earnings
gen     av_exp_earnings_vtp_ideal_def = (av_exp_earnings_vtp_ideal/2493.73) if round_2==0
replace av_exp_earnings_vtp_ideal_def = (av_exp_earnings_vtp_ideal*196.3/203.7)/2493.73 if round_2==1

sum av_exp_earnings_vtp_ideal if group_final_2==0|group_final_2==3
sum av_exp_earnings_vtp_ideal if group_final_2==1|group_final_2==2
sum av_exp_earnings_vtp_ideal if group_final_2==4

sum av_exp_earnings_vtp_ideal


*** Expectations in the no-training case

*probability of finding a job
gen     prob_1month_curr_ideal=prob_1month_curr_1 if occ_1_ideal==1
replace prob_1month_curr_ideal=prob_1month_curr_2 if occ_2_ideal==1
replace prob_1month_curr_ideal=prob_1month_curr_3 if occ_3_ideal==1

gen     prob_6month_curr_ideal=prob_6month_curr_1 if occ_1_ideal==1
replace prob_6month_curr_ideal=prob_6month_curr_2 if occ_2_ideal==1
replace prob_6month_curr_ideal=prob_6month_curr_3 if occ_3_ideal==1

gen     prob_12month_curr_ideal=prob_12month_curr_1 if occ_1_ideal==1
replace prob_12month_curr_ideal=prob_12month_curr_2 if occ_2_ideal==1
replace prob_12month_curr_ideal=prob_12month_curr_3 if occ_3_ideal==1

foreach var of varlist prob_1month_curr_ideal prob_6month_curr_ideal prob_12month_curr_ideal {
replace `var'=`var'/10
sum `var'
}

*average expected earnings
local i=1
while `i'<=3 {
replace pr_av_amount_curr_`i'=pr_av_amount_curr_`i'/10
gen av_exp_earnings_curr_`i'=((1-pr_av_amount_curr_`i')/3)*(2*min_amount_curr_`i'+max_amount_curr_`i')+(pr_av_amount_curr_`i'/3)*(min_amount_curr_`i'+2*max_amount_curr_`i')
local i=`i'+1
}
*

gen     av_exp_earnings_curr_ideal=av_exp_earnings_curr_1 if occ_1_ideal==1
replace av_exp_earnings_curr_ideal=av_exp_earnings_curr_2 if occ_2_ideal==1
replace av_exp_earnings_curr_ideal=av_exp_earnings_curr_3 if occ_3_ideal==1

*deflated expected earnings
gen     av_exp_earnings_curr_ideal_def = (av_exp_earnings_curr_ideal/2493.73) if round_2==0
replace av_exp_earnings_curr_ideal_def = (av_exp_earnings_curr_ideal*196.3/203.7)/2493.73 if round_2==1


*exclude top 1%
tab av_exp_earnings_curr_ideal_def
replace av_exp_earnings_curr_ideal_def=. if av_exp_earnings_curr_ideal_def>=245
tab av_exp_earnings_vtp_ideal_def
replace av_exp_earnings_vtp_ideal_def=. if av_exp_earnings_vtp_ideal_def>=427


** ii. Table **

* A8a) Expected probability of finding a job with current skill set
sum prob_12month_curr_ideal
* A8b) Expected probability of finding if receives VTI Training
sum prob_12month_vtp_ideal
* A8c) Average expected monthly earnings with current skill set 
sum av_exp_earnings_curr_ideal_def
* A8d) Average expected monthly earnings if receives VTI Training
sum av_exp_earnings_vtp_ideal_def

