*********************************
*********************************
** Table A9: Robustness Checks **
*********************************
*********************************

use "${mystart}/Datasets/Panel Dataset_noBL.dta", clear

** i. Create variables **

** Hours worked last week in both wage and self-employment
rename hours_worked_lastweek_self hours_worked_lastweek_s
rename hours_worked_lastweek_self_bl hours_worked_lastweek_s_bl

replace hours_worked_lastweek=hours_worked_lastweek_s+hours_worked_lastweek
replace hours_worked_lastweek_bl=hours_worked_lastweek_s_bl+hours_worked_lastweek_bl

** Labor Market Index at Follow-up

	** step 1: demean outcomes and divide by SD in the control group

	foreach var of varlist paid_emp_lastmonth months_worked_lastyear hours_worked_lastweek earnings_lastmonth_def {
	gen `var'_z=.

	local i=1
	while `i'<=3 {
	sum `var' if followup==`i'
	local `var'_m=r(mean)
	sum `var' if group_final_2==0 & followup==`i'
	local `var'_sd=r(sd)
	replace `var'_z=((`var'-``var'_m')/``var'_sd') if followup==`i'
	local i=`i'+1
	}

	}

	gen var1=paid_emp_lastmonth_z
	gen var2=months_worked_lastyear_z
	gen var3=hours_worked_lastweek_z
	gen var4=earnings_lastmonth_def_z

	** step 2: calculate the var-cov matrix of the transformed outcomes and export the weight matrix 

	corr var1 var2 var3 var4, covariance

	matrix list r(C)
	matrix varcov = r(C)

	* Generate matrix for the number of observations

	count
	matrix n = [r(N)]

	* Generate a matrix for the number of variables in the index

	matrix m = [4]


	mata:

	N = st_matrix("n")
	M = st_matrix("m")
	V = st_matrix("varcov")

	M
	N
	V

	V_inv=invsym(V)
	V_inv

	ones = J(M,1,1)
	ones

	W=V_inv * ones
	W


	weight_var=J(N,M,1)
	for (i=1; i<=M; i++) {
		weight_var[|1,i \ N,i|]=W[i,1]*weight_var[|1,i \ N,i|]
	}

	st_matrix("weight",weight_var)

	end

	matrix list weight
	matrix colnames weight = w1 w2 w3 w4 

	svmat weight, names(col)


	** step 3: compute the index

	* Rescale weights to adjust for missing values

	local j=1
	while `j'<=4 {
	replace w`j'=. if var`j'==.
	local j=`j'+1
	}

	egen tot_w=rowtotal(w1 w2 w3 w4), missing

	local j=1
	while `j'<=4 {
	gen w`j'_res=w`j'/tot_w 
	local j=`j'+1
	}

	* Generate weighted variables

	local i=1
	while `i'<=4 {
	gen var`i'_w=var`i'*w`i'_res
	local i=`i'+1
	}

	* Generate final index

	egen index_z=rowtotal(var1_w var2_w var3_w var4_w), missing

	local i=1
	while `i'<=3 {
	sum index_z if group_final_2==0 & followup==`i'
	local index_z_m=r(mean)
	local index_z_sd=r(sd)
	replace index_z=((index_z-`index_z_m')/`index_z_sd') if followup==`i'
	local i=`i'+1
	}

	sum index_z

	drop var1 - var4_w


** Labor Market Index at Baseline 
* It excludes months worked in the last year as it is not measures at baseline

	** step 1: demean outcomes and divide by SD in the control group

	foreach var of varlist paid_emp_lastmonth_bl hours_worked_lastweek_bl earnings_lastmonth_def_bl {
	gen `var'_z=.

	local i=1
	while `i'<=3 {
	sum `var' if followup==`i'
	local `var'_m=r(mean)
	sum `var' if group_final_2==0 & followup==`i'
	local `var'_sd=r(sd)
	replace `var'_z=((`var'-``var'_m')/``var'_sd') if followup==`i'
	local i=`i'+1
	}

	}

	gen var1=paid_emp_lastmonth_bl_z
	gen var2=hours_worked_lastweek_bl_z
	gen var3=earnings_lastmonth_def_bl_z

	** step 2: calculate the var-cov matrix of the transformed outcomes and export the weight matrix 

	corr var1 var2 var3, covariance

	matrix list r(C)
	matrix varcov = r(C)


	* Generate matrix for the number of observations

	count
	matrix n = [r(N)]

	* Generate a matrix for the number of variables in the index

	matrix m = [3]


	mata:

	N = st_matrix("n")
	M = st_matrix("m")
	V = st_matrix("varcov")

	M
	N
	V

	V_inv=invsym(V)
	V_inv

	ones = J(M,1,1)
	ones

	W=V_inv * ones
	W


	weight_var=J(N,M,1)
	for (i=1; i<=M; i++) {
		weight_var[|1,i \ N,i|]=W[i,1]*weight_var[|1,i \ N,i|]
	}

	st_matrix("weight",weight_var)

	end

	matrix list weight
	matrix colnames weight = w1 w2 w3

	svmat weight, names(col)


	** step 3: compute the index

	* Rescale weights to adjust for missing values

	local j=1
	while `j'<=3 {
	replace w`j'=. if var`j'==.
	local j=`j'+1
	}

	egen tot_w=rowtotal(w1 w2 w3), missing

	local j=1
	while `j'<=3 {
	gen w`j'_res=w`j'/tot_w 
	local j=`j'+1
	}

	* Generate weighted variables

	local i=1
	while `i'<=3 {
	gen var`i'_w=var`i'*w`i'_res
	local i=`i'+1
	}

	* Generate final index

	egen index_z_bl=rowtotal(var1_w var2_w var3_w), missing

	local i=1
	while `i'<=3 {
	sum index_z_bl if group_final_2==0 & followup==`i'
	local index_z_bl_m=r(mean)
	local index_z_bl_sd=r(sd)
	replace index_z_bl=((index_z_bl-`index_z_bl_m')/`index_z_bl_sd') if followup==`i'
	local i=`i'+1
	}

	sum index_z_bl

	drop var1 - var3_w

** Strata and treatment dummies for Lee bounds
tab strata, gen(strata)

tab region_bl, gen(region_bl_)

gen treat2_1=1 if group_final_2_pooled==1
replace treat2_1=0 if group_final_2_pooled==0

gen treat2_4=1 if group_final_2_pooled==4
replace treat2_4=0 if group_final_2_pooled==0

gen VT=(group_final_2==1|group_final_2==2)
gen FT=(group_final_2==4)

keep if group_final_2_pooled!=.


**  Define globals for control variables
	
global X_bl "age_bl married_bl any_child_bl employed_bl score_high_bl"


** ii. Table **

* A9a) All

reg index_z FT VT index_z_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
gen s_index_z=e(sample)
sum index_z if group_final_2==0 & s_index_z==1
test FT=VT 

** lee bounds - pooled
leebounds index_z treat2_1, cie tight(strata2-strata20)
leebounds index_z treat2_4, cie tight(strata2-strata20)


* A9b) Female

sum index_z if group_final_2==0 & sex_bl==1 &s_index_z==1
reg index_z FT VT index_z_bl sfup tfup i.round_2 education_bl i.region_bl i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&sex_bl==1, robust
test FT=VT 

** lee bounds - pooled
leebounds index_z treat2_1 if sex_bl==1, cie tight(strata2-strata20)
leebounds index_z treat2_4 if sex_bl==1, cie tight(strata2-strata20)


** A9c) Male

sum index_z if group_final_2==0 & sex_bl==0&s_index_z==1
reg index_z FT VT index_z_bl sfup tfup i.round_2 education_bl i.region_bl i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&sex_bl==0, robust
test FT=VT 

** lee bounds - pooled
leebounds index_z treat2_1 if sex_bl==0, cie tight(strata2-strata20)
leebounds index_z treat2_4 if sex_bl==0, cie tight(strata2-strata20)


* A9d) Service sectors

*recode to make codes consistent with usual numbering
recode ideal_job_type_bl (1 = 1) (4 = 2) (8 = 3) (6 = 4) (7 = 5) (3 = 6) (2 = 7) (5 = 8)
label def sec 1 "motor-mechanics" 2 "plumbing" 3 "catering" 4 "tailoring" 5 "hairdressing" 6 "construction" 7 "electrical" 8 "welding"
label val ideal_job_type_bl sec
tab ideal_job_type_bl

gen sector_male   = (ideal_job_type_bl==1 | ideal_job_type_bl==2 | ideal_job_type_bl==6 | ideal_job_type_bl==7 | ideal_job_type_bl==8) if ideal_job_type_bl!=.
gen sector_female = (ideal_job_type_bl==3 | ideal_job_type_bl==4 | ideal_job_type_bl==5) if ideal_job_type_bl!=.

char group_final_2_pooled[omit]0 

sum index_z if group_final_2==0 & sector_female==1&s_index_z==1
reg index_z FT VT index_z_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&sector_female==1, robust
test FT=VT

** lee bounds - pooled
leebounds index_z treat2_1 if sector_female==1, cie tight(education_bl region_bl_2 - region_bl_5)
leebounds index_z treat2_4 if sector_female==1, cie tight(education_bl region_bl_2 - region_bl_5)


* A9e) Manufacturing sectors

sum index_z if group_final_2==0 & sector_male==1&s_index_z==1
reg index_z FT VT index_z_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&sector_male==1, robust
test FT=VT

** lee bounds - pooled

leebounds index_z treat2_1 if sector_male==1, cie tight(education_bl region_bl_2 - region_bl_5)
leebounds index_z treat2_4 if sector_male==1, cie tight(education_bl region_bl_2 - region_bl_5)


* A9f) Kampala vs. non-Kampala

gen     kampala=1 if region_num_bl==4
replace kampala=0 if kampala==.&region_num_bl!=.

*non-kampala
sum index_z if group_final_2==0&kampala==0&s_index_z==1
reg index_z FT VT index_z_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=.&kampala==0, robust
test FT=VT

** lee bounds - pooled
leebounds index_z treat2_1 if kampala==0, cie tight(strata2-strata20)
leebounds index_z treat2_4 if kampala==0, cie tight(strata2-strata20)


* A9g) Interaction with training rounds

*generate treatment dummies and interactions
gen VT_round_2=VT*round_2

sum index_z if group_final_2==0&s_index_z==1
reg index_z FT VT VT_round index_z_bl sfup tfup i.round_2 i.strata i.idate_mm ${X_bl} [pweight=invpr_panel_incl] if invpr_panel_incl!=., robust
test FT=VT


* A9h) IPW No Covariates

reg index_z FT VT index_z_bl sfup tfup i.round_2 i.strata i.idate_mm [pweight=invpr_panel_incl] if invpr_panel_incl!=.&s_index_z==1, robust
test FT=VT


* A9i) OLS No covariates

sum index_z if group_final_2_pooled==0&s_index_z==1
reg index_z FT VT index_z_bl sfup tfup i.round_2 i.strata i.idate_mm if invpr_panel_incl!=.&s_index_z==1, robust
test FT=VT
