% This function returns the log-likelihood of the simple BM model

% Missing values in the data are assumed to be coded as -1.

function y = BMlikelihood_ATE(x,d,output_type)

% expand parameter vector
del0     = x(1);
del1     = x(2);
del2     = x(3);
del3     = x(4);
del4     = x(5);
lam00    = x(6);
lam01    = x(7);
lam02    = x(8);
lam03    = x(9);
lam04    = x(10);
lam10    = x(11);
lam11    = x(12);
lam12    = x(13);
lam13    = x(14);
lam14    = x(15);

%generate treatment-specific parameters
del       = del0+del1.*d.treat_vt_nc+del2.*d.treat_vt_yc+del3.*d.treat_ft_nc+del4.*d.treat_ft_yc;
lam0      = lam00+lam01.*d.treat_vt_nc+lam02.*d.treat_vt_yc+lam03.*d.treat_ft_nc+lam04.*d.treat_ft_yc;
lam1      = lam10+lam11.*d.treat_vt_nc+lam12.*d.treat_vt_yc+lam13.*d.treat_ft_nc+lam14.*d.treat_ft_yc;

% useful auxiliary parameters...
% ... unemployment rate
urate = del./(del+lam0);
    
% ... sampling distribution
F = ones(d.n,1);
Fbar = ones(d.n,1);
for i=1:d.n
    F(i,1)       = (del(i)+lam1(i))*d.G(i,1)./(del(i)+lam1(i)*d.G(i,1));
    F(i,1)       = min(F(i,1),1-1e-10);  % this ensures that 1-F is never exactly zero, so we can take logs 
    Fbar(i,1)    = 1-F(i,1);
end


% construct the log-likelihood...
% ... contribution of unemployed workers:
for i=1:d.n
    y_u(i,1)     = -lam0(i)*d.spelldur1(i) + d.u2j(i)*log(lam0(i)) + log(urate(i)); 
end

% ... contribution of employed workers:
for i=1:d.n
    y_e(i,1)     = -(del(i)+lam1(i)*Fbar(i,1)).*d.spelldur1(i) + d.j2u(i)*log(del(i)) + d.j2j(i)*log(lam1(i)*Fbar(i,1)) + log(1-urate(i));
end

% ... collate, integrate epsilon out and sum (if requested)
y = ones(d.n,1);
for i=1:d.n 
    y(i) = ((1-d.e(i)).*y_u(i,1) + d.e(i).*y_e(i,1));
end

if strcmpi(output_type,'scalar')
    y       = sum(y);
end

% multiply by -1 as we are in fact minimizing minus the likelihood
y       = - y;

end