%% THIS DO FILE ESTIMATES THE JOB LADDER MODEL FOR ALFONSI ET AL. (2020) 
%  SEPARATING COMPLIERS AND NON-COMPLIERS

clear all

%setting path to directory - please personalize your directories here
cd 'C:\Users\uctpvit\Dropbox (BRAC-IFS)\Vocational Training Files\Worker Follow-ups\ECMA Review\Replication files\Submitted Files\Do-files\Structural Estimation Files'

%%%%%%%%%%%%%%%%%%%%%
%%% 1) ESTIMATION %%%
%%%%%%%%%%%%%%%%%%%%%

%% 1. LOAD DATA, PREPARE ARRAYS ETC.

% load data (for whole sample)
raw_dat         = load('StructuralData.raw','-ascii');

% generate number of observations
[n, n_var]=size(raw_dat);

% create a structure for the whole sample
dat.e                = raw_dat(:,1);
dat.r1               = raw_dat(:,2);
%dat.r1               = raw_dat(:,13); %low alpha
%dat.r1               = raw_dat(:,14); %high alpha
dat.G                = raw_dat(:,3);  
dat.j2j              = raw_dat(:,4);
dat.j2u              = raw_dat(:,5);
dat.u2j              = raw_dat(:,6);
dat.spelldur1	     = raw_dat(:,7);
dat.eps              = raw_dat(:,8);
%dat.eps              = raw_dat(:,15); %low alpha
%dat.eps              = raw_dat(:,16); %high alpha
dat.treat_vt_nc      = raw_dat(:,9);
dat.treat_vt_yc      = raw_dat(:,10);
dat.treat_ft_nc      = raw_dat(:,11);
dat.treat_ft_yc      = raw_dat(:,12);
dat.cognitive        = raw_dat(:,17);
dat.patience         = raw_dat(:,18);
dat.n                = n;

%% Table 6: Panel A: Parameter Estimates (Monthly)

%ROWS: epsilon, delta (mean and sderr), lambda0 (mean and sderr),
%lambda1 (mean and sderr)   
par_t = par_est_ATE(dat)';
par = par_t(1:7,:)

%create a matrix of parameter estimates 
xhat_t      = ones(3,5);
xhat_t(:,1) = par_t(8:10,1); %control
xhat_t(:,2) = par_t(8:10,3); %VT non-compliers
xhat_t(:,3) = par_t(8:10,5); %VT compliers
xhat_t(:,4) = par_t(8:10,2); %FT non-compliers
xhat_t(:,5) = par_t(8:10,4); %FT compliers

xhat   = [xhat_t(1,:) xhat_t(2,:) xhat_t(3,:)]';

%create a matrix of epsilon means
h_mean      = ones(1,5);
h_mean(:,1) = par(1,1); %control
h_mean(:,2) = par(1,3); %VT non-compliers
h_mean(:,3) = par(1,5); %VT compliers
h_mean(:,4) = par(1,2); %FT non-compliers
h_mean(:,5) = par(1,4); %FT compliers

clear xhat_t par_t

%% Table 6: Panel B: Competition for Workers and Unemployment

com      = ones(4,5);
com(1,:) = par(6,:)./par(2,:);
com(2,:) = par(2,:)./(par(2,:)+par(4,:));
com(3,:) = ones(1,5)./par(4,:);
com(4,:) = ones(1,5)./par(2,:)

%% Table 6: Panel C: Wages and Earnings

% obtain estimates of F and f
dist = dist_est_ATE(dat,xhat);

Fk      = dist(:,1);    
fk      = dist(:,2);    

% pdf of ACCEPTED piece-rates
% same piece-rate offer distribution across treatments
Gk      = ones(10000,5);
Gk(:,1) = Fk.*xhat(1)./(xhat(1) + xhat(11).*(1-Fk));
Gk(:,2) = Fk.*(xhat(1)+xhat(2)) ./(xhat(1)+xhat(2) + (xhat(11)+xhat(12)).*(1-Fk));
Gk(:,3) = Fk.*(xhat(1)+xhat(3)) ./(xhat(1)+xhat(3) + (xhat(11)+xhat(13)).*(1-Fk));
Gk(:,4) = Fk.*(xhat(1)+xhat(4)) ./(xhat(1)+xhat(4) + (xhat(11)+xhat(14)).*(1-Fk));
Gk(:,5) = Fk.*(xhat(1)+xhat(5)) ./(xhat(1)+xhat(5) + (xhat(11)+xhat(15)).*(1-Fk));

gk      = ones(10000,5);
gk(:,1) = fk.*((xhat(1) + xhat(11)*Gk(:,1)).^2)./(xhat(1)*(xhat(1) + xhat(11)));
gk(:,2) = fk.*((xhat(1)+xhat(2) + (xhat(11)+xhat(12))*Gk(:,2)).^2)./((xhat(1)+xhat(2))*(xhat(1)+xhat(2) + xhat(11)+xhat(12)));
gk(:,3) = fk.*((xhat(1)+xhat(3) + (xhat(11)+xhat(13))*Gk(:,3)).^2)./((xhat(1)+xhat(3))*(xhat(1)+xhat(3) + xhat(11)+xhat(13)));
gk(:,4) = fk.*((xhat(1)+xhat(4) + (xhat(11)+xhat(14))*Gk(:,4)).^2)./((xhat(1)+xhat(4))*(xhat(1)+xhat(4) + xhat(11)+xhat(14)));
gk(:,5) = fk.*((xhat(1)+xhat(5) + (xhat(11)+xhat(15))*Gk(:,5)).^2)./((xhat(1)+xhat(5))*(xhat(1)+xhat(5) + xhat(11)+xhat(15)));

% create scaling factors for the pdf
rx   = sort(dat.r1(dat.r1>0))
rx2  = linspace(min(rx),max(rx),10000)
step = ((max(rx2)-min(rx2))/length(rx2));

% pdf of OFFERED piece-rates
f_mean = rx2*step*fk;   % same offer distribution

% pdf of ACCEPTED piece-rates
g_mean      = ones(1,5);
for i=1:5
    g_mean(1,i) = rx2*step*gk(:,i);
end

% rearrange parameters to have them in the same order as the tables
fw_mean_t = f_mean.*h_mean; 
fw_mean   = ones(1,5);
fw_mean(1,1) = fw_mean_t(1,1);
fw_mean(1,2) = fw_mean_t(1,4);
fw_mean(1,3) = fw_mean_t(1,2);
fw_mean(1,4) = fw_mean_t(1,5);
fw_mean(1,5) = fw_mean_t(1,3)

gw_mean_t = g_mean.*h_mean;
gw_mean   = ones(1,5);
gw_mean(1,1) = gw_mean_t(1,1);
gw_mean(1,2) = gw_mean_t(1,4);
gw_mean(1,3) = gw_mean_t(1,2);
gw_mean(1,4) = gw_mean_t(1,5);
gw_mean(1,5) = gw_mean_t(1,3)

clear gk Gk i f_mean g_mean fw_mean_t gw_mean_t

%% Table A12: Estimates in the Job Ladder Search Model, with F(r|T)

f_mean_diff      = ones(1,5);
f_mean_diff(1,1) = rx2*step*dist(:,3);  % different offer distributions
f_mean_diff(1,2) = rx2*step*dist(:,4);
f_mean_diff(1,3) = rx2*step*dist(:,5);
f_mean_diff(1,4) = rx2*step*dist(:,6);
f_mean_diff(1,5) = rx2*step*dist(:,7);

rx_control = sort(dat.r1(dat.treat_vt_nc==0&dat.treat_vt_yc==0&dat.treat_ft_nc==0&dat.treat_ft_yc==0&dat.r1>0));
rx_vt_nc   = sort(dat.r1(dat.treat_vt_nc==1&dat.treat_vt_yc==0&dat.treat_ft_nc==0&dat.treat_ft_yc==0&dat.r1>0));
rx_vt_yc   = sort(dat.r1(dat.treat_vt_nc==0&dat.treat_vt_yc==1&dat.treat_ft_nc==0&dat.treat_ft_yc==0&dat.r1>0));
rx_ft_nc   = sort(dat.r1(dat.treat_vt_nc==0&dat.treat_vt_yc==0&dat.treat_ft_nc==1&dat.treat_ft_yc==0&dat.r1>0));
rx_ft_yc   = sort(dat.r1(dat.treat_vt_nc==0&dat.treat_vt_yc==0&dat.treat_ft_nc==0&dat.treat_ft_yc==1&dat.r1>0));

gk        = ones(5,10000);
gk(1,:)   = ksdensity(rx_control,rx2,'function', 'pdf','Support','positive');
gk(2,:)   = ksdensity(rx_vt_nc,rx2,'function', 'pdf','Support','positive');
gk(3,:)   = ksdensity(rx_vt_yc,rx2,'function', 'pdf','Support','positive');
gk(4,:)   = ksdensity(rx_ft_nc,rx2,'function', 'pdf','Support','positive');
gk(5,:)   = ksdensity(rx_ft_yc,rx2,'function', 'pdf','Support','positive');

g_mean_diff      = ones(1,5);
for i=1:5
    g_mean_diff(1,i) = rx2*step*gk(i,:)';
end

% rearrange parameters to have them in the same order as the tables
fw_mean_t = f_mean_diff.*h_mean; 
fw_mean_diff   = ones(1,5);
fw_mean_diff(1,1) = fw_mean_t(1,1);
fw_mean_diff(1,2) = fw_mean_t(1,4);
fw_mean_diff(1,3) = fw_mean_t(1,2);
fw_mean_diff(1,4) = fw_mean_t(1,5);
fw_mean_diff(1,5) = fw_mean_t(1,3)

gw_mean_t = g_mean_diff.*h_mean;
gw_mean_diff   = ones(1,5);
gw_mean_diff(1,1) = gw_mean_t(1,1);
gw_mean_diff(1,2) = gw_mean_t(1,4);
gw_mean_diff(1,3) = gw_mean_t(1,2);
gw_mean_diff(1,4) = gw_mean_t(1,5);
gw_mean_diff(1,5) = gw_mean_t(1,3)

clear gk rx_control rx_vt_nc rx_vt_yc rx_ft_nc rx_ft_yc f_mean_diff g_mean_diff fw_mean_t gw_mean_t


%%%%%%%%%%%%%%%%%%%%%%
%%% 2) SIMLULATION %%%
%%%%%%%%%%%%%%%%%%%%%%

%% SETTINGS 

% number of period for simulated panel [ 12 months * (number of years-1) ]
set.capT = 12*4;
% cross-section sample size...
set.nw   = 50000;
% number of treatment groups
set.nt   = 5;
% number of simulations
set.nsim = 50;

%% Table 8: Panel A: Baseline Levels

% treatment shares
pr.pr_vt_nc   = sum(dat.treat_vt_nc)./dat.n;
pr.pr_vt_yc   = sum(dat.treat_vt_yc)./dat.n;
pr.pr_ft_nc   = sum(dat.treat_ft_nc)./dat.n;
pr.pr_ft_yc   = sum(dat.treat_ft_yc)./dat.n;
pr.pr_control = 1-pr.pr_vt_nc-pr.pr_vt_yc-pr.pr_ft_nc-pr.pr_ft_yc;

% parameter estimates
pr.del0       = xhat(1);
pr.del1       = xhat(2);
pr.del2       = xhat(3);
pr.del3       = xhat(4);
pr.del4       = xhat(5);

pr.lam00      = xhat(6);
pr.lam01      = xhat(7);
pr.lam02      = xhat(8);
pr.lam03      = xhat(9);
pr.lam04      = xhat(10);

pr.lam10      = xhat(11);
pr.lam11      = xhat(12);
pr.lam12      = xhat(13);
pr.lam13      = xhat(14);
pr.lam14      = xhat(15);

pr.skills     = 1;
pr.hetero     = 0;

pr.supp_F     = rx2';
pr.F          = Fk;

% obtain treatment effects from simulation 
sim_bl = sim_est(dat,set,pr);

% Unemployment
sim_u_bl=ones(3,1);
sim_u_bl(1,1)=mean(sim_bl(1,:));
sim_u_bl(2,1)=mean(sim_bl(1,:)+sim_bl(5,:));
sim_u_bl(3,1)=mean(sim_bl(1,:)+sim_bl(3,:))

% Conditional Earnings
sim_wc_bl=ones(3,1);
sim_wc_bl(1,1)=mean(sim_bl(11,:));
sim_wc_bl(2,1)=mean(sim_bl(11,:)+sim_bl(15,:));
sim_wc_bl(3,1)=mean(sim_bl(11,:)+sim_bl(13,:))

% Unconditional Earnings
sim_w_bl=ones(3,1);
sim_w_bl(1,1)=mean(sim_bl(6,:));
sim_w_bl(2,1)=mean(sim_bl(6,:)+sim_bl(10,:));
sim_w_bl(3,1)=mean(sim_bl(6,:)+sim_bl(8,:))


%% Table 8: Panel B: FT=VT=Control

% Assess the impact of different parameters by shutting down differences
% and measuring change in impact with respect to baseline estimation

%% Different Arrival Rates

pr.del0       = xhat(1);
pr.del1       = xhat(2);
pr.del2       = xhat(3);
pr.del3       = xhat(4);
pr.del4       = xhat(5);

pr.lam00      = xhat(6);
pr.lam01      = 0;
pr.lam02      = 0;
pr.lam03      = 0;
pr.lam04      = 0;

pr.lam10      = xhat(11);
pr.lam11      = 0;
pr.lam12      = 0;
pr.lam13      = 0;
pr.lam14      = 0;

pr.skills     = 1;
pr.hetero     = 0;

% obtain treatment effects from simulation 
sim_cn1_arr = sim_est(dat,set,pr);

% Unemployment
cn1_arr=ones(2,3);
cn1_arr(1,1)=(mean(sim_bl(5,:))-mean(sim_cn1_arr(5,:)))/mean(sim_bl(5,:));
cn1_arr(2,1)=(mean(sim_bl(3,:))-mean(sim_cn1_arr(3,:)))/mean(sim_bl(3,:));

% Conditional Earnings
cn1_arr(1,2)=(mean(sim_bl(15,:))-mean(sim_cn1_arr(15,:)))/mean(sim_bl(15,:));
cn1_arr(2,2)=(mean(sim_bl(13,:))-mean(sim_cn1_arr(13,:)))/mean(sim_bl(13,:));

% Unconditional Earnings
cn1_arr(1,3)=(mean(sim_bl(10,:))-mean(sim_cn1_arr(10,:)))/mean(sim_bl(10,:));
cn1_arr(2,3)=(mean(sim_bl(8,:))-mean(sim_cn1_arr(8,:)))/mean(sim_bl(8,:))


%% Different Separation Rates

pr.del0       = xhat(1);
pr.del1       = 0;
pr.del2       = 0;
pr.del3       = 0;
pr.del4       = 0;

pr.lam00      = xhat(6);
pr.lam01      = xhat(7);
pr.lam02      = xhat(8);
pr.lam03      = xhat(9);
pr.lam04      = xhat(10);

pr.lam10      = xhat(11);
pr.lam11      = xhat(12);
pr.lam12      = xhat(13);
pr.lam13      = xhat(14);
pr.lam14      = xhat(15);

pr.skills     = 1;
pr.hetero     = 0;

% obtain treatment effects from simulation 
sim_cn1_sep = sim_est(dat,set,pr);

% Unemployment
cn1_sep=ones(2,3);
cn1_sep(1,1)=(mean(sim_bl(5,:))-mean(sim_cn1_sep(5,:)))/mean(sim_bl(5,:));
cn1_sep(2,1)=(mean(sim_bl(3,:))-mean(sim_cn1_sep(3,:)))/mean(sim_bl(3,:));

% Conditional Earnings
cn1_sep(1,2)=(mean(sim_bl(15,:))-mean(sim_cn1_sep(15,:)))/mean(sim_bl(15,:));
cn1_sep(2,2)=(mean(sim_bl(13,:))-mean(sim_cn1_sep(13,:)))/mean(sim_bl(13,:));

% Unconditional Earnings
cn1_sep(1,3)=(mean(sim_bl(10,:))-mean(sim_cn1_sep(10,:)))/mean(sim_bl(10,:));
cn1_sep(2,3)=(mean(sim_bl(8,:))-mean(sim_cn1_sep(8,:)))/mean(sim_bl(8,:))


%% Different Skills

pr.del0       = xhat(1);
pr.del1       = xhat(2);
pr.del2       = xhat(3);
pr.del3       = xhat(4);
pr.del4       = xhat(5);

pr.lam00      = xhat(6);
pr.lam01      = xhat(7);
pr.lam02      = xhat(8);
pr.lam03      = xhat(9);
pr.lam04      = xhat(10);

pr.lam10      = xhat(11);
pr.lam11      = xhat(12);
pr.lam12      = xhat(13);
pr.lam13      = xhat(14);
pr.lam14      = xhat(15);

pr.skills     = 2;
pr.hetero     = 0;

% obtain treatment effects from simulation 
sim_cn1_sk = sim_est(dat,set,pr);

% Unemployment
cn1_sk=ones(2,3);
cn1_sk(1,1)=(mean(sim_bl(5,:))-mean(sim_cn1_sk(5,:)))/mean(sim_bl(5,:));
cn1_sk(2,1)=(mean(sim_bl(3,:))-mean(sim_cn1_sk(3,:)))/mean(sim_bl(3,:));

% Conditional Earnings
cn1_sk(1,2)=(mean(sim_bl(15,:))-mean(sim_cn1_sk(15,:)))/mean(sim_bl(15,:));
cn1_sk(2,2)=(mean(sim_bl(13,:))-mean(sim_cn1_sk(13,:)))/mean(sim_bl(13,:));

% Unconditional Earnings
cn1_sk(1,3)=(mean(sim_bl(10,:))-mean(sim_cn1_sk(10,:)))/mean(sim_bl(10,:));
cn1_sk(2,3)=(mean(sim_bl(8,:))-mean(sim_cn1_sk(8,:)))/mean(sim_bl(8,:))


%% Table 8: Panel C: FT=VT

%% Different Arrival Rates

pr.del0       = xhat(1);
pr.del1       = xhat(2);
pr.del2       = xhat(3);
pr.del3       = xhat(4);
pr.del4       = xhat(5);

pr.lam00      = xhat(6);
pr.lam01      = xhat(7);
pr.lam02      = xhat(8);
pr.lam03      = xhat(7);   
pr.lam04      = xhat(8);  

pr.lam10      = xhat(11);
pr.lam11      = xhat(12);
pr.lam12      = xhat(13);
pr.lam13      = xhat(12);  
pr.lam14      = xhat(13);  

pr.skills     = 1;
pr.hetero     = 0;

% obtain treatment effects from simulation 
sim_cn2_arr = sim_est(dat,set,pr);

% Unemployment
cn2_arr=ones(1,2);
cn2_arr(1,1)=(mean(sim_cn2_arr(5,:))-mean(sim_bl(5,:)))/(mean(sim_bl(3,:))-mean(sim_bl(5,:)));

% Unconditional Earnings
cn2_arr(1,2)=(mean(sim_cn2_arr(10,:))-mean(sim_bl(10,:)))/(mean(sim_bl(8,:))-mean(sim_bl(10,:)))


%% Different Separation Rates

pr.del0       = xhat(1);
pr.del1       = xhat(2);
pr.del2       = xhat(3);
pr.del3       = xhat(2);   
pr.del4       = xhat(3);

pr.lam00      = xhat(6);
pr.lam01      = xhat(7);
pr.lam02      = xhat(8);
pr.lam03      = xhat(9);
pr.lam04      = xhat(10);

pr.lam10      = xhat(11);
pr.lam11      = xhat(12);
pr.lam12      = xhat(13);
pr.lam13      = xhat(14);
pr.lam14      = xhat(15);

pr.skills     = 1;
pr.hetero     = 0;

% obtain treatment effects from simulation 
sim_cn2_sep = sim_est(dat,set,pr);

% Unemployment
cn2_sep=ones(1,2);
cn2_sep(1,1)=(mean(sim_cn2_sep(5,:))-mean(sim_bl(5,:)))/(mean(sim_bl(3,:))-mean(sim_bl(5,:)));

% Unconditional Earnings
cn2_sep(1,2)=(mean(sim_cn2_sep(10,:))-mean(sim_bl(10,:)))/(mean(sim_bl(8,:))-mean(sim_bl(10,:)))


%% Different Skills

pr.del0       = xhat(1);
pr.del1       = xhat(2);
pr.del2       = xhat(3);
pr.del3       = xhat(4);
pr.del4       = xhat(5);

pr.lam00      = xhat(6);
pr.lam01      = xhat(7);
pr.lam02      = xhat(8);
pr.lam03      = xhat(9);
pr.lam04      = xhat(10);

pr.lam10      = xhat(11);
pr.lam11      = xhat(12);
pr.lam12      = xhat(13);
pr.lam13      = xhat(14);
pr.lam14      = xhat(15);

pr.skills     = 3;
pr.hetero     = 0;

% obtain treatment effects from simulation 
sim_cn2_sk = sim_est(dat,set,pr);

% Unemployment
cn2_sk=ones(1,2);
cn2_sk(1,1)=(mean(sim_cn2_sk(5,:))-mean(sim_bl(5,:)))/(mean(sim_bl(3,:))-mean(sim_bl(5,:)));

% Unconditional Earnings
cn2_sk(1,2)=(mean(sim_cn2_sk(10,:))-mean(sim_bl(10,:)))/(mean(sim_bl(8,:))-mean(sim_bl(10,:)))


%% Figure 4: Counterfactuals

% parameter estimates
pr.del0       = xhat(1);
pr.del1       = xhat(2);
pr.del2       = xhat(3);
pr.del3       = xhat(4);
pr.del4       = xhat(5);

pr.lam00      = xhat(6);
pr.lam01      = xhat(7);
pr.lam02      = xhat(8);
pr.lam03      = xhat(9);
pr.lam04      = xhat(10);

pr.lam10      = xhat(11);
pr.lam11      = xhat(12);
pr.lam12      = xhat(13);
pr.lam13      = xhat(14);
pr.lam14      = xhat(15);

pr.skills     = 1;

set.nsim      = 10;

%% Heterogeneity in Cognitive Skills
pr.hetero     = 1; 

% By decile
sim_cog = NaN(30,10,11);
j=0;
for i=0:0.1:1
    j=j+1;
    pr.share_h     = i;  
    sim_cog(:,:,j) = sim_est(dat,set,pr);    
end

cog_w  = NaN(11,3,2);
cog_wc = NaN(11,3,2);
for j=1:11
    
    %point estimate
    cog_w(j,2,1) = mean(sim_cog(10,:,j))/mean(sim_cog(6,:,j));
    cog_w(j,2,2) = mean(sim_cog(8,:,j))/mean(sim_cog(6,:,j));
    cog_wc(j,2,1) = mean(sim_cog(15,:,j))/mean(sim_cog(11,:,j));
    cog_wc(j,2,2) = mean(sim_cog(13,:,j))/mean(sim_cog(11,:,j));
    
    %lower bound CI
    cog_w(j,1,1) = cog_w(j,2,1) - mean(sim_cog(25,:,j))*norminv(.975)/mean(sim_cog(6,:,j));
    cog_w(j,1,2) = cog_w(j,2,2) - mean(sim_cog(23,:,j))*norminv(.975)/mean(sim_cog(6,:,j));
    cog_wc(j,1,1) = cog_wc(j,2,1) - mean(sim_cog(30,:,j))*norminv(.975)/mean(sim_cog(11,:,j));
    cog_wc(j,1,2) = cog_wc(j,2,2) - mean(sim_cog(28,:,j))*norminv(.975)/mean(sim_cog(11,:,j));

    %upper bound CI
    cog_w(j,3,1) = cog_w(j,2,1) + mean(sim_cog(25,:,j))*norminv(.975)/mean(sim_cog(6,:,j));
    cog_w(j,3,2) = cog_w(j,2,2) + mean(sim_cog(23,:,j))*norminv(.975)/mean(sim_cog(6,:,j));
    cog_wc(j,3,1) = cog_wc(j,2,1) + mean(sim_cog(30,:,j))*norminv(.975)/mean(sim_cog(11,:,j));
    cog_wc(j,3,2) = cog_wc(j,2,2) + mean(sim_cog(28,:,j))*norminv(.975)/mean(sim_cog(11,:,j));

end

%display results
cog_w
cog_wc


% Across different samples
sim_cog_s        = NaN(30,10,3);    

pr.share_h=.485; % employees sample
sim_cog_s(:,:,1) = sim_est(dat,set,pr);    

pr.share_h=.535; % our sample
sim_cog_s(:,:,2) = sim_est(dat,set,pr);    

pr.share_h=.598; % self-financed sample
sim_cog_s(:,:,3) = sim_est(dat,set,pr);    

cog_s_w  = NaN(3,2);
cog_s_wc = NaN(3,2);
for j=1:3
    %point estimate
    cog_s_w(j,1) = mean(sim_cog_s(10,:,j))/mean(sim_cog_s(6,:,j));
    cog_s_w(j,2) = mean(sim_cog_s(8,:,j))/mean(sim_cog_s(6,:,j));
    cog_s_wc(j,1) = mean(sim_cog_s(15,:,j))/mean(sim_cog_s(11,:,j));
    cog_s_wc(j,2) = mean(sim_cog_s(13,:,j))/mean(sim_cog_s(11,:,j));
end

%display results
cog_s_w
cog_s_wc


%% Heterogeneity in Patience
pr.hetero     = 2; 

% By decile
sim_pat = NaN(30,10,11);
j=0;
for i=0:0.1:1
    j=j+1;
    pr.share_h     = i;  
    sim_pat(:,:,j) = sim_est(dat,set,pr);    
end

pat_w  = NaN(11,3,2);
pat_wc = NaN(11,3,2);
for j=1:11
    
    %point estimate
    pat_w(j,2,1) = mean(sim_pat(10,:,j))/mean(sim_pat(6,:,j));
    pat_w(j,2,2) = mean(sim_pat(8,:,j))/mean(sim_pat(6,:,j));
    pat_wc(j,2,1) = mean(sim_pat(15,:,j))/mean(sim_pat(11,:,j));
    pat_wc(j,2,2) = mean(sim_pat(13,:,j))/mean(sim_pat(11,:,j));
    
    %lower bound CI
    pat_w(j,1,1) = pat_w(j,2,1) - mean(sim_pat(25,:,j))*norminv(.975)/mean(sim_pat(6,:,j));
    pat_w(j,1,2) = pat_w(j,2,2) - mean(sim_pat(23,:,j))*norminv(.975)/mean(sim_pat(6,:,j));
    pat_wc(j,1,1) = pat_wc(j,2,1) - mean(sim_pat(30,:,j))*norminv(.975)/mean(sim_pat(11,:,j));
    pat_wc(j,1,2) = pat_wc(j,2,2) - mean(sim_pat(28,:,j))*norminv(.975)/mean(sim_pat(11,:,j));

    %upper bound CI
    pat_w(j,3,1) = pat_w(j,2,1) + mean(sim_pat(25,:,j))*norminv(.975)/mean(sim_pat(6,:,j));
    pat_w(j,3,2) = pat_w(j,2,2) + mean(sim_pat(23,:,j))*norminv(.975)/mean(sim_pat(6,:,j));
    pat_wc(j,3,1) = pat_wc(j,2,1) + mean(sim_pat(30,:,j))*norminv(.975)/mean(sim_pat(11,:,j));
    pat_wc(j,3,2) = pat_wc(j,2,2) + mean(sim_pat(28,:,j))*norminv(.975)/mean(sim_pat(11,:,j));

end

%display results
pat_w
pat_wc

% Across different samples
pr.share_h=.4829; % our sample
sim_pat_s  = sim_est(dat,set,pr);    

pat_s_w  = NaN(1,2);
pat_s_wc = NaN(1,2);

%point estimate
pat_s_w(1,1) = mean(sim_pat_s(10,:))/mean(sim_pat_s(6,:));
pat_s_w(1,2) = mean(sim_pat_s(8,:))/mean(sim_pat_s(6,:));
pat_s_wc(1,1) = mean(sim_pat_s(15,:))/mean(sim_pat_s(11,:));
pat_s_wc(1,2) = mean(sim_pat_s(13,:))/mean(sim_pat_s(11,:));

%display results
pat_s_w
pat_s_wc
