%% THIS DO FILE ESTIMATES THE JOB LADDER MODEL FOR ALFONSI ET AL. (2020) 
%  POOLING COMPLIERS AND NON-COMPLIERS

clear all

%setting path to directory - please personalize your directories here
cd 'C:\Users\uctpvit\Dropbox (BRAC-IFS)\Vocational Training Files\Worker Follow-ups\ECMA Review\Replication files\Submitted Files\Do-files\Structural Estimation Files'

%%%%%%%%%%%%%%%%%%%%%
%%% 1) ESTIMATION %%%
%%%%%%%%%%%%%%%%%%%%%

%% 1. LOAD DATA, PREPARE ARRAYS ETC.

% load data (for whole sample)
raw_dat         = load('StructuralData.raw','-ascii');

% generate number of observations
[n, n_var]=size(raw_dat);

% create a structure for the whole sample
dat.e                = raw_dat(:,1);
dat.r1               = raw_dat(:,2);
dat.G                = raw_dat(:,19);  
dat.j2j              = raw_dat(:,4);
dat.j2u              = raw_dat(:,5);
dat.u2j              = raw_dat(:,6);
dat.spelldur1	     = raw_dat(:,7);
dat.eps              = raw_dat(:,8);
dat.treat_vt         = raw_dat(:,20);
dat.treat_ft         = raw_dat(:,21);
dat.n                = n;

%% Table A14: Panel A: Parameter Estimates (Monthly)

%ROWS: epsilon, delta (mean and sderr), lambda0 (mean and sderr),
%lambda1 (mean and sderr)   
par_t = par_est_ITT(dat)';
par = par_t(1:7,:)

%create a matrix of parameter estimates 
xhat_t      = ones(3,3);
xhat_t(:,1) = par_t(8:10,1); %control
xhat_t(:,2) = par_t(8:10,3); %VT 
xhat_t(:,3) = par_t(8:10,2); %FT

xhat   = [xhat_t(1,:) xhat_t(2,:) xhat_t(3,:)]';

%create a matrix of epsilon means
h_mean      = ones(1,3);
h_mean(:,1) = par(1,1); %control
h_mean(:,2) = par(1,3); %VT 
h_mean(:,3) = par(1,2); %FT

clear xhat_t par_t

%% Table A14: Panel B: Competition for Workers and Unemployment

com      = ones(4,3);
com(1,:) = par(6,:)./par(2,:);
com(2,:) = par(2,:)./(par(2,:)+par(4,:));
com(3,:) = ones(1,3)./par(4,:);
com(4,:) = ones(1,3)./par(2,:)

%% Table A14: Panel C: Wages and Earnings

% obtain estimates of F and f
dist = dist_est_ITT(dat,xhat);

Fk      = dist(:,1);    
fk      = dist(:,2);    

% pdf of ACCEPTED piece-rates
% same piece-rate offer distribution across treatments
Gk      = ones(10000,3);
Gk(:,1) = Fk.*xhat(1)./(xhat(1) + xhat(7).*(1-Fk));
Gk(:,2) = Fk.*(xhat(1)+xhat(2)) ./(xhat(1)+xhat(2) + (xhat(7)+xhat(8)).*(1-Fk));
Gk(:,3) = Fk.*(xhat(1)+xhat(3)) ./(xhat(1)+xhat(3) + (xhat(7)+xhat(9)).*(1-Fk));

gk      = ones(10000,3);
gk(:,1) = fk.*((xhat(1) + xhat(7)*Gk(:,1)).^2)./(xhat(1)*(xhat(1) + xhat(7)));
gk(:,2) = fk.*((xhat(1)+xhat(2) + (xhat(7)+xhat(8))*Gk(:,2)).^2)./((xhat(1)+xhat(2))*(xhat(1)+xhat(2) + xhat(7)+xhat(8)));
gk(:,3) = fk.*((xhat(1)+xhat(3) + (xhat(7)+xhat(9))*Gk(:,3)).^2)./((xhat(1)+xhat(3))*(xhat(1)+xhat(3) + xhat(7)+xhat(9)));

% create scaling factors for the pdf
rx   = sort(dat.r1(dat.r1>0));
rx2  = linspace(min(rx),max(rx),10000);
step = ((max(rx2)-min(rx2))/length(rx2));

% pdf of OFFERED piece-rates
f_mean = rx2*step*fk;   % same offer distribution

% pdf of ACCEPTED piece-rates
g_mean      = ones(1,3);
for i=1:3
    g_mean(1,i) = rx2*step*gk(:,i);
end

% rearrange parameters to have them in the same order as the tables
fw_mean_t = f_mean.*h_mean; 
fw_mean   = ones(1,3);
fw_mean(1,1) = fw_mean_t(1,1);
fw_mean(1,2) = fw_mean_t(1,3);
fw_mean(1,3) = fw_mean_t(1,2)

gw_mean_t = g_mean.*h_mean;
gw_mean   = ones(1,3);
gw_mean(1,1) = gw_mean_t(1,1);
gw_mean(1,2) = gw_mean_t(1,3);
gw_mean(1,3) = gw_mean_t(1,2)

clear gk Gk i f_mean g_mean fw_mean_t gw_mean_t
