% This function returns an Estimate of the OFFERED and ACCEPTED piece-rate
% distributions

function dist = dist_est_ATE(d,x)

    %% GENERATE DISTRIBUTIONS

    % sort wages, by treatment 
    rx         = sort(d.r1(d.r1>0));
    rx_control = sort(d.r1(d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.r1>0));
    rx_vt_nc   = sort(d.r1(d.treat_vt_nc==1&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.r1>0));
    rx_vt_yc   = sort(d.r1(d.treat_vt_nc==0&d.treat_vt_yc==1&d.treat_ft_nc==0&d.treat_ft_yc==0&d.r1>0));
    rx_ft_nc   = sort(d.r1(d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==1&d.treat_ft_yc==0&d.r1>0));
    rx_ft_yc   = sort(d.r1(d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==1&d.r1>0));

    % create the support to then be able to calculate means and SD
    rx2         = linspace(min(rx),max(rx),10000);

    % create g pdf and G CDF for all groups
    gk_control   = ksdensity(rx_control,rx2,'function', 'pdf','Support','positive');
    gk_vt_nc     = ksdensity(rx_vt_nc,rx2,'function', 'pdf','Support','positive');
    gk_vt_yc     = ksdensity(rx_vt_yc,rx2,'function', 'pdf','Support','positive');
    gk_ft_nc     = ksdensity(rx_ft_nc,rx2,'function', 'pdf','Support','positive');
    gk_ft_yc     = ksdensity(rx_ft_yc,rx2,'function', 'pdf','Support','positive');

    Gk_control = ksdensity(rx_control,rx2,'function','cdf','Support','positive');
    Gk_vt_nc   = ksdensity(rx_vt_nc,rx2,'function','cdf','Support','positive');
    Gk_vt_yc   = ksdensity(rx_vt_yc,rx2,'function','cdf','Support','positive');
    Gk_ft_nc   = ksdensity(rx_ft_nc,rx2,'function','cdf','Support','positive');
    Gk_ft_yc   = ksdensity(rx_ft_yc,rx2,'function','cdf','Support','positive');

    % compute f pdf and F cdf for all groups, inverting g and G
    fk_control = x(1)*(x(1) + x(11))*gk_control./((x(1) + x(11)*Gk_control).^2);
    fk_vt_nc   = (x(1)+x(2))*(x(1)+x(2) + x(11)+x(12))*gk_vt_nc./((x(1)+x(2) + (x(11)+x(12))*Gk_vt_nc).^2);
    fk_vt_yc   = (x(1)+x(3))*(x(1)+x(3) + x(11)+x(13))*gk_vt_yc./((x(1)+x(3) + (x(11)+x(13))*Gk_vt_yc).^2);
    fk_ft_nc   = (x(1)+x(4))*(x(1)+x(4) + x(11)+x(14))*gk_ft_nc./((x(1)+x(4) + (x(11)+x(14))*Gk_ft_nc).^2);
    fk_ft_yc   = (x(1)+x(5))*(x(1)+x(5) + x(11)+x(15))*gk_ft_yc./((x(1)+x(5) + (x(11)+x(15))*Gk_ft_yc).^2);

    Fk_control = (x(1)+x(11))*Gk_control./(x(1)+x(11)*Gk_control);
    Fk_vt_nc   = (x(1)+x(2) + x(11)+x(12))*Gk_vt_nc./(x(1)+x(2) + (x(11)+x(12))*Gk_vt_nc);
    Fk_vt_yc   = (x(1)+x(3) + x(11)+x(13))*Gk_vt_yc./(x(1)+x(3) + (x(11)+x(13))*Gk_vt_yc);
    Fk_ft_nc   = (x(1)+x(4) + x(11)+x(14))*Gk_ft_nc./(x(1)+x(4) + (x(11)+x(14))*Gk_ft_nc);
    Fk_ft_yc   = (x(1)+x(5) + x(11)+x(15))*Gk_ft_yc./(x(1)+x(5) + (x(11)+x(15))*Gk_ft_yc);

    % generate a unique F for all treatment (assume differences are driven by
    % sampling error)
    Fk_all_p       = repmat(linspace(1,10000,10000)',1,5);                          

    Fk_all         = ones(10000,5);                          
    Fk_all(:,1)    = Fk_control(Fk_all_p(:,1)); %corresponding values of the F|T distribution
    Fk_all(:,2)    = Fk_vt_nc(Fk_all_p(:,2));
    Fk_all(:,3)    = Fk_vt_yc(Fk_all_p(:,3));
    Fk_all(:,4)    = Fk_ft_nc(Fk_all_p(:,4));
    Fk_all(:,5)    = Fk_ft_yc(Fk_all_p(:,5));

    fk_all         = ones(10000,5);                       
    fk_all(:,1)    = fk_control(Fk_all_p(:,1)); %corresponding values of the f|T distribution
    fk_all(:,2)    = fk_vt_nc(Fk_all_p(:,2));
    fk_all(:,3)    = fk_vt_yc(Fk_all_p(:,3));
    fk_all(:,4)    = fk_ft_nc(Fk_all_p(:,4));
    fk_all(:,5)    = fk_ft_yc(Fk_all_p(:,5));

    pr_vt_nc       = sum(d.treat_vt_nc)./d.n;
    pr_vt_yc       = sum(d.treat_vt_yc)./d.n;
    pr_ft_nc       = sum(d.treat_ft_nc)./d.n;
    pr_ft_yc       = sum(d.treat_ft_yc)./d.n;
    pr_control     = 1-pr_vt_nc-pr_vt_yc-pr_ft_nc-pr_ft_yc;
    pr             = [pr_control, pr_vt_nc, pr_vt_yc, pr_ft_nc, pr_ft_yc];

    Fk             = Fk_all*pr';
    Fk(1,1)        = 0;

    fk             = fk_all*pr';
    fk(1,1)        = 0;
    
    %% OUTPUT
    
    dist      = ones(10000,7);
    dist(:,1) = Fk;
    dist(:,2) = fk;
    dist(:,3) = fk_control;
    dist(:,4) = fk_vt_nc;
    dist(:,5) = fk_vt_yc;
    dist(:,6) = fk_ft_nc;
    dist(:,7) = fk_ft_yc;

end