% This function returns an Estimate of the OFFERED and ACCEPTED piece-rate
% distributions

function dist = dist_est_ATE(d,x)

    %% GENERATE DISTRIBUTIONS

    % sort wages, by treatment 
    rx         = sort(d.r1(d.r1>0));
    rx_control = sort(d.r1(d.treat_vt==0&d.treat_ft==0&d.r1>0));
    rx_vt      = sort(d.r1(d.treat_vt==1&d.treat_ft==0&d.r1>0));
    rx_ft      = sort(d.r1(d.treat_vt==0&d.treat_ft==1&d.r1>0));

    % create the support to then be able to calculate means and SD
    rx2         = linspace(min(rx),max(rx),10000);

    % create g pdf and G CDF for all groups
    gk_control   = ksdensity(rx_control,rx2,'function', 'pdf','Support','positive');
    gk_vt        = ksdensity(rx_vt,rx2,'function', 'pdf','Support','positive');
    gk_ft        = ksdensity(rx_ft,rx2,'function', 'pdf','Support','positive');

    Gk_control = ksdensity(rx_control,rx2,'function','cdf','Support','positive');
    Gk_vt      = ksdensity(rx_vt,rx2,'function','cdf','Support','positive');
    Gk_ft      = ksdensity(rx_ft,rx2,'function','cdf','Support','positive');

    % compute f pdf and F cdf for all groups, inverting g and G
    fk_control = x(1)*(x(1) + x(7))*gk_control./((x(1) + x(7)*Gk_control).^2);
    fk_vt      = (x(1)+x(2))*(x(1)+x(2) + x(7)+x(8))*gk_vt./((x(1)+x(2) + (x(7)+x(8))*Gk_vt).^2);
    fk_ft      = (x(1)+x(3))*(x(1)+x(3) + x(7)+x(9))*gk_ft./((x(1)+x(3) + (x(7)+x(9))*Gk_ft).^2);

    Fk_control = (x(1)+x(7))*Gk_control./(x(1)+x(7)*Gk_control);
    Fk_vt      = (x(1)+x(2) + x(7)+x(8))*Gk_vt./(x(1)+x(2) + (x(7)+x(8))*Gk_vt);
    Fk_ft      = (x(1)+x(3) + x(7)+x(9))*Gk_ft./(x(1)+x(3) + (x(7)+x(9))*Gk_ft);

    % generate a unique F for all treatment (assume differences are driven by
    % sampling error)
    Fk_all_p       = repmat(linspace(1,10000,10000)',1,3);                          

    Fk_all         = ones(10000,3);                          %corresponding values of the F|T distribution
    Fk_all(:,1)    = Fk_control(Fk_all_p(:,1));
    Fk_all(:,2)    = Fk_vt(Fk_all_p(:,2));
    Fk_all(:,3)    = Fk_ft(Fk_all_p(:,3));

    fk_all         = ones(10000,3);                          %corresponding values of the f|T distribution
    fk_all(:,1)    = fk_control(Fk_all_p(:,1));
    fk_all(:,2)    = fk_vt(Fk_all_p(:,2));
    fk_all(:,3)    = fk_ft(Fk_all_p(:,3));

    pr_vt       = sum(d.treat_vt)./d.n;
    pr_ft       = sum(d.treat_ft)./d.n;
    pr_control  = 1-pr_vt-pr_ft;
    pr             = [pr_control, pr_vt, pr_ft];

    Fk             = Fk_all*pr';
    Fk(1,1)        = 0;

    fk             = fk_all*pr';
    fk(1,1)        = 0;
    
    %% OUTPUT
    
    dist      = ones(10000,5);
    dist(:,1) = Fk;
    dist(:,2) = fk;
    dist(:,3) = fk_control;
    dist(:,4) = fk_vt;
    dist(:,5) = fk_ft;

end