% This function returns the Treatment Effects on Simulated Data

function sim = sim_est(d,s,p)

    % set the seed
    seed = 29111998;
    RandStream.setGlobalStream(RandStream('CombRecursive','Seed',seed));
    
    % generate empty matrices to be filled with treatment effects
    %treat_effect_ATE=zeros(15,50);  % 15 estimates, 10 simulations
    %treat_sd_ATE=zeros(15,50);  % 15 estimates, 10 simulations

    j=1;
    while j <=s.nsim

    % allocate memory
    [ s.e,        ...
      s.j,        ...
      s.j2j,      ...
      s.u2e,      ...
      s.e2u,      ...
      s.ten,      ...
      ]                         = deal(zeros(s.nw,s.capT));


    %% SIMULATE THE ECONOMY MANY TIMES 

        % SIMULATE FIRST PERIOD

        % treatment status
        dice                      = rand(s.nw,1);
        s.treat                   = zeros(s.nw,s.nt);
        s.treat(:,1)              = (dice<p.pr_control);
        s.treat(:,2)              = (dice>=p.pr_control&dice<(p.pr_control+p.pr_vt_nc));
        s.treat(:,3)              = (dice>=(p.pr_control+p.pr_vt_nc)&dice<(p.pr_control+p.pr_vt_nc+p.pr_vt_yc));
        s.treat(:,4)              = (dice>=(p.pr_control+p.pr_vt_nc+p.pr_vt_yc)&dice<(p.pr_control+p.pr_vt_nc+p.pr_vt_yc+p.pr_ft_nc));
        s.treat(:,5)              = (dice>=(p.pr_control+p.pr_vt_nc+p.pr_vt_yc+p.pr_ft_nc));

        % employment status
        urate                       = ones(1,s.nt);
        urate(1,1)                  = p.del0/(p.del0+p.lam00);
        urate(1,2)                  = (p.del0+p.del1)/(p.del0+p.del1 + p.lam00+p.lam01);
        urate(1,3)                  = (p.del0+p.del2)/(p.del0+p.del2 + p.lam00+p.lam02);
        urate(1,4)                  = (p.del0+p.del3)/(p.del0+p.del3 + p.lam00+p.lam03);
        urate(1,5)                  = (p.del0+p.del4)/(p.del0+p.del4 + p.lam00+p.lam04);

        dice                        = rand(s.nw,1);                                                                   
        s.e(:,1)                  = (s.treat(:,1)).*(dice>=urate(1,1))+(s.treat(:,2)).*(dice>=urate(1,2)) + ...
                                      (s.treat(:,3)).*(dice>=urate(1,3))+(s.treat(:,4)).*(dice>=urate(1,4)) + ...
                                      (s.treat(:,5)).*(dice>=urate(1,5));                             
        % r
        dice                        = rand(s.nw,1);                                                                   
        dice_Fr                     = (s.treat(:,1)).*(p.del0 + p.lam10).*dice./(p.del0 + p.lam10.*dice) + ...
                                      (s.treat(:,2)).*(p.del0+p.del1 + p.lam10+p.lam11).*dice./(p.del0+p.del1 + (p.lam10+p.lam11).*dice) + ...
                                      (s.treat(:,3)).*(p.del0+p.del2 + p.lam10+p.lam12).*dice./(p.del0+p.del2 + (p.lam10+p.lam12).*dice) + ...
                                      (s.treat(:,4)).*(p.del0+p.del3 + p.lam10+p.lam13).*dice./(p.del0+p.del3 + (p.lam10+p.lam13).*dice) + ...
                                      (s.treat(:,5)).*(p.del0+p.del4 + p.lam10+p.lam14).*dice./(p.del0+p.del4 + (p.lam10+p.lam14).*dice);                         % draw from F(r)

        s.r(:,1)                  = knnsearch(p.F,dice_Fr);        % draw from same offer distribution, corresponding rank in F
        s.r(:,1)                  = s.e(:,1).*s.r(:,1);

        % tenure: exponential distribution with intensity p.delta+p.lam1*(1-dice_F(r))
        s.ten(:,1)                = rand(s.nw,1);
        s.jten(:,1)               = (s.treat(:,1)).*(-log(s.ten(:,1))./(p.del0+p.lam10*(1-dice_Fr))) + ...
                                      (s.treat(:,2)).*(-log(s.ten(:,1))./(p.del0+p.del1+(p.lam10+p.lam11)*(1-dice_Fr))) + ...
                                      (s.treat(:,3)).*(-log(s.ten(:,1))./(p.del0+p.del2+(p.lam10+p.lam12)*(1-dice_Fr))) + ...
                                      (s.treat(:,4)).*(-log(s.ten(:,1))./(p.del0+p.del3+(p.lam10+p.lam13)*(1-dice_Fr))) + ...
                                      (s.treat(:,5)).*(-log(s.ten(:,1))./(p.del0+p.del4+(p.lam10+p.lam14)*(1-dice_Fr)));
        s.uten(:,1)               = (s.treat(:,1)).*(-log(s.ten(:,1))./(p.lam00)) + ...
                                      (s.treat(:,2)).*(-log(s.ten(:,1))./(p.lam00+p.lam01)) + ...
                                      (s.treat(:,3)).*(-log(s.ten(:,1))./(p.lam00+p.lam02)) + ...
                                      (s.treat(:,4)).*(-log(s.ten(:,1))./(p.lam00+p.lam03)) + ...
                                      (s.treat(:,5)).*(-log(s.ten(:,1))./(p.lam00+p.lam04));
        s.ten(:,1)                = floor(s.jten(:,1).*s.e(:,1)+s.uten(:,1).*(1-s.e(:,1)))

        %% MAIN SIMULATION

        t = 2;

        while t <= s.capT
            
            % OVERHEAD

            % event indicators:
            % ... unemployed job offer
            dice                    = rand(s.nw,1);
            u_offer                 = ((s.treat(:,1)).*(dice < p.lam00) + ...
                                      (s.treat(:,2)).*(dice < (p.lam00+p.lam01)) + ...
                                      (s.treat(:,3)).*(dice < (p.lam00+p.lam02)) + ...
                                      (s.treat(:,4)).*(dice < (p.lam00+p.lam03)) + ...
                                      (s.treat(:,5)).*(dice < (p.lam00+p.lam04))).*(1-s.e(:,t-1));

            % ... employed job offer or layoff
            dice                    = rand(s.nw,1);
            e_offer                 = ((s.treat(:,1)).*(dice < p.lam10) + ... 
                                      (s.treat(:,2)).*(dice < (p.lam10+p.lam11)) + ...
                                      (s.treat(:,3)).*(dice < (p.lam10+p.lam12)) + ...
                                      (s.treat(:,4)).*(dice < (p.lam10+p.lam13)) + ...
                                      (s.treat(:,5)).*(dice < (p.lam10+p.lam14))).*s.e(:,t-1);
            e_to_u                  = ((s.treat(:,1)).*(dice >= p.lam10).*(dice < p.lam10 + p.del0) + ...
                                      (s.treat(:,2)).*(dice >= (p.lam10+p.lam11)).*(dice < p.lam10+p.lam11 + p.del0+p.del1) + ...
                                      (s.treat(:,3)).*(dice >= (p.lam10+p.lam12)).*(dice < p.lam10+p.lam12 + p.del0+p.del2) + ...
                                      (s.treat(:,4)).*(dice >= (p.lam10+p.lam13)).*(dice < p.lam10+p.lam13 + p.del0+p.del3) + ...
                                      (s.treat(:,5)).*(dice >= (p.lam10+p.lam14)).*(dice < p.lam10+p.lam14 + p.del0+p.del4)).*s.e(:,t-1);
            e_to_u                  = (e_to_u>0);   % converts to logical for later use as index

            % ... draw of potential new y and calculate potential surplus
            jr                      = deal(zeros(s.nw,1));
            any_offer               = (e_offer + u_offer == 1);
            dice                    = rand(s.nw,1);
            jr                      = bsxfun(@eq,any_offer,1).*knnsearch(p.F,dice);       % get a random offer from the SAME distribution of F(r)

            % UPDATE WORKER STATES

            % unemployed hire
            u_to_e                  = u_offer>0;
            s.e(u_to_e,t)         = 1;
            s.r(u_to_e,t)         = jr(u_to_e);                   % assign value of offer for unemployed who received an offer
            s.u2e(u_to_e,t)       = 1;

            % ... unemployed stay put
            u_stay                  = (1-s.e(:,t-1)).*(1-u_to_e)>0;
            s.e(u_stay,t)         = 0;
            s.r(u_stay,t)         = s.r(u_stay,t-1);
            s.ten(u_stay,t)      = s.ten(u_stay,t-1)+1;

            % ... employed layoff
            s.r(e_to_u,t)         = 0;
            s.e2u(e_to_u,t)       = 1;
            s.ten(e_to_u,t)       = 0;

            % ... employed accepted offer
            e_to_e                  = e_offer.*(jr>s.r(:,t-1))>0;     % employed received an offer higher than current one
            s.e(e_to_e,t)         = 1;
            s.r(e_to_e,t)         = jr(e_to_e);
            s.j2j(e_to_e,t)       = 1;
            s.ten(e_to_e,t)       = 0;

            % ... employed stay put
            e_stay                  = s.e(:,t-1).*(1-e_to_e).*(1-e_to_u)>0;
            s.e(e_stay,t)         = 1;
            s.r(e_stay,t)         = s.r(e_stay,t-1);
            s.ten(e_stay,t)       = s.ten(e_stay,t-1)+1;

            % move on to next period
            t                       = t+1;
            
        end

        %% CONSTRUCT WAGES

        % Generate random draws for ability
        
        if p.hetero==0
            
            %Uniform random numbers
              u = rand(s.nw,1);
            %PDF
              pd_control = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0),'kernel','Support','positive');
              pd_vt_nc   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==1&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0),'kernel','Support','positive');
              pd_vt_yc   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==1&d.treat_ft_nc==0&d.treat_ft_yc==0),'kernel','Support','positive');
              pd_ft_nc   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==1&d.treat_ft_yc==0),'kernel','Support','positive');
              pd_ft_yc   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==1),'kernel','Support','positive');      
            %Inversion
              eps_control = icdf(pd_control,u);
              eps_vt_nc   = icdf(pd_vt_nc,u);
              eps_vt_yc   = icdf(pd_vt_yc,u);
              eps_ft_nc   = icdf(pd_ft_nc,u);
              eps_ft_yc   = icdf(pd_ft_yc,u);

            if     p.skills==1
                s.eps     = s.treat(:,1).*eps_control+s.treat(:,2).*eps_vt_nc+s.treat(:,3).*eps_vt_yc + ...
                            s.treat(:,4).*eps_ft_nc+s.treat(:,5).*eps_ft_yc;
            elseif p.skills==2
                s.eps     = eps_control; % COUNTERFACTUAL: same ability across treatments and control       
            else
                s.eps     = s.treat(:,1).*eps_control+s.treat(:,2).*eps_vt_nc+s.treat(:,3).*eps_vt_yc + ...
                            s.treat(:,4).*eps_vt_nc+s.treat(:,5).*eps_vt_yc;  % COUNTERFACTUAL: same ability across VT and FT
            end
           
        elseif p.hetero==1
            
        % COUNTERFACTUAL 4: cognitive skills / patience status
        % 1) Cognitive Skills
        dice                        = rand(s.nw,1);
        s.cognitive                 = (dice<p.share_h);

        %Uniform random numbers
          u = rand(s.nw,1);
        %PDF
          pd_control_cogH = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.cognitive==1),'kernel','Support','positive');
          pd_control_cogL = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.cognitive==0),'kernel','Support','positive');
          pd_vt_nc_cogH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==1&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.cognitive==1),'kernel','Support','positive');
          pd_vt_nc_cogL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==1&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.cognitive==0),'kernel','Support','positive');
          pd_vt_yc_cogH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==1&d.treat_ft_nc==0&d.treat_ft_yc==0&d.cognitive==1),'kernel','Support','positive');
          pd_vt_yc_cogL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==1&d.treat_ft_nc==0&d.treat_ft_yc==0&d.cognitive==0),'kernel','Support','positive');
          pd_ft_nc_cogH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==1&d.treat_ft_yc==0&d.cognitive==1),'kernel','Support','positive');
          pd_ft_nc_cogL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==1&d.treat_ft_yc==0&d.cognitive==0),'kernel','Support','positive');
          pd_ft_yc_cogH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==1&d.cognitive==1),'kernel','Support','positive');      
          pd_ft_yc_cogL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==1&d.cognitive==0),'kernel','Support','positive');      
        %Inversion
          eps_control_cogH = icdf(pd_control_cogH,u);
          eps_control_cogL = icdf(pd_control_cogL,u);
          eps_vt_nc_cogH   = icdf(pd_vt_nc_cogH,u);
          eps_vt_nc_cogL   = icdf(pd_vt_nc_cogL,u);
          eps_vt_yc_cogH   = icdf(pd_vt_yc_cogH,u);
          eps_vt_yc_cogL   = icdf(pd_vt_yc_cogL,u);
          eps_ft_nc_cogH   = icdf(pd_ft_nc_cogH,u);
          eps_ft_nc_cogL   = icdf(pd_ft_nc_cogL,u);
          eps_ft_yc_cogH   = icdf(pd_ft_yc_cogH,u);
          eps_ft_yc_cogL   = icdf(pd_ft_yc_cogL,u);

        s.eps     = s.treat(:,1).*s.cognitive.*eps_control_cogH + s.treat(:,1).*(1-s.cognitive).*eps_control_cogL + ...
                      s.treat(:,2).*s.cognitive.*eps_vt_nc_cogH + s.treat(:,2).*(1-s.cognitive).*eps_vt_nc_cogL + ...
                      s.treat(:,3).*s.cognitive.*eps_vt_yc_cogH + s.treat(:,3).*(1-s.cognitive).*eps_vt_yc_cogL + ...
                      s.treat(:,4).*s.cognitive.*eps_ft_nc_cogH + s.treat(:,4).*(1-s.cognitive).*eps_ft_nc_cogL + ...
                      s.treat(:,5).*s.cognitive.*eps_ft_yc_cogH + s.treat(:,5).*(1-s.cognitive).*eps_ft_yc_cogL;
    
        else
            
        % 2) Patience
        dice                        = rand(s.nw,1);
        s.patience                = (dice<p.share_h);

        %Uniform random numbers
          u = rand(s.nw,1);
        %PDF
          pd_control_patH = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.patience==1),'kernel','Support','positive');
          pd_control_patL = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.patience==0),'kernel','Support','positive');
          pd_vt_nc_patH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==1&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.patience==1),'kernel','Support','positive');
          pd_vt_nc_patL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==1&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==0&d.patience==0),'kernel','Support','positive');
          pd_vt_yc_patH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==1&d.treat_ft_nc==0&d.treat_ft_yc==0&d.patience==1),'kernel','Support','positive');
          pd_vt_yc_patL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==1&d.treat_ft_nc==0&d.treat_ft_yc==0&d.patience==0),'kernel','Support','positive');
          pd_ft_nc_patH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==1&d.treat_ft_yc==0&d.patience==1),'kernel','Support','positive');
          pd_ft_nc_patL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==1&d.treat_ft_yc==0&d.patience==0),'kernel','Support','positive');
          pd_ft_yc_patH   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==1&d.patience==1),'kernel','Support','positive');      
          pd_ft_yc_patL   = fitdist(d.eps(d.eps>0&d.treat_vt_nc==0&d.treat_vt_yc==0&d.treat_ft_nc==0&d.treat_ft_yc==1&d.patience==0),'kernel','Support','positive');      
        %Inversion
          eps_control_patH = icdf(pd_control_patH,u);
          eps_control_patL = icdf(pd_control_patL,u);
          eps_vt_nc_patH   = icdf(pd_vt_nc_patH,u);
          eps_vt_nc_patL   = icdf(pd_vt_nc_patL,u);
          eps_vt_yc_patH   = icdf(pd_vt_yc_patH,u);
          eps_vt_yc_patL   = icdf(pd_vt_yc_patL,u);
          eps_ft_nc_patH   = icdf(pd_ft_nc_patH,u);
          eps_ft_nc_patL   = icdf(pd_ft_nc_patL,u);
          eps_ft_yc_patH   = icdf(pd_ft_yc_patH,u);
          eps_ft_yc_patL   = icdf(pd_ft_yc_patL,u);

        s.eps     = s.treat(:,1).*s.patience.*eps_control_patH + s.treat(:,1).*(1-s.patience).*eps_control_patL + ...
                      s.treat(:,2).*s.patience.*eps_vt_nc_patH + s.treat(:,2).*(1-s.patience).*eps_vt_nc_patL + ...
                      s.treat(:,3).*s.patience.*eps_vt_yc_patH + s.treat(:,3).*(1-s.patience).*eps_vt_yc_patL + ...
                      s.treat(:,4).*s.patience.*eps_ft_nc_patH + s.treat(:,4).*(1-s.patience).*eps_ft_nc_patL + ...
                      s.treat(:,5).*s.patience.*eps_ft_yc_patH + s.treat(:,5).*(1-s.patience).*eps_ft_yc_patL;
        
        end

        % Find r in support 
        s.r(s.r==0)             = 1;
        s.r_res                   = p.supp_F(s.r); 
        s.w                       = s.r_res.*s.eps.*s.e;        % corresponding draw from the distribution of r (alpha=.28902943)

        %% CALCULATE TREATMENT EFFECTS

        % ATE
        treat_ATE=s.treat;
        treat_ATE(:,1)=1;

        ATE_effect_e=zeros(5,s.capT);
        ATE_effect_w=zeros(5,s.capT);

        ATE_sd_e=zeros(5,s.capT);
        ATE_sd_w=zeros(5,s.capT);

        %Coefficients
        s.u = ones(50000,48)-s.e;
        for i=1:s.capT;
            ATE_effect_u(:,i)=(treat_ATE'*treat_ATE)^(-1)*treat_ATE'*s.u(:,i);
            ATE_effect_w(:,i)=(treat_ATE'*treat_ATE)^(-1)*treat_ATE'*s.w(:,i);
        end

        treat_control=s.treat(:,1);
        treat_vt_nc=treat_ATE(:,2);
        treat_vt_yc=treat_ATE(:,3);
        treat_ft_nc=treat_ATE(:,4);
        treat_ft_yc=treat_ATE(:,5);
        ATE_effect_w_con=zeros(5,s.capT);

        for i=1:s.capT;
            w_con=s.w(:,i);
            w_con=w_con(s.e(:,i)==1);
            clear treat_ATE_con
            treat_ATE_con(:,1)=ones(length(w_con),1);
            treat_ATE_con(:,2)=treat_vt_nc(s.e(:,i)==1);
            treat_ATE_con(:,3)=treat_vt_yc(s.e(:,i)==1);
            treat_ATE_con(:,4)=treat_ft_nc(s.e(:,i)==1);
            treat_ATE_con(:,5)=treat_ft_yc(s.e(:,i)==1);
            ATE_effect_w_con(:,i)=(treat_ATE_con'*treat_ATE_con)^(-1)*treat_ATE_con'*w_con;
        end     

        %Standard Errors
        for i=1:s.capT;
            ATE_pred_u(:,i) = treat_ATE*ATE_effect_u(:,i);
            ATE_pred_w(:,i) = treat_ATE*ATE_effect_w(:,i);
            ATE_error_u(:,i) = s.u(:,i)-ATE_pred_u(:,i);
            ATE_error_w(:,i) = s.w(:,i)-ATE_pred_w(:,i);
            sigma_sq_u = ATE_error_u(:,i)'*ATE_error_u(:,i)/(s.nw-s.nt+1);
            sigma_sq_w = ATE_error_w(:,i)'*ATE_error_w(:,i)/(s.nw-s.nt+1);
            varcov_u = (treat_ATE'*treat_ATE)^(-1)*sigma_sq_u;
            varcov_w = (treat_ATE'*treat_ATE)^(-1)*sigma_sq_w;
            ATE_sd_u(:,i) = sqrt(diag(varcov_u));
            ATE_sd_w(:,i) = sqrt(diag(varcov_w));
        end

        for i=1:s.capT;
            w_con=s.w(:,i);
            w_con=w_con(s.e(:,i)==1);
            clear treat_ATE_con ATE_pred_w_con ATE_error_w_con
            treat_ATE_con(:,1)=ones(length(w_con),1);
            treat_ATE_con(:,2)=treat_vt_nc(s.e(:,i)==1);
            treat_ATE_con(:,3)=treat_vt_yc(s.e(:,i)==1);
            treat_ATE_con(:,4)=treat_ft_nc(s.e(:,i)==1);
            treat_ATE_con(:,5)=treat_ft_yc(s.e(:,i)==1);
            ATE_pred_w_con = treat_ATE_con*ATE_effect_w_con(:,i);
            ATE_error_w_con = w_con-ATE_pred_w_con;
            sigma_sq_w_con = ATE_error_w_con'*ATE_error_w_con/(s.nw-s.nt+1);
            varcov_w_con = (treat_ATE_con'*treat_ATE_con)^(-1)*sigma_sq_w_con;
            ATE_sd_w_con(:,i) = sqrt(diag(varcov_w_con));
        end   
        
        treat_effect_ATE(:,j) = [mean(ATE_effect_u')';mean(ATE_effect_w')';mean(ATE_effect_w_con')'];
        treat_sd_ATE(:,j)     = [mean(ATE_sd_u')';mean(ATE_sd_w')';mean(ATE_sd_w_con')'];
        
        
        j = j+1;

    end

    sim=[treat_effect_ATE;treat_sd_ATE];
    
end
